/* Generated automatically by the program `genattrtab'
   from the machine description file `md'.  */

#define IN_TARGET_CODE 1
#include "config.h"
#include "system.h"
#include "coretypes.h"
#include "backend.h"
#include "predict.h"
#include "tree.h"
#include "rtl.h"
#include "alias.h"
#include "options.h"
#include "varasm.h"
#include "stor-layout.h"
#include "calls.h"
#include "insn-attr.h"
#include "memmodel.h"
#include "tm_p.h"
#include "insn-config.h"
#include "recog.h"
#include "regs.h"
#include "real.h"
#include "output.h"
#include "toplev.h"
#include "flags.h"
#include "emit-rtl.h"

#define operands recog_data.operand

int
internal_dfa_insn_code (rtx_insn *insn ATTRIBUTE_UNUSED)
{
  enum attr_type cached_type ATTRIBUTE_UNUSED;
  enum attr_mul32 cached_mul32 ATTRIBUTE_UNUSED;
  enum attr_widen_mul64 cached_widen_mul64 ATTRIBUTE_UNUSED;
  enum attr_core_cycles cached_core_cycles ATTRIBUTE_UNUSED;
  enum attr_cortex_a7_neon_type cached_cortex_a7_neon_type ATTRIBUTE_UNUSED;
  enum attr_cortex_a8_neon_type cached_cortex_a8_neon_type ATTRIBUTE_UNUSED;
  enum attr_cortex_a9_neon_type cached_cortex_a9_neon_type ATTRIBUTE_UNUSED;
  enum attr_cortex_a15_neon_type cached_cortex_a15_neon_type ATTRIBUTE_UNUSED;
  enum attr_cortex_a17_neon_type cached_cortex_a17_neon_type ATTRIBUTE_UNUSED;
  enum attr_cortex_a53_advsimd_type cached_cortex_a53_advsimd_type ATTRIBUTE_UNUSED;
  enum attr_cortex_a57_neon_type cached_cortex_a57_neon_type ATTRIBUTE_UNUSED;
  enum attr_predicated cached_predicated ATTRIBUTE_UNUSED;
  enum attr_exynos_m1_neon_type cached_exynos_m1_neon_type ATTRIBUTE_UNUSED;
  enum attr_conds cached_conds ATTRIBUTE_UNUSED;
  int cached_shift ATTRIBUTE_UNUSED;

  switch (recog_memoized (insn))
    {
    case 2833:  /* neon_vbfdot_lanev8bfv4sf */
    case 2832:  /* neon_vbfdot_lanev8bfv2sf */
    case 2831:  /* neon_vbfdot_lanev4bfv4sf */
    case 2830:  /* neon_vbfdot_lanev4bfv2sf */
    case 2829:  /* neon_vbfdotv4sf */
    case 2828:  /* neon_vbfdotv2sf */
    case 1992:  /* neon_sudot_laneqv16qi */
    case 1991:  /* neon_usdot_laneqv16qi */
    case 1990:  /* neon_sudot_laneqv8qi */
    case 1989:  /* neon_usdot_laneqv8qi */
    case 1988:  /* neon_sudot_lanev16qi */
    case 1987:  /* neon_usdot_lanev16qi */
    case 1986:  /* neon_sudot_lanev8qi */
    case 1985:  /* neon_usdot_lanev8qi */
    case 1984:  /* neon_udot_laneqv16qi */
    case 1983:  /* neon_sdot_laneqv16qi */
    case 1982:  /* neon_udot_laneqv8qi */
    case 1981:  /* neon_sdot_laneqv8qi */
    case 1980:  /* neon_udot_lanev16qi */
    case 1979:  /* neon_sdot_lanev16qi */
    case 1978:  /* neon_udot_lanev8qi */
    case 1977:  /* neon_sdot_lanev8qi */
    case 1976:  /* neon_usdotv16qi */
    case 1975:  /* neon_usdotv8qi */
    case 1974:  /* udot_prodv16qi */
    case 1973:  /* sdot_prodv16qi */
    case 1972:  /* udot_prodv8qi */
    case 1971:  /* sdot_prodv8qi */
    case 1970:  /* neon_vcmlaq_lane270v4sf */
    case 1969:  /* neon_vcmlaq_lane180v4sf */
    case 1968:  /* neon_vcmlaq_lane90v4sf */
    case 1967:  /* neon_vcmlaq_lane0v4sf */
    case 1966:  /* neon_vcmlaq_lane270v8hf */
    case 1965:  /* neon_vcmlaq_lane180v8hf */
    case 1964:  /* neon_vcmlaq_lane90v8hf */
    case 1963:  /* neon_vcmlaq_lane0v8hf */
    case 1962:  /* neon_vcmla_laneq270v4hf */
    case 1961:  /* neon_vcmla_laneq180v4hf */
    case 1960:  /* neon_vcmla_laneq90v4hf */
    case 1959:  /* neon_vcmla_laneq0v4hf */
    case 1958:  /* neon_vcmla_laneq270v2sf */
    case 1957:  /* neon_vcmla_laneq180v2sf */
    case 1956:  /* neon_vcmla_laneq90v2sf */
    case 1955:  /* neon_vcmla_laneq0v2sf */
    case 1954:  /* neon_vcmla_lane270v4sf */
    case 1953:  /* neon_vcmla_lane180v4sf */
    case 1952:  /* neon_vcmla_lane90v4sf */
    case 1951:  /* neon_vcmla_lane0v4sf */
    case 1950:  /* neon_vcmla_lane270v2sf */
    case 1949:  /* neon_vcmla_lane180v2sf */
    case 1948:  /* neon_vcmla_lane90v2sf */
    case 1947:  /* neon_vcmla_lane0v2sf */
    case 1946:  /* neon_vcmla_lane270v8hf */
    case 1945:  /* neon_vcmla_lane180v8hf */
    case 1944:  /* neon_vcmla_lane90v8hf */
    case 1943:  /* neon_vcmla_lane0v8hf */
    case 1942:  /* neon_vcmla_lane270v4hf */
    case 1941:  /* neon_vcmla_lane180v4hf */
    case 1940:  /* neon_vcmla_lane90v4hf */
    case 1939:  /* neon_vcmla_lane0v4hf */
    case 1938:  /* neon_vcmla270v4sf */
    case 1937:  /* neon_vcmla180v4sf */
    case 1936:  /* neon_vcmla90v4sf */
    case 1935:  /* neon_vcmla0v4sf */
    case 1934:  /* neon_vcmla270v2sf */
    case 1933:  /* neon_vcmla180v2sf */
    case 1932:  /* neon_vcmla90v2sf */
    case 1931:  /* neon_vcmla0v2sf */
    case 1930:  /* neon_vcmla270v8hf */
    case 1929:  /* neon_vcmla180v8hf */
    case 1928:  /* neon_vcmla90v8hf */
    case 1927:  /* neon_vcmla0v8hf */
    case 1926:  /* neon_vcmla270v4hf */
    case 1925:  /* neon_vcmla180v4hf */
    case 1924:  /* neon_vcmla90v4hf */
    case 1923:  /* neon_vcmla0v4hf */
    case 1922:  /* neon_vcadd270v4sf */
    case 1921:  /* neon_vcadd90v4sf */
    case 1920:  /* neon_vcadd270v2sf */
    case 1919:  /* neon_vcadd90v2sf */
    case 1918:  /* neon_vcadd270v8hf */
    case 1917:  /* neon_vcadd90v8hf */
    case 1916:  /* neon_vcadd270v4hf */
    case 1915:  /* neon_vcadd90v4hf */
      if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 27 /* 0x1b */;
        }
      else if (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7))))
        {
	  return 243 /* 0xf3 */;
        }
      else if (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57))))
        {
	  return 627 /* 0x273 */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6835:  /* *p iwmmxt_textrcv8qi3 */
    case 6834:  /* *p iwmmxt_textrcv4hi3 */
    case 6833:  /* *p iwmmxt_textrcv2si3 */
    case 6832:  /* *p iwmmxt_torvscv8qi3 */
    case 6831:  /* *p iwmmxt_torvscv4hi3 */
    case 6830:  /* *p iwmmxt_torvscv2si3 */
    case 6829:  /* *p iwmmxt_torcv8qi3 */
    case 6828:  /* *p iwmmxt_torcv4hi3 */
    case 6827:  /* *p iwmmxt_torcv2si3 */
    case 6826:  /* *p iwmmxt_tandcv8qi3 */
    case 6825:  /* *p iwmmxt_tandcv4hi3 */
    case 6824:  /* *p iwmmxt_tandcv2si3 */
    case 745:  /* iwmmxt_textrcv8qi3 */
    case 744:  /* iwmmxt_textrcv4hi3 */
    case 743:  /* iwmmxt_textrcv2si3 */
    case 742:  /* iwmmxt_torvscv8qi3 */
    case 741:  /* iwmmxt_torvscv4hi3 */
    case 740:  /* iwmmxt_torvscv2si3 */
    case 739:  /* iwmmxt_torcv8qi3 */
    case 738:  /* iwmmxt_torcv4hi3 */
    case 737:  /* iwmmxt_torcv2si3 */
    case 736:  /* iwmmxt_tandcv8qi3 */
    case 735:  /* iwmmxt_tandcv4hi3 */
    case 734:  /* iwmmxt_tandcv2si3 */
      if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6769:  /* *p iwmmxt_wsadhz */
    case 6768:  /* *p iwmmxt_wsadbz */
    case 6767:  /* *p iwmmxt_wsadh */
    case 6766:  /* *p iwmmxt_wsadb */
    case 679:  /* iwmmxt_wsadhz */
    case 678:  /* iwmmxt_wsadbz */
    case 677:  /* iwmmxt_wsadh */
    case 676:  /* iwmmxt_wsadb */
      if ((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt)))
        {
	  return 7;
        }
      else if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6753:  /* *p iwmmxt_tmiatt */
    case 6752:  /* *p iwmmxt_tmiabt */
    case 6751:  /* *p iwmmxt_tmiatb */
    case 6750:  /* *p iwmmxt_tmiabb */
    case 6749:  /* *p iwmmxt_tmiaph */
    case 6748:  /* *p iwmmxt_tmia */
    case 663:  /* iwmmxt_tmiatt */
    case 662:  /* iwmmxt_tmiabt */
    case 661:  /* iwmmxt_tmiatb */
    case 660:  /* iwmmxt_tmiabb */
    case 659:  /* iwmmxt_tmiaph */
    case 658:  /* iwmmxt_tmia */
      if ((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt)))
        {
	  return 8;
        }
      else if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6745:  /* *p ashldi3_di */
    case 6744:  /* *p ashlv2si3_di */
    case 6743:  /* *p ashlv4hi3_di */
    case 6742:  /* *p lshrdi3_di */
    case 6741:  /* *p lshrv2si3_di */
    case 6740:  /* *p lshrv4hi3_di */
    case 6739:  /* *p ashrdi3_di */
    case 6738:  /* *p ashrv2si3_di */
    case 6737:  /* *p ashrv4hi3_di */
    case 6736:  /* *p rordi3_di */
    case 6735:  /* *p rorv2si3_di */
    case 6734:  /* *p rorv4hi3_di */
    case 6733:  /* *p ashldi3_iwmmxt */
    case 6732:  /* *p ashlv2si3_iwmmxt */
    case 6731:  /* *p ashlv4hi3_iwmmxt */
    case 6730:  /* *p lshrdi3_iwmmxt */
    case 6729:  /* *p lshrv2si3_iwmmxt */
    case 6728:  /* *p lshrv4hi3_iwmmxt */
    case 6727:  /* *p ashrdi3_iwmmxt */
    case 6726:  /* *p ashrv2si3_iwmmxt */
    case 6725:  /* *p ashrv4hi3_iwmmxt */
    case 6724:  /* *p rordi3 */
    case 6723:  /* *p rorv2si3 */
    case 6722:  /* *p rorv4hi3 */
    case 655:  /* ashldi3_di */
    case 654:  /* ashlv2si3_di */
    case 653:  /* ashlv4hi3_di */
    case 652:  /* lshrdi3_di */
    case 651:  /* lshrv2si3_di */
    case 650:  /* lshrv4hi3_di */
    case 649:  /* ashrdi3_di */
    case 648:  /* ashrv2si3_di */
    case 647:  /* ashrv4hi3_di */
    case 646:  /* rordi3_di */
    case 645:  /* rorv2si3_di */
    case 644:  /* rorv4hi3_di */
    case 643:  /* ashldi3_iwmmxt */
    case 642:  /* ashlv2si3_iwmmxt */
    case 641:  /* ashlv4hi3_iwmmxt */
    case 640:  /* lshrdi3_iwmmxt */
    case 639:  /* lshrv2si3_iwmmxt */
    case 638:  /* lshrv4hi3_iwmmxt */
    case 637:  /* ashrdi3_iwmmxt */
    case 636:  /* ashrv2si3_iwmmxt */
    case 635:  /* ashrv4hi3_iwmmxt */
    case 634:  /* rordi3 */
    case 633:  /* rorv2si3 */
    case 632:  /* rorv4hi3 */
      if ((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt)))
        {
	  return 3;
        }
      else if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6823:  /* *p iwmmxt_wmerge */
    case 6765:  /* *p iwmmxt_walignr3 */
    case 6764:  /* *p iwmmxt_walignr2 */
    case 6763:  /* *p iwmmxt_walignr1 */
    case 6762:  /* *p iwmmxt_walignr0 */
    case 6761:  /* *p iwmmxt_walignr */
    case 6760:  /* *p iwmmxt_waligni */
    case 6721:  /* *p iwmmxt_wunpckelsw */
    case 6720:  /* *p iwmmxt_wunpckelsh */
    case 6719:  /* *p iwmmxt_wunpckelsb */
    case 6718:  /* *p iwmmxt_wunpckeluw */
    case 6717:  /* *p iwmmxt_wunpckeluh */
    case 6716:  /* *p iwmmxt_wunpckelub */
    case 6715:  /* *p iwmmxt_wunpckehsw */
    case 6714:  /* *p iwmmxt_wunpckehsh */
    case 6713:  /* *p iwmmxt_wunpckehsb */
    case 6712:  /* *p iwmmxt_wunpckehuw */
    case 6711:  /* *p iwmmxt_wunpckehuh */
    case 6710:  /* *p iwmmxt_wunpckehub */
    case 6709:  /* *p iwmmxt_wunpckilw */
    case 6708:  /* *p iwmmxt_wunpckilh */
    case 6707:  /* *p iwmmxt_wunpckilb */
    case 6706:  /* *p iwmmxt_wunpckihw */
    case 6705:  /* *p iwmmxt_wunpckihh */
    case 6704:  /* *p iwmmxt_wunpckihb */
    case 6703:  /* *p iwmmxt_wpackdus */
    case 6702:  /* *p iwmmxt_wpackwus */
    case 6701:  /* *p iwmmxt_wpackhus */
    case 6700:  /* *p iwmmxt_wpackdss */
    case 6699:  /* *p iwmmxt_wpackwss */
    case 6698:  /* *p iwmmxt_wpackhss */
    case 6676:  /* *p iwmmxt_wshufh */
    case 733:  /* iwmmxt_wmerge */
    case 675:  /* iwmmxt_walignr3 */
    case 674:  /* iwmmxt_walignr2 */
    case 673:  /* iwmmxt_walignr1 */
    case 672:  /* iwmmxt_walignr0 */
    case 671:  /* iwmmxt_walignr */
    case 670:  /* iwmmxt_waligni */
    case 631:  /* iwmmxt_wunpckelsw */
    case 630:  /* iwmmxt_wunpckelsh */
    case 629:  /* iwmmxt_wunpckelsb */
    case 628:  /* iwmmxt_wunpckeluw */
    case 627:  /* iwmmxt_wunpckeluh */
    case 626:  /* iwmmxt_wunpckelub */
    case 625:  /* iwmmxt_wunpckehsw */
    case 624:  /* iwmmxt_wunpckehsh */
    case 623:  /* iwmmxt_wunpckehsb */
    case 622:  /* iwmmxt_wunpckehuw */
    case 621:  /* iwmmxt_wunpckehuh */
    case 620:  /* iwmmxt_wunpckehub */
    case 619:  /* iwmmxt_wunpckilw */
    case 618:  /* iwmmxt_wunpckilh */
    case 617:  /* iwmmxt_wunpckilb */
    case 616:  /* iwmmxt_wunpckihw */
    case 615:  /* iwmmxt_wunpckihh */
    case 614:  /* iwmmxt_wunpckihb */
    case 613:  /* iwmmxt_wpackdus */
    case 612:  /* iwmmxt_wpackwus */
    case 611:  /* iwmmxt_wpackhus */
    case 610:  /* iwmmxt_wpackdss */
    case 609:  /* iwmmxt_wpackwss */
    case 608:  /* iwmmxt_wpackhss */
    case 586:  /* iwmmxt_wshufh */
      if ((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt)))
        {
	  return 2;
        }
      else if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6756:  /* *p iwmmxt_tmovmskw */
    case 6755:  /* *p iwmmxt_tmovmskh */
    case 6754:  /* *p iwmmxt_tmovmskb */
    case 6675:  /* *p iwmmxt_textrmw */
    case 6674:  /* *p iwmmxt_textrmsh */
    case 6673:  /* *p iwmmxt_textrmuh */
    case 6672:  /* *p iwmmxt_textrmsb */
    case 6671:  /* *p iwmmxt_textrmub */
    case 666:  /* iwmmxt_tmovmskw */
    case 665:  /* iwmmxt_tmovmskh */
    case 664:  /* iwmmxt_tmovmskb */
    case 585:  /* iwmmxt_textrmw */
    case 584:  /* iwmmxt_textrmsh */
    case 583:  /* iwmmxt_textrmuh */
    case 582:  /* iwmmxt_textrmsb */
    case 581:  /* iwmmxt_textrmub */
      if ((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt)))
        {
	  return 5;
        }
      else if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6822:  /* *p iwmmxt_wmiawttn */
    case 6821:  /* *p iwmmxt_wmiawtbn */
    case 6820:  /* *p iwmmxt_wmiawbtn */
    case 6819:  /* *p iwmmxt_wmiawbbn */
    case 6818:  /* *p iwmmxt_wmiawtt */
    case 6817:  /* *p iwmmxt_wmiawtb */
    case 6816:  /* *p iwmmxt_wmiawbt */
    case 6815:  /* *p iwmmxt_wmiawbb */
    case 6814:  /* *p iwmmxt_wmiattn */
    case 6813:  /* *p iwmmxt_wmiatbn */
    case 6812:  /* *p iwmmxt_wmiabtn */
    case 6811:  /* *p iwmmxt_wmiabbn */
    case 6810:  /* *p iwmmxt_wmiatt */
    case 6809:  /* *p iwmmxt_wmiatb */
    case 6808:  /* *p iwmmxt_wmiabt */
    case 6807:  /* *p iwmmxt_wmiabb */
    case 6806:  /* *p iwmmxt_wqmiattn */
    case 6805:  /* *p iwmmxt_wqmiatbn */
    case 6804:  /* *p iwmmxt_wqmiabtn */
    case 6803:  /* *p iwmmxt_wqmiabbn */
    case 6802:  /* *p iwmmxt_wqmiatt */
    case 6801:  /* *p iwmmxt_wqmiatb */
    case 6800:  /* *p iwmmxt_wqmiabt */
    case 6799:  /* *p iwmmxt_wqmiabb */
    case 6796:  /* *p iwmmxt_wqmulwmr */
    case 6794:  /* *p iwmmxt_wqmulwm */
    case 6792:  /* *p iwmmxt_wmulwl */
    case 6791:  /* *p iwmmxt_wmulwumr */
    case 6787:  /* *p iwmmxt_wmulwum */
    case 6786:  /* *p iwmmxt_wmulwsm */
    case 6785:  /* *p iwmmxt_wmaddun */
    case 6784:  /* *p iwmmxt_wmaddsn */
    case 6783:  /* *p iwmmxt_wmaddux */
    case 6782:  /* *p iwmmxt_wmaddsx */
    case 6747:  /* *p iwmmxt_wmaddu */
    case 6746:  /* *p iwmmxt_wmadds */
    case 6659:  /* *p iwmmxt_wmacuz */
    case 6658:  /* *p iwmmxt_wmacu */
    case 6657:  /* *p iwmmxt_wmacsz */
    case 6656:  /* *p iwmmxt_wmacs */
    case 732:  /* iwmmxt_wmiawttn */
    case 731:  /* iwmmxt_wmiawtbn */
    case 730:  /* iwmmxt_wmiawbtn */
    case 729:  /* iwmmxt_wmiawbbn */
    case 728:  /* iwmmxt_wmiawtt */
    case 727:  /* iwmmxt_wmiawtb */
    case 726:  /* iwmmxt_wmiawbt */
    case 725:  /* iwmmxt_wmiawbb */
    case 724:  /* iwmmxt_wmiattn */
    case 723:  /* iwmmxt_wmiatbn */
    case 722:  /* iwmmxt_wmiabtn */
    case 721:  /* iwmmxt_wmiabbn */
    case 720:  /* iwmmxt_wmiatt */
    case 719:  /* iwmmxt_wmiatb */
    case 718:  /* iwmmxt_wmiabt */
    case 717:  /* iwmmxt_wmiabb */
    case 716:  /* iwmmxt_wqmiattn */
    case 715:  /* iwmmxt_wqmiatbn */
    case 714:  /* iwmmxt_wqmiabtn */
    case 713:  /* iwmmxt_wqmiabbn */
    case 712:  /* iwmmxt_wqmiatt */
    case 711:  /* iwmmxt_wqmiatb */
    case 710:  /* iwmmxt_wqmiabt */
    case 709:  /* iwmmxt_wqmiabb */
    case 706:  /* iwmmxt_wqmulwmr */
    case 704:  /* iwmmxt_wqmulwm */
    case 702:  /* iwmmxt_wmulwl */
    case 701:  /* iwmmxt_wmulwumr */
    case 697:  /* iwmmxt_wmulwum */
    case 696:  /* iwmmxt_wmulwsm */
    case 695:  /* iwmmxt_wmaddun */
    case 694:  /* iwmmxt_wmaddsn */
    case 693:  /* iwmmxt_wmaddux */
    case 692:  /* iwmmxt_wmaddsx */
    case 657:  /* iwmmxt_wmaddu */
    case 656:  /* iwmmxt_wmadds */
    case 569:  /* iwmmxt_wmacuz */
    case 568:  /* iwmmxt_wmacu */
    case 567:  /* iwmmxt_wmacsz */
    case 566:  /* iwmmxt_wmacs */
      if ((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt)))
        {
	  return 9;
        }
      else if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6795:  /* *p iwmmxt_wqmulmr */
    case 6793:  /* *p iwmmxt_wqmulm */
    case 6790:  /* *p iwmmxt_wmulwsmr */
    case 6789:  /* *p iwmmxt_wmulumr */
    case 6788:  /* *p iwmmxt_wmulsmr */
    case 6655:  /* *p umulv4hi3_highpart */
    case 6654:  /* *p smulv4hi3_highpart */
    case 6653:  /* *p *mulv4hi3_iwmmxt */
    case 705:  /* iwmmxt_wqmulmr */
    case 703:  /* iwmmxt_wqmulm */
    case 700:  /* iwmmxt_wmulwsmr */
    case 699:  /* iwmmxt_wmulumr */
    case 698:  /* iwmmxt_wmulsmr */
    case 565:  /* umulv4hi3_highpart */
    case 564:  /* smulv4hi3_highpart */
    case 563:  /* *mulv4hi3_iwmmxt */
      if ((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt)))
        {
	  return 10 /* 0xa */;
        }
      else if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6798:  /* *p iwmmxt_waddbhusl */
    case 6797:  /* *p iwmmxt_waddbhusm */
    case 6781:  /* *p iwmmxt_avg4r */
    case 6780:  /* *p iwmmxt_avg4 */
    case 6779:  /* *p addcv2si3 */
    case 6778:  /* *p addcv4hi3 */
    case 6777:  /* *p iwmmxt_wsubaddhx */
    case 6776:  /* *p iwmmxt_waddsubhx */
    case 6759:  /* *p iwmmxt_waccw */
    case 6758:  /* *p iwmmxt_wacch */
    case 6757:  /* *p iwmmxt_waccb */
    case 6697:  /* *p *uminv8qi3_iwmmxt */
    case 6696:  /* *p *uminv4hi3_iwmmxt */
    case 6695:  /* *p *uminv2si3_iwmmxt */
    case 6694:  /* *p *sminv8qi3_iwmmxt */
    case 6693:  /* *p *sminv4hi3_iwmmxt */
    case 6692:  /* *p *sminv2si3_iwmmxt */
    case 6691:  /* *p *umaxv8qi3_iwmmxt */
    case 6690:  /* *p *umaxv4hi3_iwmmxt */
    case 6689:  /* *p *umaxv2si3_iwmmxt */
    case 6688:  /* *p *smaxv8qi3_iwmmxt */
    case 6687:  /* *p *smaxv4hi3_iwmmxt */
    case 6686:  /* *p *smaxv2si3_iwmmxt */
    case 6685:  /* *p gtv2si3 */
    case 6684:  /* *p gtv4hi3 */
    case 6683:  /* *p gtv8qi3 */
    case 6682:  /* *p gtuv2si3 */
    case 6681:  /* *p gtuv4hi3 */
    case 6680:  /* *p gtuv8qi3 */
    case 6679:  /* *p eqv2si3 */
    case 6678:  /* *p eqv4hi3 */
    case 6677:  /* *p eqv8qi3 */
    case 6667:  /* *p iwmmxt_uavgv4hi3 */
    case 6666:  /* *p iwmmxt_uavgv8qi3 */
    case 6665:  /* *p iwmmxt_uavgrndv4hi3 */
    case 6664:  /* *p iwmmxt_uavgrndv8qi3 */
    case 6652:  /* *p ussubv2si3 */
    case 6651:  /* *p ussubv4hi3 */
    case 6650:  /* *p ussubv8qi3 */
    case 6649:  /* *p sssubv2si3 */
    case 6648:  /* *p sssubv4hi3 */
    case 6647:  /* *p sssubv8qi3 */
    case 6646:  /* *p *subv8qi3_iwmmxt */
    case 6645:  /* *p *subv4hi3_iwmmxt */
    case 6644:  /* *p *subv2si3_iwmmxt */
    case 6643:  /* *p usaddv2si3 */
    case 6642:  /* *p usaddv4hi3 */
    case 6641:  /* *p usaddv8qi3 */
    case 6640:  /* *p ssaddv2si3 */
    case 6639:  /* *p ssaddv4hi3 */
    case 6638:  /* *p ssaddv8qi3 */
    case 6637:  /* *p *addv8qi3_iwmmxt */
    case 6636:  /* *p *addv4hi3_iwmmxt */
    case 6635:  /* *p *addv2si3_iwmmxt */
    case 708:  /* iwmmxt_waddbhusl */
    case 707:  /* iwmmxt_waddbhusm */
    case 691:  /* iwmmxt_avg4r */
    case 690:  /* iwmmxt_avg4 */
    case 689:  /* addcv2si3 */
    case 688:  /* addcv4hi3 */
    case 687:  /* iwmmxt_wsubaddhx */
    case 686:  /* iwmmxt_waddsubhx */
    case 669:  /* iwmmxt_waccw */
    case 668:  /* iwmmxt_wacch */
    case 667:  /* iwmmxt_waccb */
    case 607:  /* *uminv8qi3_iwmmxt */
    case 606:  /* *uminv4hi3_iwmmxt */
    case 605:  /* *uminv2si3_iwmmxt */
    case 604:  /* *sminv8qi3_iwmmxt */
    case 603:  /* *sminv4hi3_iwmmxt */
    case 602:  /* *sminv2si3_iwmmxt */
    case 601:  /* *umaxv8qi3_iwmmxt */
    case 600:  /* *umaxv4hi3_iwmmxt */
    case 599:  /* *umaxv2si3_iwmmxt */
    case 598:  /* *smaxv8qi3_iwmmxt */
    case 597:  /* *smaxv4hi3_iwmmxt */
    case 596:  /* *smaxv2si3_iwmmxt */
    case 595:  /* gtv2si3 */
    case 594:  /* gtv4hi3 */
    case 593:  /* gtv8qi3 */
    case 592:  /* gtuv2si3 */
    case 591:  /* gtuv4hi3 */
    case 590:  /* gtuv8qi3 */
    case 589:  /* eqv2si3 */
    case 588:  /* eqv4hi3 */
    case 587:  /* eqv8qi3 */
    case 577:  /* iwmmxt_uavgv4hi3 */
    case 576:  /* iwmmxt_uavgv8qi3 */
    case 575:  /* iwmmxt_uavgrndv4hi3 */
    case 574:  /* iwmmxt_uavgrndv8qi3 */
    case 562:  /* ussubv2si3 */
    case 561:  /* ussubv4hi3 */
    case 560:  /* ussubv8qi3 */
    case 559:  /* sssubv2si3 */
    case 558:  /* sssubv4hi3 */
    case 557:  /* sssubv8qi3 */
    case 556:  /* *subv8qi3_iwmmxt */
    case 555:  /* *subv4hi3_iwmmxt */
    case 554:  /* *subv2si3_iwmmxt */
    case 553:  /* usaddv2si3 */
    case 552:  /* usaddv4hi3 */
    case 551:  /* usaddv8qi3 */
    case 550:  /* ssaddv2si3 */
    case 549:  /* ssaddv4hi3 */
    case 548:  /* ssaddv8qi3 */
    case 547:  /* *addv8qi3_iwmmxt */
    case 546:  /* *addv4hi3_iwmmxt */
    case 545:  /* *addv2si3_iwmmxt */
      if ((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt)))
        {
	  return 6;
        }
      else if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6775:  /* *p iwmmxt_wabsdiffw */
    case 6774:  /* *p iwmmxt_wabsdiffh */
    case 6773:  /* *p iwmmxt_wabsdiffb */
    case 6772:  /* *p iwmmxt_wabsv8qi3 */
    case 6771:  /* *p iwmmxt_wabsv4hi3 */
    case 6770:  /* *p iwmmxt_wabsv2si3 */
    case 6663:  /* *p iwmmxt_clrv2si */
    case 6662:  /* *p iwmmxt_clrv4hi */
    case 6661:  /* *p iwmmxt_clrv8qi */
    case 6660:  /* *p iwmmxt_clrdi */
    case 6634:  /* *p *xorv8qi3_iwmmxt */
    case 6633:  /* *p *xorv4hi3_iwmmxt */
    case 6632:  /* *p *xorv2si3_iwmmxt */
    case 6631:  /* *p *iorv8qi3_iwmmxt */
    case 6630:  /* *p *iorv4hi3_iwmmxt */
    case 6629:  /* *p *iorv2si3_iwmmxt */
    case 6628:  /* *p *andv8qi3_iwmmxt */
    case 6627:  /* *p *andv4hi3_iwmmxt */
    case 6626:  /* *p *andv2si3_iwmmxt */
    case 6622:  /* *p iwmmxt_nanddi3 */
    case 6621:  /* *p iwmmxt_anddi3 */
    case 6620:  /* *p iwmmxt_xordi3 */
    case 6619:  /* *p iwmmxt_iordi3 */
    case 685:  /* iwmmxt_wabsdiffw */
    case 684:  /* iwmmxt_wabsdiffh */
    case 683:  /* iwmmxt_wabsdiffb */
    case 682:  /* iwmmxt_wabsv8qi3 */
    case 681:  /* iwmmxt_wabsv4hi3 */
    case 680:  /* iwmmxt_wabsv2si3 */
    case 573:  /* iwmmxt_clrv2si */
    case 572:  /* iwmmxt_clrv4hi */
    case 571:  /* iwmmxt_clrv8qi */
    case 570:  /* iwmmxt_clrdi */
    case 544:  /* *xorv8qi3_iwmmxt */
    case 543:  /* *xorv4hi3_iwmmxt */
    case 542:  /* *xorv2si3_iwmmxt */
    case 541:  /* *iorv8qi3_iwmmxt */
    case 540:  /* *iorv4hi3_iwmmxt */
    case 539:  /* *iorv2si3_iwmmxt */
    case 538:  /* *andv8qi3_iwmmxt */
    case 537:  /* *andv4hi3_iwmmxt */
    case 536:  /* *andv2si3_iwmmxt */
    case 529:  /* iwmmxt_nanddi3 */
    case 528:  /* iwmmxt_anddi3 */
    case 527:  /* iwmmxt_xordi3 */
    case 526:  /* iwmmxt_iordi3 */
      if ((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt)))
        {
	  return 1;
        }
      else if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 6670:  /* *p iwmmxt_tinsrw */
    case 6669:  /* *p iwmmxt_tinsrh */
    case 6668:  /* *p iwmmxt_tinsrb */
    case 6618:  /* *p tbcstv2si */
    case 6617:  /* *p tbcstv4hi */
    case 6616:  /* *p tbcstv8qi */
    case 580:  /* iwmmxt_tinsrw */
    case 579:  /* iwmmxt_tinsrh */
    case 578:  /* iwmmxt_tinsrb */
    case 525:  /* tbcstv2si */
    case 524:  /* tbcstv4hi */
    case 523:  /* tbcstv8qi */
      if ((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt)))
        {
	  return 4;
        }
      else if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 28 /* 0x1c */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case 403:  /* force_register_use */
    case 398:  /* consttable_16 */
    case 397:  /* consttable_8 */
    case 396:  /* consttable_4 */
    case 395:  /* consttable_2 */
    case 394:  /* consttable_1 */
    case 393:  /* consttable_end */
    case 392:  /* align_8 */
    case 391:  /* align_4 */
    case 276:  /* *deleted_compare */
      return 0;

    case 7040:  /* *p mve_sqshll_di */
    case 7039:  /* *p mve_srshrl_di */
    case 7038:  /* *p mve_srshr_si */
    case 7037:  /* *p mve_sqshl_si */
    case 7036:  /* *p mve_urshr_si */
    case 7035:  /* *p mve_uqshl_si */
    case 7034:  /* *p mve_urshrl_di */
    case 7033:  /* *p mve_uqshll_di */
    case 7032:  /* *p mve_sqrshr_si */
    case 7031:  /* *p mve_uqrshl_si */
    case 7030:  /* *p mve_sqrshrl_sat48_di */
    case 7029:  /* *p mve_sqrshrl_sat64_di */
    case 7028:  /* *p mve_uqrshll_sat48_di */
    case 7027:  /* *p mve_uqrshll_sat64_di */
    case 6970:  /* *p arm_store_release_exclusivesi */
    case 6969:  /* *p arm_store_release_exclusivehi */
    case 6968:  /* *p arm_store_release_exclusiveqi */
    case 6967:  /* *p arm_store_release_exclusivedi */
    case 6966:  /* *p arm_store_exclusivedi */
    case 6965:  /* *p arm_store_exclusivesi */
    case 6964:  /* *p arm_store_exclusivehi */
    case 6963:  /* *p arm_store_exclusiveqi */
    case 6962:  /* *p arm_load_acquire_exclusivedi */
    case 6961:  /* *p arm_load_exclusivedi */
    case 6960:  /* *p arm_load_acquire_exclusivesi */
    case 6959:  /* *p arm_load_exclusivesi */
    case 6958:  /* *p arm_load_acquire_exclusivehi */
    case 6957:  /* *p arm_load_acquire_exclusiveqi */
    case 6956:  /* *p arm_load_exclusivehi */
    case 6955:  /* *p arm_load_exclusiveqi */
    case 6954:  /* *p arm_atomic_loaddi2_ldrd */
    case 6953:  /* *p atomic_storesi */
    case 6952:  /* *p atomic_storehi */
    case 6951:  /* *p atomic_storeqi */
    case 6950:  /* *p atomic_loadsi */
    case 6949:  /* *p atomic_loadhi */
    case 6948:  /* *p atomic_loadqi */
    case 6947:  /* *p thumb2_lsrl */
    case 6946:  /* *p thumb2_lsll */
    case 6945:  /* *p thumb2_asrl */
    case 6944:  /* *p *clear_multiple */
    case 6943:  /* *p *clear_apsr */
    case 6615:  /* *p *load_multiple */
    case 6420:  /* *p arm_set_apsr */
    case 6419:  /* *p arm_get_apsr */
    case 4963:  /* *movmisalignv4sf_mve_load */
    case 4962:  /* *movmisalignv8hf_mve_load */
    case 4961:  /* *movmisalignv4si_mve_load */
    case 4960:  /* *movmisalignv8hi_mve_load */
    case 4959:  /* *movmisalignv16qi_mve_load */
    case 4958:  /* *movmisalignv4sf_mve_store */
    case 4957:  /* *movmisalignv8hf_mve_store */
    case 4956:  /* *movmisalignv4si_mve_store */
    case 4955:  /* *movmisalignv8hi_mve_store */
    case 4954:  /* *movmisalignv16qi_mve_store */
    case 4953:  /* arm_vcx3qa_p_v16qi */
    case 4952:  /* arm_vcx3q_p_v16qi */
    case 4951:  /* arm_vcx2qa_p_v16qi */
    case 4950:  /* arm_vcx2q_p_v16qi */
    case 4949:  /* arm_vcx1qa_p_v16qi */
    case 4948:  /* arm_vcx1q_p_v16qi */
    case 4947:  /* arm_vcx3qav16qi */
    case 4946:  /* arm_vcx3qv16qi */
    case 4945:  /* arm_vcx2qav16qi */
    case 4944:  /* arm_vcx2qv16qi */
    case 4943:  /* arm_vcx1qav16qi */
    case 4942:  /* arm_vcx1qv16qi */
    case 4941:  /* mve_vshlcq_m_uv4si */
    case 4940:  /* mve_vshlcq_m_sv4si */
    case 4939:  /* mve_vshlcq_m_uv8hi */
    case 4938:  /* mve_vshlcq_m_sv8hi */
    case 4937:  /* mve_vshlcq_m_uv16qi */
    case 4936:  /* mve_vshlcq_m_sv16qi */
    case 4935:  /* mve_sqshll_di */
    case 4934:  /* mve_srshrl_di */
    case 4933:  /* mve_srshr_si */
    case 4932:  /* mve_sqshl_si */
    case 4931:  /* mve_urshr_si */
    case 4930:  /* mve_uqshl_si */
    case 4929:  /* mve_urshrl_di */
    case 4928:  /* mve_uqshll_di */
    case 4927:  /* mve_sqrshr_si */
    case 4926:  /* mve_uqrshl_si */
    case 4925:  /* mve_sqrshrl_sat48_di */
    case 4924:  /* mve_sqrshrl_sat64_di */
    case 4923:  /* mve_uqrshll_sat48_di */
    case 4922:  /* mve_uqrshll_sat64_di */
    case 4921:  /* mve_vec_setv2di_internal */
    case 4920:  /* mve_vec_setv4sf_internal */
    case 4919:  /* mve_vec_setv4si_internal */
    case 4918:  /* mve_vec_setv8hf_internal */
    case 4917:  /* mve_vec_setv8hi_internal */
    case 4916:  /* mve_vec_setv16qi_internal */
    case 4915:  /* *mve_vec_extract_zext_internalv4si */
    case 4914:  /* *mve_vec_extract_zext_internalv8hi */
    case 4913:  /* *mve_vec_extract_zext_internalv16qi */
    case 4912:  /* *mve_vec_extract_sext_internalv4si */
    case 4911:  /* *mve_vec_extract_sext_internalv8hi */
    case 4910:  /* *mve_vec_extract_sext_internalv16qi */
    case 4909:  /* mve_vec_extractv2didi */
    case 4908:  /* mve_vec_extractv4sfsf */
    case 4907:  /* mve_vec_extractv8hfhf */
    case 4906:  /* mve_vec_extractv4sisi */
    case 4905:  /* mve_vec_extractv8hihi */
    case 4904:  /* mve_vec_extractv16qiqi */
    case 4903:  /* mve_vld4qv4sf */
    case 4902:  /* mve_vld4qv8hf */
    case 4901:  /* mve_vld4qv4si */
    case 4900:  /* mve_vld4qv8hi */
    case 4899:  /* mve_vld4qv16qi */
    case 4898:  /* mve_vld2qv4sf */
    case 4897:  /* mve_vld2qv8hf */
    case 4896:  /* mve_vld2qv4si */
    case 4895:  /* mve_vld2qv8hi */
    case 4894:  /* mve_vld2qv16qi */
    case 4893:  /* mve_vst2qv4sf */
    case 4892:  /* mve_vst2qv8hf */
    case 4891:  /* mve_vst2qv4si */
    case 4890:  /* mve_vst2qv8hi */
    case 4889:  /* mve_vst2qv16qi */
    case 4888:  /* mve_vsbcq_sv4si */
    case 4887:  /* mve_vsbcq_uv4si */
    case 4886:  /* mve_vsbcq_m_sv4si */
    case 4885:  /* mve_vsbcq_m_uv4si */
    case 4884:  /* mve_vsbciq_sv4si */
    case 4883:  /* mve_vsbciq_uv4si */
    case 4882:  /* mve_vsbciq_m_sv4si */
    case 4881:  /* mve_vsbciq_m_uv4si */
    case 4880:  /* mve_vadcq_sv4si */
    case 4879:  /* mve_vadcq_uv4si */
    case 4878:  /* mve_vadcq_m_sv4si */
    case 4877:  /* mve_vadcq_m_uv4si */
    case 4876:  /* mve_vadciq_sv4si */
    case 4875:  /* mve_vadciq_uv4si */
    case 4874:  /* mve_vadciq_m_sv4si */
    case 4873:  /* mve_vadciq_m_uv4si */
    case 4872:  /* mve_vldrdq_gather_base_wb_z_uv2di_insn */
    case 4871:  /* mve_vldrdq_gather_base_wb_z_sv2di_insn */
    case 4870:  /* set_fpscr_nzcvqc */
    case 4869:  /* get_fpscr_nzcvqc */
    case 4868:  /* mve_vldrdq_gather_base_wb_uv2di_insn */
    case 4867:  /* mve_vldrdq_gather_base_wb_sv2di_insn */
    case 4866:  /* mve_vldrwq_gather_base_wb_z_fv4sf_insn */
    case 4865:  /* mve_vldrwq_gather_base_wb_fv4sf_insn */
    case 4864:  /* mve_vldrwq_gather_base_wb_z_uv4si_insn */
    case 4863:  /* mve_vldrwq_gather_base_wb_z_sv4si_insn */
    case 4862:  /* mve_vldrwq_gather_base_wb_uv4si_insn */
    case 4861:  /* mve_vldrwq_gather_base_wb_sv4si_insn */
    case 4860:  /* mve_vstrdq_scatter_base_wb_p_uv2di */
    case 4859:  /* mve_vstrdq_scatter_base_wb_p_sv2di */
    case 4858:  /* mve_vstrdq_scatter_base_wb_uv2di */
    case 4857:  /* mve_vstrdq_scatter_base_wb_sv2di */
    case 4856:  /* mve_vstrwq_scatter_base_wb_p_fv4sf */
    case 4855:  /* mve_vstrwq_scatter_base_wb_fv4sf */
    case 4854:  /* mve_vstrwq_scatter_base_wb_p_uv4si */
    case 4853:  /* mve_vstrwq_scatter_base_wb_p_sv4si */
    case 4852:  /* mve_vstrwq_scatter_base_wb_uv4si */
    case 4851:  /* mve_vstrwq_scatter_base_wb_sv4si */
    case 4850:  /* mve_viwdupq_m_wb_uv4si_insn */
    case 4849:  /* mve_viwdupq_m_wb_uv8hi_insn */
    case 4848:  /* mve_viwdupq_m_wb_uv16qi_insn */
    case 4847:  /* mve_viwdupq_wb_uv4si_insn */
    case 4846:  /* mve_viwdupq_wb_uv8hi_insn */
    case 4845:  /* mve_viwdupq_wb_uv16qi_insn */
    case 4844:  /* mve_vdwdupq_m_wb_uv4si_insn */
    case 4843:  /* mve_vdwdupq_m_wb_uv8hi_insn */
    case 4842:  /* mve_vdwdupq_m_wb_uv16qi_insn */
    case 4841:  /* mve_vdwdupq_wb_uv4si_insn */
    case 4840:  /* mve_vdwdupq_wb_uv8hi_insn */
    case 4839:  /* mve_vdwdupq_wb_uv16qi_insn */
    case 4838:  /* mve_vddupq_m_wb_uv4si_insn */
    case 4837:  /* mve_vddupq_m_wb_uv8hi_insn */
    case 4836:  /* mve_vddupq_m_wb_uv16qi_insn */
    case 4835:  /* mve_vddupq_uv4si_insn */
    case 4834:  /* mve_vddupq_uv8hi_insn */
    case 4833:  /* mve_vddupq_uv16qi_insn */
    case 4832:  /* mve_vidupq_m_wb_uv4si_insn */
    case 4831:  /* mve_vidupq_m_wb_uv8hi_insn */
    case 4830:  /* mve_vidupq_m_wb_uv16qi_insn */
    case 4829:  /* mve_vidupq_uv4si_insn */
    case 4828:  /* mve_vidupq_uv8hi_insn */
    case 4827:  /* mve_vidupq_uv16qi_insn */
    case 4826:  /* mve_vaddq_fv4sf */
    case 4825:  /* mve_vaddq_fv8hf */
    case 4824:  /* mve_vaddqv4si */
    case 4823:  /* mve_vaddqv8hi */
    case 4822:  /* mve_vaddqv16qi */
    case 4821:  /* mve_vstrwq_scatter_shifted_offset_uv4si_insn */
    case 4820:  /* mve_vstrwq_scatter_shifted_offset_sv4si_insn */
    case 4819:  /* mve_vstrwq_scatter_shifted_offset_p_uv4si_insn */
    case 4818:  /* mve_vstrwq_scatter_shifted_offset_p_sv4si_insn */
    case 4817:  /* mve_vstrwq_scatter_shifted_offset_p_fv4sf_insn */
    case 4816:  /* mve_vstrwq_scatter_shifted_offset_fv4sf_insn */
    case 4815:  /* mve_vstrwq_scatter_offset_uv4si_insn */
    case 4814:  /* mve_vstrwq_scatter_offset_sv4si_insn */
    case 4813:  /* mve_vstrwq_scatter_offset_p_uv4si_insn */
    case 4812:  /* mve_vstrwq_scatter_offset_p_sv4si_insn */
    case 4811:  /* mve_vstrwq_scatter_offset_p_fv4sf_insn */
    case 4810:  /* mve_vstrwq_scatter_offset_fv4sf_insn */
    case 4809:  /* mve_vstrwq_scatter_base_p_fv4sf */
    case 4808:  /* mve_vstrwq_scatter_base_fv4sf */
    case 4807:  /* mve_vstrhq_scatter_shifted_offset_p_fv8hf_insn */
    case 4806:  /* mve_vstrhq_scatter_shifted_offset_fv8hf_insn */
    case 4805:  /* mve_vstrhq_scatter_offset_p_fv8hf_insn */
    case 4804:  /* mve_vstrhq_scatter_offset_fv8hf_insn */
    case 4803:  /* mve_vstrdq_scatter_shifted_offset_uv2di_insn */
    case 4802:  /* mve_vstrdq_scatter_shifted_offset_sv2di_insn */
    case 4801:  /* mve_vstrdq_scatter_shifted_offset_p_uv2di_insn */
    case 4800:  /* mve_vstrdq_scatter_shifted_offset_p_sv2di_insn */
    case 4799:  /* mve_vstrdq_scatter_offset_uv2di_insn */
    case 4798:  /* mve_vstrdq_scatter_offset_sv2di_insn */
    case 4797:  /* mve_vstrdq_scatter_offset_p_uv2di_insn */
    case 4796:  /* mve_vstrdq_scatter_offset_p_sv2di_insn */
    case 4795:  /* mve_vstrdq_scatter_base_uv2di */
    case 4794:  /* mve_vstrdq_scatter_base_sv2di */
    case 4793:  /* mve_vstrdq_scatter_base_p_uv2di */
    case 4792:  /* mve_vstrdq_scatter_base_p_sv2di */
    case 4791:  /* mve_vstrwq_uv4si */
    case 4790:  /* mve_vstrwq_sv4si */
    case 4789:  /* mve_vstrwq_p_uv4si */
    case 4788:  /* mve_vstrwq_p_sv4si */
    case 4787:  /* mve_vstrwq_p_fv4sf */
    case 4786:  /* mve_vstrwq_fv4sf */
    case 4785:  /* mve_vstrhq_uv4si */
    case 4784:  /* mve_vstrhq_sv4si */
    case 4783:  /* mve_vstrhq_uv8hi */
    case 4782:  /* mve_vstrhq_sv8hi */
    case 4781:  /* mve_vstrhq_scatter_shifted_offset_uv4si_insn */
    case 4780:  /* mve_vstrhq_scatter_shifted_offset_sv4si_insn */
    case 4779:  /* mve_vstrhq_scatter_shifted_offset_uv8hi_insn */
    case 4778:  /* mve_vstrhq_scatter_shifted_offset_sv8hi_insn */
    case 4777:  /* mve_vstrhq_scatter_shifted_offset_p_uv4si_insn */
    case 4776:  /* mve_vstrhq_scatter_shifted_offset_p_sv4si_insn */
    case 4775:  /* mve_vstrhq_scatter_shifted_offset_p_uv8hi_insn */
    case 4774:  /* mve_vstrhq_scatter_shifted_offset_p_sv8hi_insn */
    case 4773:  /* mve_vstrhq_scatter_offset_uv4si_insn */
    case 4772:  /* mve_vstrhq_scatter_offset_sv4si_insn */
    case 4771:  /* mve_vstrhq_scatter_offset_uv8hi_insn */
    case 4770:  /* mve_vstrhq_scatter_offset_sv8hi_insn */
    case 4769:  /* mve_vstrhq_scatter_offset_p_uv4si_insn */
    case 4768:  /* mve_vstrhq_scatter_offset_p_sv4si_insn */
    case 4767:  /* mve_vstrhq_scatter_offset_p_uv8hi_insn */
    case 4766:  /* mve_vstrhq_scatter_offset_p_sv8hi_insn */
    case 4765:  /* mve_vstrhq_p_uv4si */
    case 4764:  /* mve_vstrhq_p_sv4si */
    case 4763:  /* mve_vstrhq_p_uv8hi */
    case 4762:  /* mve_vstrhq_p_sv8hi */
    case 4761:  /* mve_vstrhq_p_fv8hf */
    case 4760:  /* mve_vstrhq_fv8hf */
    case 4759:  /* mve_vldrwq_gather_shifted_offset_z_uv4si */
    case 4758:  /* mve_vldrwq_gather_shifted_offset_z_sv4si */
    case 4757:  /* mve_vldrwq_gather_shifted_offset_z_fv4sf */
    case 4756:  /* mve_vldrwq_gather_shifted_offset_uv4si */
    case 4755:  /* mve_vldrwq_gather_shifted_offset_sv4si */
    case 4754:  /* mve_vldrwq_gather_shifted_offset_fv4sf */
    case 4753:  /* mve_vldrwq_gather_offset_z_uv4si */
    case 4752:  /* mve_vldrwq_gather_offset_z_sv4si */
    case 4751:  /* mve_vldrwq_gather_offset_z_fv4sf */
    case 4750:  /* mve_vldrwq_gather_offset_uv4si */
    case 4749:  /* mve_vldrwq_gather_offset_sv4si */
    case 4748:  /* mve_vldrwq_gather_offset_fv4sf */
    case 4747:  /* mve_vldrwq_gather_base_z_fv4sf */
    case 4746:  /* mve_vldrwq_gather_base_fv4sf */
    case 4745:  /* mve_vldrhq_gather_shifted_offset_z_fv8hf */
    case 4744:  /* mve_vldrhq_gather_shifted_offset_fv8hf */
    case 4743:  /* mve_vldrhq_gather_offset_z_fv8hf */
    case 4742:  /* mve_vldrhq_gather_offset_fv8hf */
    case 4741:  /* mve_vldrdq_gather_shifted_offset_z_uv2di */
    case 4740:  /* mve_vldrdq_gather_shifted_offset_z_sv2di */
    case 4739:  /* mve_vldrdq_gather_shifted_offset_uv2di */
    case 4738:  /* mve_vldrdq_gather_shifted_offset_sv2di */
    case 4737:  /* mve_vldrdq_gather_offset_z_uv2di */
    case 4736:  /* mve_vldrdq_gather_offset_z_sv2di */
    case 4735:  /* mve_vldrdq_gather_offset_uv2di */
    case 4734:  /* mve_vldrdq_gather_offset_sv2di */
    case 4733:  /* mve_vldrdq_gather_base_z_uv2di */
    case 4732:  /* mve_vldrdq_gather_base_z_sv2di */
    case 4731:  /* mve_vldrdq_gather_base_uv2di */
    case 4730:  /* mve_vldrdq_gather_base_sv2di */
    case 4729:  /* mve_vldrwq_z_uv4si */
    case 4728:  /* mve_vldrwq_z_sv4si */
    case 4727:  /* mve_vldrwq_z_fv4sf */
    case 4726:  /* mve_vldrwq_uv4si */
    case 4725:  /* mve_vldrwq_sv4si */
    case 4724:  /* mve_vldrwq_fv4sf */
    case 4723:  /* mve_vldrhq_z_uv4si */
    case 4722:  /* mve_vldrhq_z_sv4si */
    case 4721:  /* mve_vldrhq_z_uv8hi */
    case 4720:  /* mve_vldrhq_z_sv8hi */
    case 4719:  /* mve_vldrhq_z_fv8hf */
    case 4718:  /* mve_vldrhq_uv4si */
    case 4717:  /* mve_vldrhq_sv4si */
    case 4716:  /* mve_vldrhq_uv8hi */
    case 4715:  /* mve_vldrhq_sv8hi */
    case 4714:  /* mve_vldrhq_gather_shifted_offset_z_uv4si */
    case 4713:  /* mve_vldrhq_gather_shifted_offset_z_sv4si */
    case 4712:  /* mve_vldrhq_gather_shifted_offset_z_uv8hi */
    case 4711:  /* mve_vldrhq_gather_shifted_offset_z_sv8hi */
    case 4710:  /* mve_vldrhq_gather_shifted_offset_uv4si */
    case 4709:  /* mve_vldrhq_gather_shifted_offset_sv4si */
    case 4708:  /* mve_vldrhq_gather_shifted_offset_uv8hi */
    case 4707:  /* mve_vldrhq_gather_shifted_offset_sv8hi */
    case 4706:  /* mve_vldrhq_gather_offset_z_uv4si */
    case 4705:  /* mve_vldrhq_gather_offset_z_sv4si */
    case 4704:  /* mve_vldrhq_gather_offset_z_uv8hi */
    case 4703:  /* mve_vldrhq_gather_offset_z_sv8hi */
    case 4702:  /* mve_vldrhq_gather_offset_uv4si */
    case 4701:  /* mve_vldrhq_gather_offset_sv4si */
    case 4700:  /* mve_vldrhq_gather_offset_uv8hi */
    case 4699:  /* mve_vldrhq_gather_offset_sv8hi */
    case 4698:  /* mve_vldrhq_fv8hf */
    case 4697:  /* mve_vldrwq_gather_base_z_uv4si */
    case 4696:  /* mve_vldrwq_gather_base_z_sv4si */
    case 4695:  /* mve_vldrbq_z_uv4si */
    case 4694:  /* mve_vldrbq_z_sv4si */
    case 4693:  /* mve_vldrbq_z_uv8hi */
    case 4692:  /* mve_vldrbq_z_sv8hi */
    case 4691:  /* mve_vldrbq_z_uv16qi */
    case 4690:  /* mve_vldrbq_z_sv16qi */
    case 4689:  /* mve_vldrbq_gather_offset_z_uv4si */
    case 4688:  /* mve_vldrbq_gather_offset_z_sv4si */
    case 4687:  /* mve_vldrbq_gather_offset_z_uv8hi */
    case 4686:  /* mve_vldrbq_gather_offset_z_sv8hi */
    case 4685:  /* mve_vldrbq_gather_offset_z_uv16qi */
    case 4684:  /* mve_vldrbq_gather_offset_z_sv16qi */
    case 4683:  /* mve_vstrbq_p_uv4si */
    case 4682:  /* mve_vstrbq_p_sv4si */
    case 4681:  /* mve_vstrbq_p_uv8hi */
    case 4680:  /* mve_vstrbq_p_sv8hi */
    case 4679:  /* mve_vstrbq_p_uv16qi */
    case 4678:  /* mve_vstrbq_p_sv16qi */
    case 4677:  /* mve_vstrwq_scatter_base_p_uv4si */
    case 4676:  /* mve_vstrwq_scatter_base_p_sv4si */
    case 4675:  /* mve_vstrbq_scatter_offset_p_uv4si_insn */
    case 4674:  /* mve_vstrbq_scatter_offset_p_sv4si_insn */
    case 4673:  /* mve_vstrbq_scatter_offset_p_uv8hi_insn */
    case 4672:  /* mve_vstrbq_scatter_offset_p_sv8hi_insn */
    case 4671:  /* mve_vstrbq_scatter_offset_p_uv16qi_insn */
    case 4670:  /* mve_vstrbq_scatter_offset_p_sv16qi_insn */
    case 4669:  /* mve_vldrwq_gather_base_uv4si */
    case 4668:  /* mve_vldrwq_gather_base_sv4si */
    case 4667:  /* mve_vldrbq_uv4si */
    case 4666:  /* mve_vldrbq_sv4si */
    case 4665:  /* mve_vldrbq_uv8hi */
    case 4664:  /* mve_vldrbq_sv8hi */
    case 4663:  /* mve_vldrbq_uv16qi */
    case 4662:  /* mve_vldrbq_sv16qi */
    case 4661:  /* mve_vldrbq_gather_offset_uv4si */
    case 4660:  /* mve_vldrbq_gather_offset_sv4si */
    case 4659:  /* mve_vldrbq_gather_offset_uv8hi */
    case 4658:  /* mve_vldrbq_gather_offset_sv8hi */
    case 4657:  /* mve_vldrbq_gather_offset_uv16qi */
    case 4656:  /* mve_vldrbq_gather_offset_sv16qi */
    case 4655:  /* mve_vstrwq_scatter_base_uv4si */
    case 4654:  /* mve_vstrwq_scatter_base_sv4si */
    case 4653:  /* mve_vstrbq_scatter_offset_uv4si_insn */
    case 4652:  /* mve_vstrbq_scatter_offset_sv4si_insn */
    case 4651:  /* mve_vstrbq_scatter_offset_uv8hi_insn */
    case 4650:  /* mve_vstrbq_scatter_offset_sv8hi_insn */
    case 4649:  /* mve_vstrbq_scatter_offset_uv16qi_insn */
    case 4648:  /* mve_vstrbq_scatter_offset_sv16qi_insn */
    case 4647:  /* mve_vstrbq_uv4si */
    case 4646:  /* mve_vstrbq_sv4si */
    case 4645:  /* mve_vstrbq_uv8hi */
    case 4644:  /* mve_vstrbq_sv8hi */
    case 4643:  /* mve_vstrbq_uv16qi */
    case 4642:  /* mve_vstrbq_sv16qi */
    case 4641:  /* mve_vsubq_m_n_fv4sf */
    case 4640:  /* mve_vsubq_m_n_fv8hf */
    case 4639:  /* mve_vsubq_m_fv4sf */
    case 4638:  /* mve_vsubq_m_fv8hf */
    case 4637:  /* mve_vorrq_m_fv4sf */
    case 4636:  /* mve_vorrq_m_fv8hf */
    case 4635:  /* mve_vornq_m_fv4sf */
    case 4634:  /* mve_vornq_m_fv8hf */
    case 4633:  /* mve_vmulq_m_n_fv4sf */
    case 4632:  /* mve_vmulq_m_n_fv8hf */
    case 4631:  /* mve_vmulq_m_fv4sf */
    case 4630:  /* mve_vmulq_m_fv8hf */
    case 4629:  /* mve_vminnmq_m_fv4sf */
    case 4628:  /* mve_vminnmq_m_fv8hf */
    case 4627:  /* mve_vmaxnmq_m_fv4sf */
    case 4626:  /* mve_vmaxnmq_m_fv8hf */
    case 4625:  /* mve_vfmsq_m_fv4sf */
    case 4624:  /* mve_vfmsq_m_fv8hf */
    case 4623:  /* mve_vfmasq_m_n_fv4sf */
    case 4622:  /* mve_vfmasq_m_n_fv8hf */
    case 4621:  /* mve_vfmaq_m_n_fv4sf */
    case 4620:  /* mve_vfmaq_m_n_fv8hf */
    case 4619:  /* mve_vfmaq_m_fv4sf */
    case 4618:  /* mve_vfmaq_m_fv8hf */
    case 4617:  /* mve_veorq_m_fv4sf */
    case 4616:  /* mve_veorq_m_fv8hf */
    case 4615:  /* mve_vcmulq_rot90_m_fv4sf */
    case 4614:  /* mve_vcmulq_rot90_m_fv8hf */
    case 4613:  /* mve_vcmulq_rot270_m_fv4sf */
    case 4612:  /* mve_vcmulq_rot270_m_fv8hf */
    case 4611:  /* mve_vcmulq_rot180_m_fv4sf */
    case 4610:  /* mve_vcmulq_rot180_m_fv8hf */
    case 4609:  /* mve_vcmulq_m_fv4sf */
    case 4608:  /* mve_vcmulq_m_fv8hf */
    case 4607:  /* mve_vcmlaq_rot90_m_fv4sf */
    case 4606:  /* mve_vcmlaq_rot90_m_fv8hf */
    case 4605:  /* mve_vcmlaq_rot270_m_fv4sf */
    case 4604:  /* mve_vcmlaq_rot270_m_fv8hf */
    case 4603:  /* mve_vcmlaq_rot180_m_fv4sf */
    case 4602:  /* mve_vcmlaq_rot180_m_fv8hf */
    case 4601:  /* mve_vcmlaq_m_fv4sf */
    case 4600:  /* mve_vcmlaq_m_fv8hf */
    case 4599:  /* mve_vcaddq_rot90_m_fv4sf */
    case 4598:  /* mve_vcaddq_rot90_m_fv8hf */
    case 4597:  /* mve_vcaddq_rot270_m_fv4sf */
    case 4596:  /* mve_vcaddq_rot270_m_fv8hf */
    case 4595:  /* mve_vbrsrq_m_n_fv4sf */
    case 4594:  /* mve_vbrsrq_m_n_fv8hf */
    case 4593:  /* mve_vbicq_m_fv4sf */
    case 4592:  /* mve_vbicq_m_fv8hf */
    case 4591:  /* mve_vandq_m_fv4sf */
    case 4590:  /* mve_vandq_m_fv8hf */
    case 4589:  /* mve_vaddq_m_n_fv4sf */
    case 4588:  /* mve_vaddq_m_n_fv8hf */
    case 4587:  /* mve_vaddq_m_fv4sf */
    case 4586:  /* mve_vaddq_m_fv8hf */
    case 4585:  /* mve_vabdq_m_fv4sf */
    case 4584:  /* mve_vabdq_m_fv8hf */
    case 4583:  /* mve_vrmlsldavhaxq_p_sv4si */
    case 4582:  /* mve_vrmlsldavhaq_p_sv4si */
    case 4581:  /* mve_vrmlaldavhaxq_p_sv4si */
    case 4580:  /* mve_vrmlaldavhaq_p_uv4si */
    case 4579:  /* mve_vqshruntq_m_n_sv4si */
    case 4578:  /* mve_vqshruntq_m_n_sv8hi */
    case 4577:  /* mve_vqshrunbq_m_n_sv4si */
    case 4576:  /* mve_vqshrunbq_m_n_sv8hi */
    case 4575:  /* mve_vqrshruntq_m_n_sv4si */
    case 4574:  /* mve_vqrshruntq_m_n_sv8hi */
    case 4573:  /* mve_vqrshrunbq_m_n_sv4si */
    case 4572:  /* mve_vqrshrunbq_m_n_sv8hi */
    case 4571:  /* mve_vqdmulltq_m_sv4si */
    case 4570:  /* mve_vqdmulltq_m_sv8hi */
    case 4569:  /* mve_vqdmulltq_m_n_sv4si */
    case 4568:  /* mve_vqdmulltq_m_n_sv8hi */
    case 4567:  /* mve_vqdmullbq_m_sv4si */
    case 4566:  /* mve_vqdmullbq_m_sv8hi */
    case 4565:  /* mve_vqdmullbq_m_n_sv4si */
    case 4564:  /* mve_vqdmullbq_m_n_sv8hi */
    case 4563:  /* mve_vmulltq_poly_m_pv8hi */
    case 4562:  /* mve_vmulltq_poly_m_pv16qi */
    case 4561:  /* mve_vmullbq_poly_m_pv8hi */
    case 4560:  /* mve_vmullbq_poly_m_pv16qi */
    case 4559:  /* mve_vmlsldavaxq_p_sv4si */
    case 4558:  /* mve_vmlsldavaxq_p_sv8hi */
    case 4557:  /* mve_vmlsldavaq_p_sv4si */
    case 4556:  /* mve_vmlsldavaq_p_sv8hi */
    case 4555:  /* mve_vshrntq_m_n_uv4si */
    case 4554:  /* mve_vshrntq_m_n_sv4si */
    case 4553:  /* mve_vshrntq_m_n_uv8hi */
    case 4552:  /* mve_vshrntq_m_n_sv8hi */
    case 4551:  /* mve_vshrnbq_m_n_uv4si */
    case 4550:  /* mve_vshrnbq_m_n_sv4si */
    case 4549:  /* mve_vshrnbq_m_n_uv8hi */
    case 4548:  /* mve_vshrnbq_m_n_sv8hi */
    case 4547:  /* mve_vshlltq_m_n_sv8hi */
    case 4546:  /* mve_vshlltq_m_n_uv8hi */
    case 4545:  /* mve_vshlltq_m_n_sv16qi */
    case 4544:  /* mve_vshlltq_m_n_uv16qi */
    case 4543:  /* mve_vshllbq_m_n_sv8hi */
    case 4542:  /* mve_vshllbq_m_n_uv8hi */
    case 4541:  /* mve_vshllbq_m_n_sv16qi */
    case 4540:  /* mve_vshllbq_m_n_uv16qi */
    case 4539:  /* mve_vrshrntq_m_n_sv4si */
    case 4538:  /* mve_vrshrntq_m_n_uv4si */
    case 4537:  /* mve_vrshrntq_m_n_sv8hi */
    case 4536:  /* mve_vrshrntq_m_n_uv8hi */
    case 4535:  /* mve_vrshrnbq_m_n_sv4si */
    case 4534:  /* mve_vrshrnbq_m_n_uv4si */
    case 4533:  /* mve_vrshrnbq_m_n_sv8hi */
    case 4532:  /* mve_vrshrnbq_m_n_uv8hi */
    case 4531:  /* mve_vrmlaldavhaq_p_sv4si */
    case 4530:  /* mve_vqshrntq_m_n_uv4si */
    case 4529:  /* mve_vqshrntq_m_n_sv4si */
    case 4528:  /* mve_vqshrntq_m_n_uv8hi */
    case 4527:  /* mve_vqshrntq_m_n_sv8hi */
    case 4526:  /* mve_vqshrnbq_m_n_sv4si */
    case 4525:  /* mve_vqshrnbq_m_n_uv4si */
    case 4524:  /* mve_vqshrnbq_m_n_sv8hi */
    case 4523:  /* mve_vqshrnbq_m_n_uv8hi */
    case 4522:  /* mve_vqrshrntq_m_n_uv4si */
    case 4521:  /* mve_vqrshrntq_m_n_sv4si */
    case 4520:  /* mve_vqrshrntq_m_n_uv8hi */
    case 4519:  /* mve_vqrshrntq_m_n_sv8hi */
    case 4518:  /* mve_vqrshrnbq_m_n_sv4si */
    case 4517:  /* mve_vqrshrnbq_m_n_uv4si */
    case 4516:  /* mve_vqrshrnbq_m_n_sv8hi */
    case 4515:  /* mve_vqrshrnbq_m_n_uv8hi */
    case 4514:  /* mve_vmlaldavaxq_p_sv4si */
    case 4513:  /* mve_vmlaldavaxq_p_sv8hi */
    case 4512:  /* mve_vmlaldavaq_p_sv4si */
    case 4511:  /* mve_vmlaldavaq_p_uv4si */
    case 4510:  /* mve_vmlaldavaq_p_sv8hi */
    case 4509:  /* mve_vmlaldavaq_p_uv8hi */
    case 4508:  /* mve_vqrdmulhq_m_sv4si */
    case 4507:  /* mve_vqrdmulhq_m_sv8hi */
    case 4506:  /* mve_vqrdmulhq_m_sv16qi */
    case 4505:  /* mve_vqrdmulhq_m_n_sv4si */
    case 4504:  /* mve_vqrdmulhq_m_n_sv8hi */
    case 4503:  /* mve_vqrdmulhq_m_n_sv16qi */
    case 4502:  /* mve_vqrdmlsdhxq_m_sv4si */
    case 4501:  /* mve_vqrdmlsdhxq_m_sv8hi */
    case 4500:  /* mve_vqrdmlsdhxq_m_sv16qi */
    case 4499:  /* mve_vqrdmlsdhq_m_sv4si */
    case 4498:  /* mve_vqrdmlsdhq_m_sv8hi */
    case 4497:  /* mve_vqrdmlsdhq_m_sv16qi */
    case 4496:  /* mve_vqrdmladhxq_m_sv4si */
    case 4495:  /* mve_vqrdmladhxq_m_sv8hi */
    case 4494:  /* mve_vqrdmladhxq_m_sv16qi */
    case 4493:  /* mve_vqrdmladhq_m_sv4si */
    case 4492:  /* mve_vqrdmladhq_m_sv8hi */
    case 4491:  /* mve_vqrdmladhq_m_sv16qi */
    case 4490:  /* mve_vqdmulhq_m_sv4si */
    case 4489:  /* mve_vqdmulhq_m_sv8hi */
    case 4488:  /* mve_vqdmulhq_m_sv16qi */
    case 4487:  /* mve_vqdmulhq_m_n_sv4si */
    case 4486:  /* mve_vqdmulhq_m_n_sv8hi */
    case 4485:  /* mve_vqdmulhq_m_n_sv16qi */
    case 4484:  /* mve_vqdmlsdhxq_m_sv4si */
    case 4483:  /* mve_vqdmlsdhxq_m_sv8hi */
    case 4482:  /* mve_vqdmlsdhxq_m_sv16qi */
    case 4481:  /* mve_vqdmlsdhq_m_sv4si */
    case 4480:  /* mve_vqdmlsdhq_m_sv8hi */
    case 4479:  /* mve_vqdmlsdhq_m_sv16qi */
    case 4478:  /* mve_vqdmladhxq_m_sv4si */
    case 4477:  /* mve_vqdmladhxq_m_sv8hi */
    case 4476:  /* mve_vqdmladhxq_m_sv16qi */
    case 4475:  /* mve_vqdmladhq_m_sv4si */
    case 4474:  /* mve_vqdmladhq_m_sv8hi */
    case 4473:  /* mve_vqdmladhq_m_sv16qi */
    case 4472:  /* mve_vmlsdavaxq_p_sv4si */
    case 4471:  /* mve_vmlsdavaxq_p_sv8hi */
    case 4470:  /* mve_vmlsdavaxq_p_sv16qi */
    case 4469:  /* mve_vmlsdavaq_p_sv4si */
    case 4468:  /* mve_vmlsdavaq_p_sv8hi */
    case 4467:  /* mve_vmlsdavaq_p_sv16qi */
    case 4466:  /* mve_vmladavaxq_p_sv4si */
    case 4465:  /* mve_vmladavaxq_p_sv8hi */
    case 4464:  /* mve_vmladavaxq_p_sv16qi */
    case 4463:  /* mve_vhcaddq_rot90_m_sv4si */
    case 4462:  /* mve_vhcaddq_rot90_m_sv8hi */
    case 4461:  /* mve_vhcaddq_rot90_m_sv16qi */
    case 4460:  /* mve_vhcaddq_rot270_m_sv4si */
    case 4459:  /* mve_vhcaddq_rot270_m_sv8hi */
    case 4458:  /* mve_vhcaddq_rot270_m_sv16qi */
    case 4457:  /* mve_vsubq_m_n_uv4si */
    case 4456:  /* mve_vsubq_m_n_sv4si */
    case 4455:  /* mve_vsubq_m_n_uv8hi */
    case 4454:  /* mve_vsubq_m_n_sv8hi */
    case 4453:  /* mve_vsubq_m_n_uv16qi */
    case 4452:  /* mve_vsubq_m_n_sv16qi */
    case 4451:  /* mve_vsliq_m_n_sv4si */
    case 4450:  /* mve_vsliq_m_n_uv4si */
    case 4449:  /* mve_vsliq_m_n_sv8hi */
    case 4448:  /* mve_vsliq_m_n_uv8hi */
    case 4447:  /* mve_vsliq_m_n_sv16qi */
    case 4446:  /* mve_vsliq_m_n_uv16qi */
    case 4445:  /* mve_vshrq_m_n_uv4si */
    case 4444:  /* mve_vshrq_m_n_sv4si */
    case 4443:  /* mve_vshrq_m_n_uv8hi */
    case 4442:  /* mve_vshrq_m_n_sv8hi */
    case 4441:  /* mve_vshrq_m_n_uv16qi */
    case 4440:  /* mve_vshrq_m_n_sv16qi */
    case 4439:  /* mve_vshlq_m_n_uv4si */
    case 4438:  /* mve_vshlq_m_n_sv4si */
    case 4437:  /* mve_vshlq_m_n_uv8hi */
    case 4436:  /* mve_vshlq_m_n_sv8hi */
    case 4435:  /* mve_vshlq_m_n_uv16qi */
    case 4434:  /* mve_vshlq_m_n_sv16qi */
    case 4433:  /* mve_vrshrq_m_n_uv4si */
    case 4432:  /* mve_vrshrq_m_n_sv4si */
    case 4431:  /* mve_vrshrq_m_n_uv8hi */
    case 4430:  /* mve_vrshrq_m_n_sv8hi */
    case 4429:  /* mve_vrshrq_m_n_uv16qi */
    case 4428:  /* mve_vrshrq_m_n_sv16qi */
    case 4427:  /* mve_vrshlq_m_uv4si */
    case 4426:  /* mve_vrshlq_m_sv4si */
    case 4425:  /* mve_vrshlq_m_uv8hi */
    case 4424:  /* mve_vrshlq_m_sv8hi */
    case 4423:  /* mve_vrshlq_m_uv16qi */
    case 4422:  /* mve_vrshlq_m_sv16qi */
    case 4421:  /* mve_vrmulhq_m_sv4si */
    case 4420:  /* mve_vrmulhq_m_uv4si */
    case 4419:  /* mve_vrmulhq_m_sv8hi */
    case 4418:  /* mve_vrmulhq_m_uv8hi */
    case 4417:  /* mve_vrmulhq_m_sv16qi */
    case 4416:  /* mve_vrmulhq_m_uv16qi */
    case 4415:  /* mve_vrhaddq_m_sv4si */
    case 4414:  /* mve_vrhaddq_m_uv4si */
    case 4413:  /* mve_vrhaddq_m_sv8hi */
    case 4412:  /* mve_vrhaddq_m_uv8hi */
    case 4411:  /* mve_vrhaddq_m_sv16qi */
    case 4410:  /* mve_vrhaddq_m_uv16qi */
    case 4409:  /* mve_vqsubq_m_sv4si */
    case 4408:  /* mve_vqsubq_m_uv4si */
    case 4407:  /* mve_vqsubq_m_sv8hi */
    case 4406:  /* mve_vqsubq_m_uv8hi */
    case 4405:  /* mve_vqsubq_m_sv16qi */
    case 4404:  /* mve_vqsubq_m_uv16qi */
    case 4403:  /* mve_vqsubq_m_n_sv4si */
    case 4402:  /* mve_vqsubq_m_n_uv4si */
    case 4401:  /* mve_vqsubq_m_n_sv8hi */
    case 4400:  /* mve_vqsubq_m_n_uv8hi */
    case 4399:  /* mve_vqsubq_m_n_sv16qi */
    case 4398:  /* mve_vqsubq_m_n_uv16qi */
    case 4397:  /* mve_vqshlq_m_sv4si */
    case 4396:  /* mve_vqshlq_m_uv4si */
    case 4395:  /* mve_vqshlq_m_sv8hi */
    case 4394:  /* mve_vqshlq_m_uv8hi */
    case 4393:  /* mve_vqshlq_m_sv16qi */
    case 4392:  /* mve_vqshlq_m_uv16qi */
    case 4391:  /* mve_vqshlq_m_n_uv4si */
    case 4390:  /* mve_vqshlq_m_n_sv4si */
    case 4389:  /* mve_vqshlq_m_n_uv8hi */
    case 4388:  /* mve_vqshlq_m_n_sv8hi */
    case 4387:  /* mve_vqshlq_m_n_uv16qi */
    case 4386:  /* mve_vqshlq_m_n_sv16qi */
    case 4385:  /* mve_vqrshlq_m_sv4si */
    case 4384:  /* mve_vqrshlq_m_uv4si */
    case 4383:  /* mve_vqrshlq_m_sv8hi */
    case 4382:  /* mve_vqrshlq_m_uv8hi */
    case 4381:  /* mve_vqrshlq_m_sv16qi */
    case 4380:  /* mve_vqrshlq_m_uv16qi */
    case 4379:  /* mve_vqrdmlashq_m_n_sv4si */
    case 4378:  /* mve_vqrdmlashq_m_n_sv8hi */
    case 4377:  /* mve_vqrdmlashq_m_n_sv16qi */
    case 4376:  /* mve_vqrdmlahq_m_n_sv4si */
    case 4375:  /* mve_vqrdmlahq_m_n_sv8hi */
    case 4374:  /* mve_vqrdmlahq_m_n_sv16qi */
    case 4373:  /* mve_vqdmlashq_m_n_sv4si */
    case 4372:  /* mve_vqdmlashq_m_n_sv8hi */
    case 4371:  /* mve_vqdmlashq_m_n_sv16qi */
    case 4370:  /* mve_vqdmlahq_m_n_sv4si */
    case 4369:  /* mve_vqdmlahq_m_n_sv8hi */
    case 4368:  /* mve_vqdmlahq_m_n_sv16qi */
    case 4367:  /* mve_vqaddq_m_sv4si */
    case 4366:  /* mve_vqaddq_m_uv4si */
    case 4365:  /* mve_vqaddq_m_sv8hi */
    case 4364:  /* mve_vqaddq_m_uv8hi */
    case 4363:  /* mve_vqaddq_m_sv16qi */
    case 4362:  /* mve_vqaddq_m_uv16qi */
    case 4361:  /* mve_vqaddq_m_n_sv4si */
    case 4360:  /* mve_vqaddq_m_n_uv4si */
    case 4359:  /* mve_vqaddq_m_n_sv8hi */
    case 4358:  /* mve_vqaddq_m_n_uv8hi */
    case 4357:  /* mve_vqaddq_m_n_sv16qi */
    case 4356:  /* mve_vqaddq_m_n_uv16qi */
    case 4355:  /* mve_vorrq_m_uv4si */
    case 4354:  /* mve_vorrq_m_sv4si */
    case 4353:  /* mve_vorrq_m_uv8hi */
    case 4352:  /* mve_vorrq_m_sv8hi */
    case 4351:  /* mve_vorrq_m_uv16qi */
    case 4350:  /* mve_vorrq_m_sv16qi */
    case 4349:  /* mve_vornq_m_sv4si */
    case 4348:  /* mve_vornq_m_uv4si */
    case 4347:  /* mve_vornq_m_sv8hi */
    case 4346:  /* mve_vornq_m_uv8hi */
    case 4345:  /* mve_vornq_m_sv16qi */
    case 4344:  /* mve_vornq_m_uv16qi */
    case 4343:  /* mve_vmulq_m_uv4si */
    case 4342:  /* mve_vmulq_m_sv4si */
    case 4341:  /* mve_vmulq_m_uv8hi */
    case 4340:  /* mve_vmulq_m_sv8hi */
    case 4339:  /* mve_vmulq_m_uv16qi */
    case 4338:  /* mve_vmulq_m_sv16qi */
    case 4337:  /* mve_vmulq_m_n_sv4si */
    case 4336:  /* mve_vmulq_m_n_uv4si */
    case 4335:  /* mve_vmulq_m_n_sv8hi */
    case 4334:  /* mve_vmulq_m_n_uv8hi */
    case 4333:  /* mve_vmulq_m_n_sv16qi */
    case 4332:  /* mve_vmulq_m_n_uv16qi */
    case 4331:  /* mve_vmulltq_int_m_uv4si */
    case 4330:  /* mve_vmulltq_int_m_sv4si */
    case 4329:  /* mve_vmulltq_int_m_uv8hi */
    case 4328:  /* mve_vmulltq_int_m_sv8hi */
    case 4327:  /* mve_vmulltq_int_m_uv16qi */
    case 4326:  /* mve_vmulltq_int_m_sv16qi */
    case 4325:  /* mve_vmullbq_int_m_sv4si */
    case 4324:  /* mve_vmullbq_int_m_uv4si */
    case 4323:  /* mve_vmullbq_int_m_sv8hi */
    case 4322:  /* mve_vmullbq_int_m_uv8hi */
    case 4321:  /* mve_vmullbq_int_m_sv16qi */
    case 4320:  /* mve_vmullbq_int_m_uv16qi */
    case 4319:  /* mve_vmulhq_m_uv4si */
    case 4318:  /* mve_vmulhq_m_sv4si */
    case 4317:  /* mve_vmulhq_m_uv8hi */
    case 4316:  /* mve_vmulhq_m_sv8hi */
    case 4315:  /* mve_vmulhq_m_uv16qi */
    case 4314:  /* mve_vmulhq_m_sv16qi */
    case 4313:  /* mve_vmlasq_m_n_sv4si */
    case 4312:  /* mve_vmlasq_m_n_uv4si */
    case 4311:  /* mve_vmlasq_m_n_sv8hi */
    case 4310:  /* mve_vmlasq_m_n_uv8hi */
    case 4309:  /* mve_vmlasq_m_n_sv16qi */
    case 4308:  /* mve_vmlasq_m_n_uv16qi */
    case 4307:  /* mve_vmlaq_m_n_uv4si */
    case 4306:  /* mve_vmlaq_m_n_sv4si */
    case 4305:  /* mve_vmlaq_m_n_uv8hi */
    case 4304:  /* mve_vmlaq_m_n_sv8hi */
    case 4303:  /* mve_vmlaq_m_n_uv16qi */
    case 4302:  /* mve_vmlaq_m_n_sv16qi */
    case 4301:  /* mve_vmladavaq_p_sv4si */
    case 4300:  /* mve_vmladavaq_p_uv4si */
    case 4299:  /* mve_vmladavaq_p_sv8hi */
    case 4298:  /* mve_vmladavaq_p_uv8hi */
    case 4297:  /* mve_vmladavaq_p_sv16qi */
    case 4296:  /* mve_vmladavaq_p_uv16qi */
    case 4295:  /* mve_vminq_m_uv4si */
    case 4294:  /* mve_vminq_m_sv4si */
    case 4293:  /* mve_vminq_m_uv8hi */
    case 4292:  /* mve_vminq_m_sv8hi */
    case 4291:  /* mve_vminq_m_uv16qi */
    case 4290:  /* mve_vminq_m_sv16qi */
    case 4289:  /* mve_vmaxq_m_uv4si */
    case 4288:  /* mve_vmaxq_m_sv4si */
    case 4287:  /* mve_vmaxq_m_uv8hi */
    case 4286:  /* mve_vmaxq_m_sv8hi */
    case 4285:  /* mve_vmaxq_m_uv16qi */
    case 4284:  /* mve_vmaxq_m_sv16qi */
    case 4283:  /* mve_vhsubq_m_uv4si */
    case 4282:  /* mve_vhsubq_m_sv4si */
    case 4281:  /* mve_vhsubq_m_uv8hi */
    case 4280:  /* mve_vhsubq_m_sv8hi */
    case 4279:  /* mve_vhsubq_m_uv16qi */
    case 4278:  /* mve_vhsubq_m_sv16qi */
    case 4277:  /* mve_vhsubq_m_n_uv4si */
    case 4276:  /* mve_vhsubq_m_n_sv4si */
    case 4275:  /* mve_vhsubq_m_n_uv8hi */
    case 4274:  /* mve_vhsubq_m_n_sv8hi */
    case 4273:  /* mve_vhsubq_m_n_uv16qi */
    case 4272:  /* mve_vhsubq_m_n_sv16qi */
    case 4271:  /* mve_vhaddq_m_uv4si */
    case 4270:  /* mve_vhaddq_m_sv4si */
    case 4269:  /* mve_vhaddq_m_uv8hi */
    case 4268:  /* mve_vhaddq_m_sv8hi */
    case 4267:  /* mve_vhaddq_m_uv16qi */
    case 4266:  /* mve_vhaddq_m_sv16qi */
    case 4265:  /* mve_vhaddq_m_n_uv4si */
    case 4264:  /* mve_vhaddq_m_n_sv4si */
    case 4263:  /* mve_vhaddq_m_n_uv8hi */
    case 4262:  /* mve_vhaddq_m_n_sv8hi */
    case 4261:  /* mve_vhaddq_m_n_uv16qi */
    case 4260:  /* mve_vhaddq_m_n_sv16qi */
    case 4259:  /* mve_veorq_m_uv4si */
    case 4258:  /* mve_veorq_m_sv4si */
    case 4257:  /* mve_veorq_m_uv8hi */
    case 4256:  /* mve_veorq_m_sv8hi */
    case 4255:  /* mve_veorq_m_uv16qi */
    case 4254:  /* mve_veorq_m_sv16qi */
    case 4253:  /* mve_vcaddq_rot90_m_sv4si */
    case 4252:  /* mve_vcaddq_rot90_m_uv4si */
    case 4251:  /* mve_vcaddq_rot90_m_sv8hi */
    case 4250:  /* mve_vcaddq_rot90_m_uv8hi */
    case 4249:  /* mve_vcaddq_rot90_m_sv16qi */
    case 4248:  /* mve_vcaddq_rot90_m_uv16qi */
    case 4247:  /* mve_vcaddq_rot270_m_sv4si */
    case 4246:  /* mve_vcaddq_rot270_m_uv4si */
    case 4245:  /* mve_vcaddq_rot270_m_sv8hi */
    case 4244:  /* mve_vcaddq_rot270_m_uv8hi */
    case 4243:  /* mve_vcaddq_rot270_m_sv16qi */
    case 4242:  /* mve_vcaddq_rot270_m_uv16qi */
    case 4241:  /* mve_vbrsrq_m_n_sv4si */
    case 4240:  /* mve_vbrsrq_m_n_uv4si */
    case 4239:  /* mve_vbrsrq_m_n_sv8hi */
    case 4238:  /* mve_vbrsrq_m_n_uv8hi */
    case 4237:  /* mve_vbrsrq_m_n_sv16qi */
    case 4236:  /* mve_vbrsrq_m_n_uv16qi */
    case 4235:  /* mve_vbicq_m_sv4si */
    case 4234:  /* mve_vbicq_m_uv4si */
    case 4233:  /* mve_vbicq_m_sv8hi */
    case 4232:  /* mve_vbicq_m_uv8hi */
    case 4231:  /* mve_vbicq_m_sv16qi */
    case 4230:  /* mve_vbicq_m_uv16qi */
    case 4229:  /* mve_vandq_m_sv4si */
    case 4228:  /* mve_vandq_m_uv4si */
    case 4227:  /* mve_vandq_m_sv8hi */
    case 4226:  /* mve_vandq_m_uv8hi */
    case 4225:  /* mve_vandq_m_sv16qi */
    case 4224:  /* mve_vandq_m_uv16qi */
    case 4223:  /* mve_vaddq_m_sv4si */
    case 4222:  /* mve_vaddq_m_uv4si */
    case 4221:  /* mve_vaddq_m_sv8hi */
    case 4220:  /* mve_vaddq_m_uv8hi */
    case 4219:  /* mve_vaddq_m_sv16qi */
    case 4218:  /* mve_vaddq_m_uv16qi */
    case 4217:  /* mve_vaddq_m_n_uv4si */
    case 4216:  /* mve_vaddq_m_n_sv4si */
    case 4215:  /* mve_vaddq_m_n_uv8hi */
    case 4214:  /* mve_vaddq_m_n_sv8hi */
    case 4213:  /* mve_vaddq_m_n_uv16qi */
    case 4212:  /* mve_vaddq_m_n_sv16qi */
    case 4211:  /* mve_vabdq_m_uv4si */
    case 4210:  /* mve_vabdq_m_sv4si */
    case 4209:  /* mve_vabdq_m_uv8hi */
    case 4208:  /* mve_vabdq_m_sv8hi */
    case 4207:  /* mve_vabdq_m_uv16qi */
    case 4206:  /* mve_vabdq_m_sv16qi */
    case 4205:  /* mve_vcvtq_m_n_to_f_sv4sf */
    case 4204:  /* mve_vcvtq_m_n_to_f_uv4sf */
    case 4203:  /* mve_vcvtq_m_n_to_f_sv8hf */
    case 4202:  /* mve_vcvtq_m_n_to_f_uv8hf */
    case 4201:  /* mve_vsubq_m_sv4si */
    case 4200:  /* mve_vsubq_m_uv4si */
    case 4199:  /* mve_vsubq_m_sv8hi */
    case 4198:  /* mve_vsubq_m_uv8hi */
    case 4197:  /* mve_vsubq_m_sv16qi */
    case 4196:  /* mve_vsubq_m_uv16qi */
    case 4195:  /* mve_vsriq_m_n_uv4si */
    case 4194:  /* mve_vsriq_m_n_sv4si */
    case 4193:  /* mve_vsriq_m_n_uv8hi */
    case 4192:  /* mve_vsriq_m_n_sv8hi */
    case 4191:  /* mve_vsriq_m_n_uv16qi */
    case 4190:  /* mve_vsriq_m_n_sv16qi */
    case 4189:  /* mve_vshlq_m_uv4si */
    case 4188:  /* mve_vshlq_m_sv4si */
    case 4187:  /* mve_vshlq_m_uv8hi */
    case 4186:  /* mve_vshlq_m_sv8hi */
    case 4185:  /* mve_vshlq_m_uv16qi */
    case 4184:  /* mve_vshlq_m_sv16qi */
    case 4183:  /* mve_vqshluq_m_n_sv4si */
    case 4182:  /* mve_vqshluq_m_n_sv8hi */
    case 4181:  /* mve_vqshluq_m_n_sv16qi */
    case 4180:  /* mve_vabavq_p_uv4si */
    case 4179:  /* mve_vabavq_p_sv4si */
    case 4178:  /* mve_vabavq_p_uv8hi */
    case 4177:  /* mve_vabavq_p_sv8hi */
    case 4176:  /* mve_vabavq_p_uv16qi */
    case 4175:  /* mve_vabavq_p_sv16qi */
    case 4174:  /* mve_vrmlsldavhaq_sv4si */
    case 4173:  /* mve_vrmlaldavhq_p_uv4si */
    case 4172:  /* mve_vrmlaldavhq_p_sv4si */
    case 4171:  /* mve_vcvtq_m_from_f_sv4si */
    case 4170:  /* mve_vcvtq_m_from_f_uv4si */
    case 4169:  /* mve_vcvtq_m_from_f_sv8hi */
    case 4168:  /* mve_vcvtq_m_from_f_uv8hi */
    case 4167:  /* mve_vrev16q_m_uv16qi */
    case 4166:  /* mve_vrev16q_m_sv16qi */
    case 4165:  /* mve_vcvtq_m_n_from_f_uv4si */
    case 4164:  /* mve_vcvtq_m_n_from_f_sv4si */
    case 4163:  /* mve_vcvtq_m_n_from_f_uv8hi */
    case 4162:  /* mve_vcvtq_m_n_from_f_sv8hi */
    case 4161:  /* mve_vcvtnq_m_uv4si */
    case 4160:  /* mve_vcvtnq_m_sv4si */
    case 4159:  /* mve_vcvtnq_m_uv8hi */
    case 4158:  /* mve_vcvtnq_m_sv8hi */
    case 4157:  /* mve_vcvtpq_m_uv4si */
    case 4156:  /* mve_vcvtpq_m_sv4si */
    case 4155:  /* mve_vcvtpq_m_uv8hi */
    case 4154:  /* mve_vcvtpq_m_sv8hi */
    case 4153:  /* mve_vcvtmq_m_uv4si */
    case 4152:  /* mve_vcvtmq_m_sv4si */
    case 4151:  /* mve_vcvtmq_m_uv8hi */
    case 4150:  /* mve_vcvtmq_m_sv8hi */
    case 4149:  /* mve_vshrntq_n_uv4si */
    case 4148:  /* mve_vshrntq_n_sv4si */
    case 4147:  /* mve_vshrntq_n_uv8hi */
    case 4146:  /* mve_vshrntq_n_sv8hi */
    case 4145:  /* mve_vshrnbq_n_sv4si */
    case 4144:  /* mve_vshrnbq_n_uv4si */
    case 4143:  /* mve_vshrnbq_n_sv8hi */
    case 4142:  /* mve_vshrnbq_n_uv8hi */
    case 4141:  /* mve_vrshrntq_n_sv4si */
    case 4140:  /* mve_vrshrntq_n_uv4si */
    case 4139:  /* mve_vrshrntq_n_sv8hi */
    case 4138:  /* mve_vrshrntq_n_uv8hi */
    case 4137:  /* mve_vrshrnbq_n_uv4si */
    case 4136:  /* mve_vrshrnbq_n_sv4si */
    case 4135:  /* mve_vrshrnbq_n_uv8hi */
    case 4134:  /* mve_vrshrnbq_n_sv8hi */
    case 4133:  /* mve_vrndxq_m_fv4sf */
    case 4132:  /* mve_vrndxq_m_fv8hf */
    case 4131:  /* mve_vrndpq_m_fv4sf */
    case 4130:  /* mve_vrndpq_m_fv8hf */
    case 4129:  /* mve_vrndnq_m_fv4sf */
    case 4128:  /* mve_vrndnq_m_fv8hf */
    case 4127:  /* mve_vrndmq_m_fv4sf */
    case 4126:  /* mve_vrndmq_m_fv8hf */
    case 4125:  /* mve_vrndaq_m_fv4sf */
    case 4124:  /* mve_vrndaq_m_fv8hf */
    case 4123:  /* mve_vrmlsldavhxq_p_sv4si */
    case 4122:  /* mve_vrmlsldavhq_p_sv4si */
    case 4121:  /* mve_vrmlsldavhaxq_sv4si */
    case 4120:  /* mve_vrmlaldavhxq_p_sv4si */
    case 4119:  /* mve_vrmlaldavhaxq_sv4si */
    case 4118:  /* mve_vrev64q_m_fv4sf */
    case 4117:  /* mve_vrev64q_m_fv8hf */
    case 4116:  /* mve_vrev32q_m_uv8hi */
    case 4115:  /* mve_vrev32q_m_sv8hi */
    case 4114:  /* mve_vrev32q_m_uv16qi */
    case 4113:  /* mve_vrev32q_m_sv16qi */
    case 4112:  /* mve_vrev32q_m_fv8hf */
    case 4111:  /* mve_vqshruntq_n_sv4si */
    case 4110:  /* mve_vqshruntq_n_sv8hi */
    case 4109:  /* mve_vqshrunbq_n_sv4si */
    case 4108:  /* mve_vqshrunbq_n_sv8hi */
    case 4107:  /* mve_vqshrntq_n_sv4si */
    case 4106:  /* mve_vqshrntq_n_uv4si */
    case 4105:  /* mve_vqshrntq_n_sv8hi */
    case 4104:  /* mve_vqshrntq_n_uv8hi */
    case 4103:  /* mve_vqshrnbq_n_sv4si */
    case 4102:  /* mve_vqshrnbq_n_uv4si */
    case 4101:  /* mve_vqshrnbq_n_sv8hi */
    case 4100:  /* mve_vqshrnbq_n_uv8hi */
    case 4099:  /* mve_vqrshruntq_n_sv4si */
    case 4098:  /* mve_vqrshruntq_n_sv8hi */
    case 4097:  /* mve_vqrshrntq_n_sv4si */
    case 4096:  /* mve_vqrshrntq_n_uv4si */
    case 4095:  /* mve_vqrshrntq_n_sv8hi */
    case 4094:  /* mve_vqrshrntq_n_uv8hi */
    case 4093:  /* mve_vqmovuntq_m_sv4si */
    case 4092:  /* mve_vqmovuntq_m_sv8hi */
    case 4091:  /* mve_vqmovunbq_m_sv4si */
    case 4090:  /* mve_vqmovunbq_m_sv8hi */
    case 4089:  /* mve_vqmovntq_m_sv4si */
    case 4088:  /* mve_vqmovntq_m_uv4si */
    case 4087:  /* mve_vqmovntq_m_sv8hi */
    case 4086:  /* mve_vqmovntq_m_uv8hi */
    case 4085:  /* mve_vqmovnbq_m_uv4si */
    case 4084:  /* mve_vqmovnbq_m_sv4si */
    case 4083:  /* mve_vqmovnbq_m_uv8hi */
    case 4082:  /* mve_vqmovnbq_m_sv8hi */
    case 4081:  /* mve_vpselq_fv4sf */
    case 4080:  /* mve_vpselq_fv8hf */
    case 4079:  /* mve_vorrq_m_n_uv4si */
    case 4078:  /* mve_vorrq_m_n_sv4si */
    case 4077:  /* mve_vorrq_m_n_uv8hi */
    case 4076:  /* mve_vorrq_m_n_sv8hi */
    case 4075:  /* mve_vnegq_m_fv4sf */
    case 4074:  /* mve_vnegq_m_fv8hf */
    case 4073:  /* mve_vmvnq_m_n_sv4si */
    case 4072:  /* mve_vmvnq_m_n_uv4si */
    case 4071:  /* mve_vmvnq_m_n_sv8hi */
    case 4070:  /* mve_vmvnq_m_n_uv8hi */
    case 4069:  /* mve_vmovntq_m_sv4si */
    case 4068:  /* mve_vmovntq_m_uv4si */
    case 4067:  /* mve_vmovntq_m_sv8hi */
    case 4066:  /* mve_vmovntq_m_uv8hi */
    case 4065:  /* mve_vmovnbq_m_sv4si */
    case 4064:  /* mve_vmovnbq_m_uv4si */
    case 4063:  /* mve_vmovnbq_m_sv8hi */
    case 4062:  /* mve_vmovnbq_m_uv8hi */
    case 4061:  /* mve_vmovltq_m_sv8hi */
    case 4060:  /* mve_vmovltq_m_uv8hi */
    case 4059:  /* mve_vmovltq_m_sv16qi */
    case 4058:  /* mve_vmovltq_m_uv16qi */
    case 4057:  /* mve_vmovlbq_m_sv8hi */
    case 4056:  /* mve_vmovlbq_m_uv8hi */
    case 4055:  /* mve_vmovlbq_m_sv16qi */
    case 4054:  /* mve_vmovlbq_m_uv16qi */
    case 4053:  /* mve_vmlsldavxq_p_sv4si */
    case 4052:  /* mve_vmlsldavxq_p_sv8hi */
    case 4051:  /* mve_vmlsldavq_p_sv4si */
    case 4050:  /* mve_vmlsldavq_p_sv8hi */
    case 4049:  /* mve_vmlsldavaxq_sv4si */
    case 4048:  /* mve_vmlsldavaxq_sv8hi */
    case 4047:  /* mve_vmlsldavaq_sv4si */
    case 4046:  /* mve_vmlsldavaq_sv8hi */
    case 4045:  /* mve_vmlaldavxq_p_sv4si */
    case 4044:  /* mve_vmlaldavxq_p_sv8hi */
    case 4043:  /* mve_vmlaldavq_p_sv4si */
    case 4042:  /* mve_vmlaldavq_p_uv4si */
    case 4041:  /* mve_vmlaldavq_p_sv8hi */
    case 4040:  /* mve_vmlaldavq_p_uv8hi */
    case 4039:  /* mve_vmlaldavaxq_sv4si */
    case 4038:  /* mve_vmlaldavaxq_sv8hi */
    case 4037:  /* mve_vmlaldavaq_uv4si */
    case 4036:  /* mve_vmlaldavaq_sv4si */
    case 4035:  /* mve_vmlaldavaq_uv8hi */
    case 4034:  /* mve_vmlaldavaq_sv8hi */
    case 4033:  /* mve_vminnmvq_p_fv4sf */
    case 4032:  /* mve_vminnmvq_p_fv8hf */
    case 4031:  /* mve_vminnmavq_p_fv4sf */
    case 4030:  /* mve_vminnmavq_p_fv8hf */
    case 4029:  /* mve_vminnmaq_m_fv4sf */
    case 4028:  /* mve_vminnmaq_m_fv8hf */
    case 4027:  /* mve_vmaxnmvq_p_fv4sf */
    case 4026:  /* mve_vmaxnmvq_p_fv8hf */
    case 4025:  /* mve_vmaxnmavq_p_fv4sf */
    case 4024:  /* mve_vmaxnmavq_p_fv8hf */
    case 4023:  /* mve_vmaxnmaq_m_fv4sf */
    case 4022:  /* mve_vmaxnmaq_m_fv8hf */
    case 4021:  /* mve_vfmsq_fv4sf */
    case 4020:  /* mve_vfmsq_fv8hf */
    case 4019:  /* mve_vfmasq_n_fv4sf */
    case 4018:  /* mve_vfmasq_n_fv8hf */
    case 4017:  /* mve_vfmaq_n_fv4sf */
    case 4016:  /* mve_vfmaq_n_fv8hf */
    case 4015:  /* mve_vfmaq_fv4sf */
    case 4014:  /* mve_vfmaq_fv8hf */
    case 4013:  /* mve_vdupq_m_n_fv4sf */
    case 4012:  /* mve_vdupq_m_n_fv8hf */
    case 4011:  /* mve_vcvttq_m_f32_f16v4sf */
    case 4010:  /* mve_vcvttq_m_f16_f32v8hf */
    case 4009:  /* mve_vcvtbq_m_f32_f16v4sf */
    case 4008:  /* mve_vcvtbq_m_f16_f32v8hf */
    case 4007:  /* mve_vcmpneq_m_n_fv4sf */
    case 4006:  /* mve_vcmpneq_m_n_fv8hf */
    case 4005:  /* mve_vcmpneq_m_fv4sf */
    case 4004:  /* mve_vcmpneq_m_fv8hf */
    case 4003:  /* mve_vcmpltq_m_n_fv4sf */
    case 4002:  /* mve_vcmpltq_m_n_fv8hf */
    case 4001:  /* mve_vcmpltq_m_fv4sf */
    case 4000:  /* mve_vcmpltq_m_fv8hf */
    case 3999:  /* mve_vcmpleq_m_n_fv4sf */
    case 3998:  /* mve_vcmpleq_m_n_fv8hf */
    case 3997:  /* mve_vcmpleq_m_fv4sf */
    case 3996:  /* mve_vcmpleq_m_fv8hf */
    case 3995:  /* mve_vcmpgtq_m_n_fv4sf */
    case 3994:  /* mve_vcmpgtq_m_n_fv8hf */
    case 3993:  /* mve_vcmpgtq_m_fv4sf */
    case 3992:  /* mve_vcmpgtq_m_fv8hf */
    case 3991:  /* mve_vcmpgeq_m_n_fv4sf */
    case 3990:  /* mve_vcmpgeq_m_n_fv8hf */
    case 3989:  /* mve_vcmpgeq_m_fv4sf */
    case 3988:  /* mve_vcmpgeq_m_fv8hf */
    case 3987:  /* mve_vcmpeqq_m_n_fv4sf */
    case 3986:  /* mve_vcmpeqq_m_n_fv8hf */
    case 3985:  /* mve_vcmlaq_rot270v4sf */
    case 3984:  /* mve_vcmlaq_rot180v4sf */
    case 3983:  /* mve_vcmlaq_rot90v4sf */
    case 3982:  /* mve_vcmlaqv4sf */
    case 3981:  /* mve_vcmlaq_rot270v8hf */
    case 3980:  /* mve_vcmlaq_rot180v8hf */
    case 3979:  /* mve_vcmlaq_rot90v8hf */
    case 3978:  /* mve_vcmlaqv8hf */
    case 3977:  /* mve_vaddlvaq_p_sv4si */
    case 3976:  /* mve_vaddlvaq_p_uv4si */
    case 3975:  /* mve_vabsq_m_fv4sf */
    case 3974:  /* mve_vabsq_m_fv8hf */
    case 3973:  /* mve_vmladavaxq_sv4si */
    case 3972:  /* mve_vmladavaxq_sv8hi */
    case 3971:  /* mve_vmladavaxq_sv16qi */
    case 3970:  /* mve_vmlsdavaq_sv4si */
    case 3969:  /* mve_vmlsdavaq_sv8hi */
    case 3968:  /* mve_vmlsdavaq_sv16qi */
    case 3967:  /* mve_vmlsdavaxq_sv4si */
    case 3966:  /* mve_vmlsdavaxq_sv8hi */
    case 3965:  /* mve_vmlsdavaxq_sv16qi */
    case 3964:  /* mve_vqdmladhq_sv4si */
    case 3963:  /* mve_vqdmladhq_sv8hi */
    case 3962:  /* mve_vqdmladhq_sv16qi */
    case 3961:  /* mve_vqdmladhxq_sv4si */
    case 3960:  /* mve_vqdmladhxq_sv8hi */
    case 3959:  /* mve_vqdmladhxq_sv16qi */
    case 3958:  /* mve_vqdmlsdhq_sv4si */
    case 3957:  /* mve_vqdmlsdhq_sv8hi */
    case 3956:  /* mve_vqdmlsdhq_sv16qi */
    case 3955:  /* mve_vqdmlsdhxq_sv4si */
    case 3954:  /* mve_vqdmlsdhxq_sv8hi */
    case 3953:  /* mve_vqdmlsdhxq_sv16qi */
    case 3952:  /* mve_vsriq_n_uv4si */
    case 3951:  /* mve_vsriq_n_sv4si */
    case 3950:  /* mve_vsriq_n_uv8hi */
    case 3949:  /* mve_vsriq_n_sv8hi */
    case 3948:  /* mve_vsriq_n_uv16qi */
    case 3947:  /* mve_vsriq_n_sv16qi */
    case 3946:  /* mve_vsliq_n_uv4si */
    case 3945:  /* mve_vsliq_n_sv4si */
    case 3944:  /* mve_vsliq_n_uv8hi */
    case 3943:  /* mve_vsliq_n_sv8hi */
    case 3942:  /* mve_vsliq_n_uv16qi */
    case 3941:  /* mve_vsliq_n_sv16qi */
    case 3940:  /* mve_vshlq_m_r_uv4si */
    case 3939:  /* mve_vshlq_m_r_sv4si */
    case 3938:  /* mve_vshlq_m_r_uv8hi */
    case 3937:  /* mve_vshlq_m_r_sv8hi */
    case 3936:  /* mve_vshlq_m_r_uv16qi */
    case 3935:  /* mve_vshlq_m_r_sv16qi */
    case 3934:  /* mve_vrshlq_m_n_uv4si */
    case 3933:  /* mve_vrshlq_m_n_sv4si */
    case 3932:  /* mve_vrshlq_m_n_uv8hi */
    case 3931:  /* mve_vrshlq_m_n_sv8hi */
    case 3930:  /* mve_vrshlq_m_n_uv16qi */
    case 3929:  /* mve_vrshlq_m_n_sv16qi */
    case 3928:  /* mve_vrev64q_m_uv4si */
    case 3927:  /* mve_vrev64q_m_sv4si */
    case 3926:  /* mve_vrev64q_m_uv8hi */
    case 3925:  /* mve_vrev64q_m_sv8hi */
    case 3924:  /* mve_vrev64q_m_uv16qi */
    case 3923:  /* mve_vrev64q_m_sv16qi */
    case 3922:  /* mve_vqshlq_m_r_uv4si */
    case 3921:  /* mve_vqshlq_m_r_sv4si */
    case 3920:  /* mve_vqshlq_m_r_uv8hi */
    case 3919:  /* mve_vqshlq_m_r_sv8hi */
    case 3918:  /* mve_vqshlq_m_r_uv16qi */
    case 3917:  /* mve_vqshlq_m_r_sv16qi */
    case 3916:  /* mve_vqrshlq_m_n_uv4si */
    case 3915:  /* mve_vqrshlq_m_n_sv4si */
    case 3914:  /* mve_vqrshlq_m_n_uv8hi */
    case 3913:  /* mve_vqrshlq_m_n_sv8hi */
    case 3912:  /* mve_vqrshlq_m_n_uv16qi */
    case 3911:  /* mve_vqrshlq_m_n_sv16qi */
    case 3910:  /* mve_vqrdmlsdhxq_sv4si */
    case 3909:  /* mve_vqrdmlsdhxq_sv8hi */
    case 3908:  /* mve_vqrdmlsdhxq_sv16qi */
    case 3907:  /* mve_vqrdmlsdhq_sv4si */
    case 3906:  /* mve_vqrdmlsdhq_sv8hi */
    case 3905:  /* mve_vqrdmlsdhq_sv16qi */
    case 3904:  /* mve_vqrdmlashq_n_sv4si */
    case 3903:  /* mve_vqrdmlashq_n_sv8hi */
    case 3902:  /* mve_vqrdmlashq_n_sv16qi */
    case 3901:  /* mve_vqrdmlahq_n_sv4si */
    case 3900:  /* mve_vqrdmlahq_n_sv8hi */
    case 3899:  /* mve_vqrdmlahq_n_sv16qi */
    case 3898:  /* mve_vqrdmladhxq_sv4si */
    case 3897:  /* mve_vqrdmladhxq_sv8hi */
    case 3896:  /* mve_vqrdmladhxq_sv16qi */
    case 3895:  /* mve_vqrdmladhq_sv4si */
    case 3894:  /* mve_vqrdmladhq_sv8hi */
    case 3893:  /* mve_vqrdmladhq_sv16qi */
    case 3892:  /* mve_vqnegq_m_sv4si */
    case 3891:  /* mve_vqnegq_m_sv8hi */
    case 3890:  /* mve_vqnegq_m_sv16qi */
    case 3889:  /* mve_vqdmlashq_n_sv4si */
    case 3888:  /* mve_vqdmlashq_n_sv8hi */
    case 3887:  /* mve_vqdmlashq_n_sv16qi */
    case 3886:  /* mve_vqdmlahq_n_sv4si */
    case 3885:  /* mve_vqdmlahq_n_sv8hi */
    case 3884:  /* mve_vqdmlahq_n_sv16qi */
    case 3883:  /* mve_vqabsq_m_sv4si */
    case 3882:  /* mve_vqabsq_m_sv8hi */
    case 3881:  /* mve_vqabsq_m_sv16qi */
    case 3880:  /* mve_vpselq_uv2di */
    case 3879:  /* mve_vpselq_sv2di */
    case 3878:  /* mve_vpselq_uv4si */
    case 3877:  /* mve_vpselq_sv4si */
    case 3876:  /* mve_vpselq_uv8hi */
    case 3875:  /* mve_vpselq_sv8hi */
    case 3874:  /* mve_vpselq_uv16qi */
    case 3873:  /* mve_vpselq_sv16qi */
    case 3872:  /* mve_vnegq_m_sv4si */
    case 3871:  /* mve_vnegq_m_sv8hi */
    case 3870:  /* mve_vnegq_m_sv16qi */
    case 3869:  /* mve_vmvnq_m_uv4si */
    case 3868:  /* mve_vmvnq_m_sv4si */
    case 3867:  /* mve_vmvnq_m_uv8hi */
    case 3866:  /* mve_vmvnq_m_sv8hi */
    case 3865:  /* mve_vmvnq_m_uv16qi */
    case 3864:  /* mve_vmvnq_m_sv16qi */
    case 3863:  /* mve_vmlsdavxq_p_sv4si */
    case 3862:  /* mve_vmlsdavxq_p_sv8hi */
    case 3861:  /* mve_vmlsdavxq_p_sv16qi */
    case 3860:  /* mve_vmlsdavq_p_sv4si */
    case 3859:  /* mve_vmlsdavq_p_sv8hi */
    case 3858:  /* mve_vmlsdavq_p_sv16qi */
    case 3857:  /* mve_vmlasq_n_uv4si */
    case 3856:  /* mve_vmlasq_n_sv4si */
    case 3855:  /* mve_vmlasq_n_uv8hi */
    case 3854:  /* mve_vmlasq_n_sv8hi */
    case 3853:  /* mve_vmlasq_n_uv16qi */
    case 3852:  /* mve_vmlasq_n_sv16qi */
    case 3851:  /* mve_vmlaq_n_uv4si */
    case 3850:  /* mve_vmlaq_n_sv4si */
    case 3849:  /* mve_vmlaq_n_uv8hi */
    case 3848:  /* mve_vmlaq_n_sv8hi */
    case 3847:  /* mve_vmlaq_n_uv16qi */
    case 3846:  /* mve_vmlaq_n_sv16qi */
    case 3845:  /* mve_vmladavxq_p_sv4si */
    case 3844:  /* mve_vmladavxq_p_sv8hi */
    case 3843:  /* mve_vmladavxq_p_sv16qi */
    case 3842:  /* mve_vmladavq_p_uv4si */
    case 3841:  /* mve_vmladavq_p_sv4si */
    case 3840:  /* mve_vmladavq_p_uv8hi */
    case 3839:  /* mve_vmladavq_p_sv8hi */
    case 3838:  /* mve_vmladavq_p_uv16qi */
    case 3837:  /* mve_vmladavq_p_sv16qi */
    case 3836:  /* mve_vmladavaq_uv4si */
    case 3835:  /* mve_vmladavaq_sv4si */
    case 3834:  /* mve_vmladavaq_uv8hi */
    case 3833:  /* mve_vmladavaq_sv8hi */
    case 3832:  /* mve_vmladavaq_uv16qi */
    case 3831:  /* mve_vmladavaq_sv16qi */
    case 3830:  /* mve_vminvq_p_uv4si */
    case 3829:  /* mve_vminvq_p_sv4si */
    case 3828:  /* mve_vminvq_p_uv8hi */
    case 3827:  /* mve_vminvq_p_sv8hi */
    case 3826:  /* mve_vminvq_p_uv16qi */
    case 3825:  /* mve_vminvq_p_sv16qi */
    case 3824:  /* mve_vminavq_p_sv4si */
    case 3823:  /* mve_vminavq_p_sv8hi */
    case 3822:  /* mve_vminavq_p_sv16qi */
    case 3821:  /* mve_vminaq_m_sv4si */
    case 3820:  /* mve_vminaq_m_sv8hi */
    case 3819:  /* mve_vminaq_m_sv16qi */
    case 3818:  /* mve_vmaxvq_p_uv4si */
    case 3817:  /* mve_vmaxvq_p_sv4si */
    case 3816:  /* mve_vmaxvq_p_uv8hi */
    case 3815:  /* mve_vmaxvq_p_sv8hi */
    case 3814:  /* mve_vmaxvq_p_uv16qi */
    case 3813:  /* mve_vmaxvq_p_sv16qi */
    case 3812:  /* mve_vmaxavq_p_sv4si */
    case 3811:  /* mve_vmaxavq_p_sv8hi */
    case 3810:  /* mve_vmaxavq_p_sv16qi */
    case 3809:  /* mve_vmaxaq_m_sv4si */
    case 3808:  /* mve_vmaxaq_m_sv8hi */
    case 3807:  /* mve_vmaxaq_m_sv16qi */
    case 3806:  /* mve_vdupq_m_n_uv4si */
    case 3805:  /* mve_vdupq_m_n_sv4si */
    case 3804:  /* mve_vdupq_m_n_uv8hi */
    case 3803:  /* mve_vdupq_m_n_sv8hi */
    case 3802:  /* mve_vdupq_m_n_uv16qi */
    case 3801:  /* mve_vdupq_m_n_sv16qi */
    case 3800:  /* mve_vcmpneq_m_uv4si */
    case 3799:  /* mve_vcmpneq_m_sv4si */
    case 3798:  /* mve_vcmpneq_m_uv8hi */
    case 3797:  /* mve_vcmpneq_m_sv8hi */
    case 3796:  /* mve_vcmpneq_m_uv16qi */
    case 3795:  /* mve_vcmpneq_m_sv16qi */
    case 3794:  /* mve_vcmpneq_m_n_uv4si */
    case 3793:  /* mve_vcmpneq_m_n_sv4si */
    case 3792:  /* mve_vcmpneq_m_n_uv8hi */
    case 3791:  /* mve_vcmpneq_m_n_sv8hi */
    case 3790:  /* mve_vcmpneq_m_n_uv16qi */
    case 3789:  /* mve_vcmpneq_m_n_sv16qi */
    case 3788:  /* mve_vcmpltq_m_sv4si */
    case 3787:  /* mve_vcmpltq_m_sv8hi */
    case 3786:  /* mve_vcmpltq_m_sv16qi */
    case 3785:  /* mve_vcmpltq_m_n_sv4si */
    case 3784:  /* mve_vcmpltq_m_n_sv8hi */
    case 3783:  /* mve_vcmpltq_m_n_sv16qi */
    case 3782:  /* mve_vcmpleq_m_sv4si */
    case 3781:  /* mve_vcmpleq_m_sv8hi */
    case 3780:  /* mve_vcmpleq_m_sv16qi */
    case 3779:  /* mve_vcmpleq_m_n_sv4si */
    case 3778:  /* mve_vcmpleq_m_n_sv8hi */
    case 3777:  /* mve_vcmpleq_m_n_sv16qi */
    case 3776:  /* mve_vcmphiq_m_uv4si */
    case 3775:  /* mve_vcmphiq_m_uv8hi */
    case 3774:  /* mve_vcmphiq_m_uv16qi */
    case 3773:  /* mve_vcmphiq_m_n_uv4si */
    case 3772:  /* mve_vcmphiq_m_n_uv8hi */
    case 3771:  /* mve_vcmphiq_m_n_uv16qi */
    case 3770:  /* mve_vcmpgtq_m_sv4si */
    case 3769:  /* mve_vcmpgtq_m_sv8hi */
    case 3768:  /* mve_vcmpgtq_m_sv16qi */
    case 3767:  /* mve_vcmpgtq_m_n_sv4si */
    case 3766:  /* mve_vcmpgtq_m_n_sv8hi */
    case 3765:  /* mve_vcmpgtq_m_n_sv16qi */
    case 3764:  /* mve_vcmpgeq_m_sv4si */
    case 3763:  /* mve_vcmpgeq_m_sv8hi */
    case 3762:  /* mve_vcmpgeq_m_sv16qi */
    case 3761:  /* mve_vcmpgeq_m_n_sv4si */
    case 3760:  /* mve_vcmpgeq_m_n_sv8hi */
    case 3759:  /* mve_vcmpgeq_m_n_sv16qi */
    case 3758:  /* mve_vcmpeqq_m_uv4si */
    case 3757:  /* mve_vcmpeqq_m_sv4si */
    case 3756:  /* mve_vcmpeqq_m_uv8hi */
    case 3755:  /* mve_vcmpeqq_m_sv8hi */
    case 3754:  /* mve_vcmpeqq_m_uv16qi */
    case 3753:  /* mve_vcmpeqq_m_sv16qi */
    case 3752:  /* mve_vcmpeqq_m_n_uv4si */
    case 3751:  /* mve_vcmpeqq_m_n_sv4si */
    case 3750:  /* mve_vcmpeqq_m_n_uv8hi */
    case 3749:  /* mve_vcmpeqq_m_n_sv8hi */
    case 3748:  /* mve_vcmpeqq_m_n_uv16qi */
    case 3747:  /* mve_vcmpeqq_m_n_sv16qi */
    case 3746:  /* mve_vcmpcsq_m_uv4si */
    case 3745:  /* mve_vcmpcsq_m_uv8hi */
    case 3744:  /* mve_vcmpcsq_m_uv16qi */
    case 3743:  /* mve_vcmpcsq_m_n_uv4si */
    case 3742:  /* mve_vcmpcsq_m_n_uv8hi */
    case 3741:  /* mve_vcmpcsq_m_n_uv16qi */
    case 3740:  /* mve_vclzq_m_uv4si */
    case 3739:  /* mve_vclzq_m_sv4si */
    case 3738:  /* mve_vclzq_m_uv8hi */
    case 3737:  /* mve_vclzq_m_sv8hi */
    case 3736:  /* mve_vclzq_m_uv16qi */
    case 3735:  /* mve_vclzq_m_sv16qi */
    case 3734:  /* mve_vclsq_m_sv4si */
    case 3733:  /* mve_vclsq_m_sv8hi */
    case 3732:  /* mve_vclsq_m_sv16qi */
    case 3731:  /* mve_vaddvaq_p_uv4si */
    case 3730:  /* mve_vaddvaq_p_sv4si */
    case 3729:  /* mve_vaddvaq_p_uv8hi */
    case 3728:  /* mve_vaddvaq_p_sv8hi */
    case 3727:  /* mve_vaddvaq_p_uv16qi */
    case 3726:  /* mve_vaddvaq_p_sv16qi */
    case 3725:  /* mve_vabsq_m_sv4si */
    case 3724:  /* mve_vabsq_m_sv8hi */
    case 3723:  /* mve_vabsq_m_sv16qi */
    case 3722:  /* mve_vshlcq_uv4si */
    case 3721:  /* mve_vshlcq_sv4si */
    case 3720:  /* mve_vshlcq_uv8hi */
    case 3719:  /* mve_vshlcq_sv8hi */
    case 3718:  /* mve_vshlcq_uv16qi */
    case 3717:  /* mve_vshlcq_sv16qi */
    case 3716:  /* mve_vabavq_uv4si */
    case 3715:  /* mve_vabavq_sv4si */
    case 3714:  /* mve_vabavq_uv8hi */
    case 3713:  /* mve_vabavq_sv8hi */
    case 3712:  /* mve_vabavq_uv16qi */
    case 3711:  /* mve_vabavq_sv16qi */
    case 3710:  /* mve_vrmlaldavhaq_uv4si */
    case 3709:  /* mve_vrmlaldavhaq_sv4si */
    case 3708:  /* mve_vqrshrunbq_n_sv4si */
    case 3707:  /* mve_vqrshrunbq_n_sv8hi */
    case 3706:  /* mve_vqrshrnbq_n_sv4si */
    case 3705:  /* mve_vqrshrnbq_n_uv4si */
    case 3704:  /* mve_vqrshrnbq_n_sv8hi */
    case 3703:  /* mve_vqrshrnbq_n_uv8hi */
    case 3702:  /* mve_vcvtq_m_to_f_uv4sf */
    case 3701:  /* mve_vcvtq_m_to_f_sv4sf */
    case 3700:  /* mve_vcvtq_m_to_f_uv8hf */
    case 3699:  /* mve_vcvtq_m_to_f_sv8hf */
    case 3698:  /* mve_vcvtaq_m_uv4si */
    case 3697:  /* mve_vcvtaq_m_sv4si */
    case 3696:  /* mve_vcvtaq_m_uv8hi */
    case 3695:  /* mve_vcvtaq_m_sv8hi */
    case 3694:  /* mve_vcmpeqq_m_fv4sf */
    case 3693:  /* mve_vcmpeqq_m_fv8hf */
    case 3692:  /* mve_vbicq_m_n_uv4si */
    case 3691:  /* mve_vbicq_m_n_sv4si */
    case 3690:  /* mve_vbicq_m_n_uv8hi */
    case 3689:  /* mve_vbicq_m_n_sv8hi */
    case 3688:  /* mve_vrmlaldavhq_sv4si */
    case 3687:  /* mve_vrmlaldavhq_uv4si */
    case 3686:  /* mve_vmullbq_poly_pv8hi */
    case 3685:  /* mve_vmullbq_poly_pv16qi */
    case 3684:  /* mve_vmulltq_poly_pv8hi */
    case 3683:  /* mve_vmulltq_poly_pv16qi */
    case 3682:  /* mve_vsubq_fv4sf */
    case 3681:  /* mve_vsubq_fv8hf */
    case 3680:  /* mve_vshlltq_n_sv8hi */
    case 3679:  /* mve_vshlltq_n_uv8hi */
    case 3678:  /* mve_vshlltq_n_sv16qi */
    case 3677:  /* mve_vshlltq_n_uv16qi */
    case 3676:  /* mve_vshllbq_n_uv8hi */
    case 3675:  /* mve_vshllbq_n_sv8hi */
    case 3674:  /* mve_vshllbq_n_uv16qi */
    case 3673:  /* mve_vshllbq_n_sv16qi */
    case 3672:  /* mve_vrmlsldavhxq_sv4si */
    case 3671:  /* mve_vrmlsldavhq_sv4si */
    case 3670:  /* mve_vrmlaldavhxq_sv4si */
    case 3669:  /* mve_vqmovuntq_sv4si */
    case 3668:  /* mve_vqmovuntq_sv8hi */
    case 3667:  /* mve_vqmovunbq_sv4si */
    case 3666:  /* mve_vqmovunbq_sv8hi */
    case 3665:  /* mve_vqmovntq_sv4si */
    case 3664:  /* mve_vqmovntq_uv4si */
    case 3663:  /* mve_vqmovntq_sv8hi */
    case 3662:  /* mve_vqmovntq_uv8hi */
    case 3661:  /* mve_vqmovnbq_sv4si */
    case 3660:  /* mve_vqmovnbq_uv4si */
    case 3659:  /* mve_vqmovnbq_sv8hi */
    case 3658:  /* mve_vqmovnbq_uv8hi */
    case 3657:  /* mve_vqdmulltq_sv4si */
    case 3656:  /* mve_vqdmulltq_sv8hi */
    case 3655:  /* mve_vqdmulltq_n_sv4si */
    case 3654:  /* mve_vqdmulltq_n_sv8hi */
    case 3653:  /* mve_vqdmullbq_sv4si */
    case 3652:  /* mve_vqdmullbq_sv8hi */
    case 3651:  /* mve_vqdmullbq_n_sv4si */
    case 3650:  /* mve_vqdmullbq_n_sv8hi */
    case 3649:  /* mve_vorrq_n_sv4si */
    case 3648:  /* mve_vorrq_n_uv4si */
    case 3647:  /* mve_vorrq_n_sv8hi */
    case 3646:  /* mve_vorrq_n_uv8hi */
    case 3645:  /* mve_vorrq_fv4sf */
    case 3644:  /* mve_vorrq_fv8hf */
    case 3643:  /* mve_vornq_fv4sf */
    case 3642:  /* mve_vornq_fv8hf */
    case 3641:  /* mve_vmulq_n_fv4sf */
    case 3640:  /* mve_vmulq_n_fv8hf */
    case 3639:  /* mve_vmulq_fv4sf */
    case 3638:  /* mve_vmulq_fv8hf */
    case 3637:  /* mve_vmovntq_uv4si */
    case 3636:  /* mve_vmovntq_sv4si */
    case 3635:  /* mve_vmovntq_uv8hi */
    case 3634:  /* mve_vmovntq_sv8hi */
    case 3633:  /* mve_vmovnbq_sv4si */
    case 3632:  /* mve_vmovnbq_uv4si */
    case 3631:  /* mve_vmovnbq_sv8hi */
    case 3630:  /* mve_vmovnbq_uv8hi */
    case 3629:  /* mve_vmlsldavxq_sv4si */
    case 3628:  /* mve_vmlsldavxq_sv8hi */
    case 3627:  /* mve_vmlsldavq_sv4si */
    case 3626:  /* mve_vmlsldavq_sv8hi */
    case 3625:  /* mve_vmlaldavxq_sv4si */
    case 3624:  /* mve_vmlaldavxq_sv8hi */
    case 3623:  /* mve_vmlaldavq_sv4si */
    case 3622:  /* mve_vmlaldavq_uv4si */
    case 3621:  /* mve_vmlaldavq_sv8hi */
    case 3620:  /* mve_vmlaldavq_uv8hi */
    case 3619:  /* mve_vminnmvq_fv4sf */
    case 3618:  /* mve_vminnmvq_fv8hf */
    case 3617:  /* mve_vminnmq_fv4sf */
    case 3616:  /* mve_vminnmq_fv8hf */
    case 3615:  /* mve_vminnmavq_fv4sf */
    case 3614:  /* mve_vminnmavq_fv8hf */
    case 3613:  /* mve_vminnmaq_fv4sf */
    case 3612:  /* mve_vminnmaq_fv8hf */
    case 3611:  /* mve_vmaxnmvq_fv4sf */
    case 3610:  /* mve_vmaxnmvq_fv8hf */
    case 3609:  /* mve_vmaxnmq_fv4sf */
    case 3608:  /* mve_vmaxnmq_fv8hf */
    case 3607:  /* mve_vmaxnmavq_fv4sf */
    case 3606:  /* mve_vmaxnmavq_fv8hf */
    case 3605:  /* mve_vmaxnmaq_fv4sf */
    case 3604:  /* mve_vmaxnmaq_fv8hf */
    case 3603:  /* mve_veorq_fv4sf */
    case 3602:  /* mve_veorq_fv8hf */
    case 3601:  /* mve_vcvttq_f16_f32v8hf */
    case 3600:  /* mve_vcvtbq_f16_f32v8hf */
    case 3599:  /* mve_vctp64q_mv2qi */
    case 3598:  /* mve_vctp32q_mv4bi */
    case 3597:  /* mve_vctp16q_mv8bi */
    case 3596:  /* mve_vctp8q_mv16bi */
    case 3595:  /* mve_vcmulq_rot270v4sf */
    case 3594:  /* mve_vcmulq_rot180v4sf */
    case 3593:  /* mve_vcmulq_rot90v4sf */
    case 3592:  /* mve_vcmulqv4sf */
    case 3591:  /* mve_vcmulq_rot270v8hf */
    case 3590:  /* mve_vcmulq_rot180v8hf */
    case 3589:  /* mve_vcmulq_rot90v8hf */
    case 3588:  /* mve_vcmulqv8hf */
    case 3587:  /* mve_vcmpneq_n_fv4sf */
    case 3586:  /* mve_vcmpltq_n_fv4sf */
    case 3585:  /* mve_vcmpleq_n_fv4sf */
    case 3584:  /* mve_vcmpgtq_n_fv4sf */
    case 3583:  /* mve_vcmpgeq_n_fv4sf */
    case 3582:  /* mve_vcmpeqq_n_fv4sf */
    case 3581:  /* mve_vcmpneq_n_fv8hf */
    case 3580:  /* mve_vcmpltq_n_fv8hf */
    case 3579:  /* mve_vcmpleq_n_fv8hf */
    case 3578:  /* mve_vcmpgtq_n_fv8hf */
    case 3577:  /* mve_vcmpgeq_n_fv8hf */
    case 3576:  /* mve_vcmpeqq_n_fv8hf */
    case 3575:  /* mve_vcmpneq_fv4sf */
    case 3574:  /* mve_vcmpltq_fv4sf */
    case 3573:  /* mve_vcmpleq_fv4sf */
    case 3572:  /* mve_vcmpgtq_fv4sf */
    case 3571:  /* mve_vcmpgeq_fv4sf */
    case 3570:  /* mve_vcmpeqq_fv4sf */
    case 3569:  /* mve_vcmpneq_fv8hf */
    case 3568:  /* mve_vcmpltq_fv8hf */
    case 3567:  /* mve_vcmpleq_fv8hf */
    case 3566:  /* mve_vcmpgtq_fv8hf */
    case 3565:  /* mve_vcmpgeq_fv8hf */
    case 3564:  /* mve_vcmpeqq_fv8hf */
    case 3563:  /* mve_vcaddq_rot270v4sf */
    case 3562:  /* mve_vcaddq_rot90v4sf */
    case 3561:  /* mve_vcaddq_rot270v8hf */
    case 3560:  /* mve_vcaddq_rot90v8hf */
    case 3559:  /* mve_vbicq_n_uv4si */
    case 3558:  /* mve_vbicq_n_sv4si */
    case 3557:  /* mve_vbicq_n_uv8hi */
    case 3556:  /* mve_vbicq_n_sv8hi */
    case 3555:  /* mve_vbicq_fv4sf */
    case 3554:  /* mve_vbicq_fv8hf */
    case 3553:  /* mve_vandq_fv4sf */
    case 3552:  /* mve_vandq_fv8hf */
    case 3551:  /* mve_vaddq_n_fv4sf */
    case 3550:  /* mve_vaddq_n_fv8hf */
    case 3549:  /* mve_vaddlvaq_uv4si */
    case 3548:  /* mve_vaddlvaq_sv4si */
    case 3547:  /* mve_vabdq_fv4sf */
    case 3546:  /* mve_vabdq_fv8hf */
    case 3545:  /* mve_vsubqv4si */
    case 3544:  /* mve_vsubqv8hi */
    case 3543:  /* mve_vsubqv16qi */
    case 3542:  /* mve_vsubq_uv4si */
    case 3541:  /* mve_vsubq_sv4si */
    case 3540:  /* mve_vsubq_uv8hi */
    case 3539:  /* mve_vsubq_sv8hi */
    case 3538:  /* mve_vsubq_uv16qi */
    case 3537:  /* mve_vsubq_sv16qi */
    case 3536:  /* mve_vsubq_n_uv4si */
    case 3535:  /* mve_vsubq_n_sv4si */
    case 3534:  /* mve_vsubq_n_uv8hi */
    case 3533:  /* mve_vsubq_n_sv8hi */
    case 3532:  /* mve_vsubq_n_uv16qi */
    case 3531:  /* mve_vsubq_n_sv16qi */
    case 3530:  /* mve_vshlq_r_uv4si */
    case 3529:  /* mve_vshlq_r_sv4si */
    case 3528:  /* mve_vshlq_r_uv8hi */
    case 3527:  /* mve_vshlq_r_sv8hi */
    case 3526:  /* mve_vshlq_r_uv16qi */
    case 3525:  /* mve_vshlq_r_sv16qi */
    case 3524:  /* mve_vshlq_n_sv4si */
    case 3523:  /* mve_vshlq_n_uv4si */
    case 3522:  /* mve_vshlq_n_sv8hi */
    case 3521:  /* mve_vshlq_n_uv8hi */
    case 3520:  /* mve_vshlq_n_sv16qi */
    case 3519:  /* mve_vshlq_n_uv16qi */
    case 3518:  /* mve_vrshrq_n_uv4si */
    case 3517:  /* mve_vrshrq_n_sv4si */
    case 3516:  /* mve_vrshrq_n_uv8hi */
    case 3515:  /* mve_vrshrq_n_sv8hi */
    case 3514:  /* mve_vrshrq_n_uv16qi */
    case 3513:  /* mve_vrshrq_n_sv16qi */
    case 3512:  /* mve_vrshlq_uv4si */
    case 3511:  /* mve_vrshlq_sv4si */
    case 3510:  /* mve_vrshlq_uv8hi */
    case 3509:  /* mve_vrshlq_sv8hi */
    case 3508:  /* mve_vrshlq_uv16qi */
    case 3507:  /* mve_vrshlq_sv16qi */
    case 3506:  /* mve_vrshlq_n_sv4si */
    case 3505:  /* mve_vrshlq_n_uv4si */
    case 3504:  /* mve_vrshlq_n_sv8hi */
    case 3503:  /* mve_vrshlq_n_uv8hi */
    case 3502:  /* mve_vrshlq_n_sv16qi */
    case 3501:  /* mve_vrshlq_n_uv16qi */
    case 3500:  /* mve_vrmulhq_uv4si */
    case 3499:  /* mve_vrmulhq_sv4si */
    case 3498:  /* mve_vrmulhq_uv8hi */
    case 3497:  /* mve_vrmulhq_sv8hi */
    case 3496:  /* mve_vrmulhq_uv16qi */
    case 3495:  /* mve_vrmulhq_sv16qi */
    case 3494:  /* mve_vrhaddq_uv4si */
    case 3493:  /* mve_vrhaddq_sv4si */
    case 3492:  /* mve_vrhaddq_uv8hi */
    case 3491:  /* mve_vrhaddq_sv8hi */
    case 3490:  /* mve_vrhaddq_uv16qi */
    case 3489:  /* mve_vrhaddq_sv16qi */
    case 3488:  /* mve_vqsubq_sv4si */
    case 3487:  /* mve_vqsubq_uv4si */
    case 3486:  /* mve_vqsubq_sv8hi */
    case 3485:  /* mve_vqsubq_uv8hi */
    case 3484:  /* mve_vqsubq_sv16qi */
    case 3483:  /* mve_vqsubq_uv16qi */
    case 3482:  /* mve_vqsubq_n_uv4si */
    case 3481:  /* mve_vqsubq_n_sv4si */
    case 3480:  /* mve_vqsubq_n_uv8hi */
    case 3479:  /* mve_vqsubq_n_sv8hi */
    case 3478:  /* mve_vqsubq_n_uv16qi */
    case 3477:  /* mve_vqsubq_n_sv16qi */
    case 3476:  /* mve_vqshluq_n_sv4si */
    case 3475:  /* mve_vqshluq_n_sv8hi */
    case 3474:  /* mve_vqshluq_n_sv16qi */
    case 3473:  /* mve_vqshlq_uv4si */
    case 3472:  /* mve_vqshlq_sv4si */
    case 3471:  /* mve_vqshlq_uv8hi */
    case 3470:  /* mve_vqshlq_sv8hi */
    case 3469:  /* mve_vqshlq_uv16qi */
    case 3468:  /* mve_vqshlq_sv16qi */
    case 3467:  /* mve_vqshlq_r_sv4si */
    case 3466:  /* mve_vqshlq_r_uv4si */
    case 3465:  /* mve_vqshlq_r_sv8hi */
    case 3464:  /* mve_vqshlq_r_uv8hi */
    case 3463:  /* mve_vqshlq_r_sv16qi */
    case 3462:  /* mve_vqshlq_r_uv16qi */
    case 3461:  /* mve_vqshlq_n_uv4si */
    case 3460:  /* mve_vqshlq_n_sv4si */
    case 3459:  /* mve_vqshlq_n_uv8hi */
    case 3458:  /* mve_vqshlq_n_sv8hi */
    case 3457:  /* mve_vqshlq_n_uv16qi */
    case 3456:  /* mve_vqshlq_n_sv16qi */
    case 3455:  /* mve_vqrshlq_uv4si */
    case 3454:  /* mve_vqrshlq_sv4si */
    case 3453:  /* mve_vqrshlq_uv8hi */
    case 3452:  /* mve_vqrshlq_sv8hi */
    case 3451:  /* mve_vqrshlq_uv16qi */
    case 3450:  /* mve_vqrshlq_sv16qi */
    case 3449:  /* mve_vqrshlq_n_uv4si */
    case 3448:  /* mve_vqrshlq_n_sv4si */
    case 3447:  /* mve_vqrshlq_n_uv8hi */
    case 3446:  /* mve_vqrshlq_n_sv8hi */
    case 3445:  /* mve_vqrshlq_n_uv16qi */
    case 3444:  /* mve_vqrshlq_n_sv16qi */
    case 3443:  /* mve_vqrdmulhq_sv4si */
    case 3442:  /* mve_vqrdmulhq_sv8hi */
    case 3441:  /* mve_vqrdmulhq_sv16qi */
    case 3440:  /* mve_vqrdmulhq_n_sv4si */
    case 3439:  /* mve_vqrdmulhq_n_sv8hi */
    case 3438:  /* mve_vqrdmulhq_n_sv16qi */
    case 3437:  /* mve_vqdmulhq_sv4si */
    case 3436:  /* mve_vqdmulhq_sv8hi */
    case 3435:  /* mve_vqdmulhq_sv16qi */
    case 3434:  /* mve_vqdmulhq_n_sv4si */
    case 3433:  /* mve_vqdmulhq_n_sv8hi */
    case 3432:  /* mve_vqdmulhq_n_sv16qi */
    case 3431:  /* mve_vqaddq_sv4si */
    case 3430:  /* mve_vqaddq_uv4si */
    case 3429:  /* mve_vqaddq_sv8hi */
    case 3428:  /* mve_vqaddq_uv8hi */
    case 3427:  /* mve_vqaddq_sv16qi */
    case 3426:  /* mve_vqaddq_uv16qi */
    case 3425:  /* mve_vqaddq_n_uv4si */
    case 3424:  /* mve_vqaddq_n_sv4si */
    case 3423:  /* mve_vqaddq_n_uv8hi */
    case 3422:  /* mve_vqaddq_n_sv8hi */
    case 3421:  /* mve_vqaddq_n_uv16qi */
    case 3420:  /* mve_vqaddq_n_sv16qi */
    case 3419:  /* mve_vorrq_sv4si */
    case 3418:  /* mve_vorrq_sv8hi */
    case 3417:  /* mve_vorrq_sv16qi */
    case 3416:  /* mve_vornq_sv4si */
    case 3415:  /* mve_vornq_sv8hi */
    case 3414:  /* mve_vornq_sv16qi */
    case 3413:  /* mve_vmulqv4si */
    case 3412:  /* mve_vmulqv8hi */
    case 3411:  /* mve_vmulqv16qi */
    case 3410:  /* mve_vmulq_sv4si */
    case 3409:  /* mve_vmulq_uv4si */
    case 3408:  /* mve_vmulq_sv8hi */
    case 3407:  /* mve_vmulq_uv8hi */
    case 3406:  /* mve_vmulq_sv16qi */
    case 3405:  /* mve_vmulq_uv16qi */
    case 3404:  /* mve_vmulq_n_sv4si */
    case 3403:  /* mve_vmulq_n_uv4si */
    case 3402:  /* mve_vmulq_n_sv8hi */
    case 3401:  /* mve_vmulq_n_uv8hi */
    case 3400:  /* mve_vmulq_n_sv16qi */
    case 3399:  /* mve_vmulq_n_uv16qi */
    case 3398:  /* mve_vmulltq_int_sv4si */
    case 3397:  /* mve_vmulltq_int_uv4si */
    case 3396:  /* mve_vmulltq_int_sv8hi */
    case 3395:  /* mve_vmulltq_int_uv8hi */
    case 3394:  /* mve_vmulltq_int_sv16qi */
    case 3393:  /* mve_vmulltq_int_uv16qi */
    case 3392:  /* mve_vmullbq_int_sv4si */
    case 3391:  /* mve_vmullbq_int_uv4si */
    case 3390:  /* mve_vmullbq_int_sv8hi */
    case 3389:  /* mve_vmullbq_int_uv8hi */
    case 3388:  /* mve_vmullbq_int_sv16qi */
    case 3387:  /* mve_vmullbq_int_uv16qi */
    case 3386:  /* mve_vmulhq_uv4si */
    case 3385:  /* mve_vmulhq_sv4si */
    case 3384:  /* mve_vmulhq_uv8hi */
    case 3383:  /* mve_vmulhq_sv8hi */
    case 3382:  /* mve_vmulhq_uv16qi */
    case 3381:  /* mve_vmulhq_sv16qi */
    case 3380:  /* mve_vmlsdavxq_sv4si */
    case 3379:  /* mve_vmlsdavxq_sv8hi */
    case 3378:  /* mve_vmlsdavxq_sv16qi */
    case 3377:  /* mve_vmlsdavq_sv4si */
    case 3376:  /* mve_vmlsdavq_sv8hi */
    case 3375:  /* mve_vmlsdavq_sv16qi */
    case 3374:  /* mve_vmladavxq_sv4si */
    case 3373:  /* mve_vmladavxq_sv8hi */
    case 3372:  /* mve_vmladavxq_sv16qi */
    case 3371:  /* mve_vmladavq_sv4si */
    case 3370:  /* mve_vmladavq_uv4si */
    case 3369:  /* mve_vmladavq_sv8hi */
    case 3368:  /* mve_vmladavq_uv8hi */
    case 3367:  /* mve_vmladavq_sv16qi */
    case 3366:  /* mve_vmladavq_uv16qi */
    case 3365:  /* mve_vminvq_sv4si */
    case 3364:  /* mve_vminvq_uv4si */
    case 3363:  /* mve_vminvq_sv8hi */
    case 3362:  /* mve_vminvq_uv8hi */
    case 3361:  /* mve_vminvq_sv16qi */
    case 3360:  /* mve_vminvq_uv16qi */
    case 3359:  /* mve_vminq_uv4si */
    case 3358:  /* mve_vminq_uv8hi */
    case 3357:  /* mve_vminq_uv16qi */
    case 3356:  /* mve_vminq_sv4si */
    case 3355:  /* mve_vminq_sv8hi */
    case 3354:  /* mve_vminq_sv16qi */
    case 3353:  /* mve_vminavq_sv4si */
    case 3352:  /* mve_vminavq_sv8hi */
    case 3351:  /* mve_vminavq_sv16qi */
    case 3350:  /* mve_vminaq_sv4si */
    case 3349:  /* mve_vminaq_sv8hi */
    case 3348:  /* mve_vminaq_sv16qi */
    case 3347:  /* mve_vmaxvq_sv4si */
    case 3346:  /* mve_vmaxvq_uv4si */
    case 3345:  /* mve_vmaxvq_sv8hi */
    case 3344:  /* mve_vmaxvq_uv8hi */
    case 3343:  /* mve_vmaxvq_sv16qi */
    case 3342:  /* mve_vmaxvq_uv16qi */
    case 3341:  /* mve_vmaxq_uv4si */
    case 3340:  /* mve_vmaxq_uv8hi */
    case 3339:  /* mve_vmaxq_uv16qi */
    case 3338:  /* mve_vmaxq_sv4si */
    case 3337:  /* mve_vmaxq_sv8hi */
    case 3336:  /* mve_vmaxq_sv16qi */
    case 3335:  /* mve_vmaxavq_sv4si */
    case 3334:  /* mve_vmaxavq_sv8hi */
    case 3333:  /* mve_vmaxavq_sv16qi */
    case 3332:  /* mve_vmaxaq_sv4si */
    case 3331:  /* mve_vmaxaq_sv8hi */
    case 3330:  /* mve_vmaxaq_sv16qi */
    case 3329:  /* mve_vhsubq_uv4si */
    case 3328:  /* mve_vhsubq_sv4si */
    case 3327:  /* mve_vhsubq_uv8hi */
    case 3326:  /* mve_vhsubq_sv8hi */
    case 3325:  /* mve_vhsubq_uv16qi */
    case 3324:  /* mve_vhsubq_sv16qi */
    case 3323:  /* mve_vhsubq_n_sv4si */
    case 3322:  /* mve_vhsubq_n_uv4si */
    case 3321:  /* mve_vhsubq_n_sv8hi */
    case 3320:  /* mve_vhsubq_n_uv8hi */
    case 3319:  /* mve_vhsubq_n_sv16qi */
    case 3318:  /* mve_vhsubq_n_uv16qi */
    case 3317:  /* mve_vhcaddq_rot90_sv4si */
    case 3316:  /* mve_vhcaddq_rot90_sv8hi */
    case 3315:  /* mve_vhcaddq_rot90_sv16qi */
    case 3314:  /* mve_vhcaddq_rot270_sv4si */
    case 3313:  /* mve_vhcaddq_rot270_sv8hi */
    case 3312:  /* mve_vhcaddq_rot270_sv16qi */
    case 3311:  /* mve_vhaddq_uv4si */
    case 3310:  /* mve_vhaddq_sv4si */
    case 3309:  /* mve_vhaddq_uv8hi */
    case 3308:  /* mve_vhaddq_sv8hi */
    case 3307:  /* mve_vhaddq_uv16qi */
    case 3306:  /* mve_vhaddq_sv16qi */
    case 3305:  /* mve_vhaddq_n_sv4si */
    case 3304:  /* mve_vhaddq_n_uv4si */
    case 3303:  /* mve_vhaddq_n_sv8hi */
    case 3302:  /* mve_vhaddq_n_uv8hi */
    case 3301:  /* mve_vhaddq_n_sv16qi */
    case 3300:  /* mve_vhaddq_n_uv16qi */
    case 3299:  /* mve_veorq_uv4si */
    case 3298:  /* mve_veorq_uv8hi */
    case 3297:  /* mve_veorq_uv16qi */
    case 3296:  /* mve_vcaddq_rot270v4si */
    case 3295:  /* mve_vcaddq_rot90v4si */
    case 3294:  /* mve_vcaddq_rot270v8hi */
    case 3293:  /* mve_vcaddq_rot90v8hi */
    case 3292:  /* mve_vcaddq_rot270v16qi */
    case 3291:  /* mve_vcaddq_rot90v16qi */
    case 3290:  /* mve_vbrsrq_n_sv4si */
    case 3289:  /* mve_vbrsrq_n_uv4si */
    case 3288:  /* mve_vbrsrq_n_sv8hi */
    case 3287:  /* mve_vbrsrq_n_uv8hi */
    case 3286:  /* mve_vbrsrq_n_sv16qi */
    case 3285:  /* mve_vbrsrq_n_uv16qi */
    case 3284:  /* mve_vbicq_uv4si */
    case 3283:  /* mve_vbicq_uv8hi */
    case 3282:  /* mve_vbicq_uv16qi */
    case 3281:  /* mve_vandq_uv4si */
    case 3280:  /* mve_vandq_uv8hi */
    case 3279:  /* mve_vandq_uv16qi */
    case 3278:  /* mve_vaddvq_p_sv4si */
    case 3277:  /* mve_vaddvq_p_uv4si */
    case 3276:  /* mve_vaddvq_p_sv8hi */
    case 3275:  /* mve_vaddvq_p_uv8hi */
    case 3274:  /* mve_vaddvq_p_sv16qi */
    case 3273:  /* mve_vaddvq_p_uv16qi */
    case 3272:  /* mve_vaddvaq_uv4si */
    case 3271:  /* mve_vaddvaq_sv4si */
    case 3270:  /* mve_vaddvaq_uv8hi */
    case 3269:  /* mve_vaddvaq_sv8hi */
    case 3268:  /* mve_vaddvaq_uv16qi */
    case 3267:  /* mve_vaddvaq_sv16qi */
    case 3266:  /* mve_vaddq_n_uv4si */
    case 3265:  /* mve_vaddq_n_sv4si */
    case 3264:  /* mve_vaddq_n_uv8hi */
    case 3263:  /* mve_vaddq_n_sv8hi */
    case 3262:  /* mve_vaddq_n_uv16qi */
    case 3261:  /* mve_vaddq_n_sv16qi */
    case 3260:  /* mve_vabdq_uv4si */
    case 3259:  /* mve_vabdq_sv4si */
    case 3258:  /* mve_vabdq_uv8hi */
    case 3257:  /* mve_vabdq_sv8hi */
    case 3256:  /* mve_vabdq_uv16qi */
    case 3255:  /* mve_vabdq_sv16qi */
    case 3254:  /* mve_vcmpneq_n_v4si */
    case 3253:  /* mve_vcmpltq_n_v4si */
    case 3252:  /* mve_vcmpleq_n_v4si */
    case 3251:  /* mve_vcmphiq_n_v4si */
    case 3250:  /* mve_vcmpgtq_n_v4si */
    case 3249:  /* mve_vcmpcsq_n_v4si */
    case 3248:  /* mve_vcmpgeq_n_v4si */
    case 3247:  /* mve_vcmpeqq_n_v4si */
    case 3246:  /* mve_vcmpneq_n_v8hi */
    case 3245:  /* mve_vcmpltq_n_v8hi */
    case 3244:  /* mve_vcmpleq_n_v8hi */
    case 3243:  /* mve_vcmphiq_n_v8hi */
    case 3242:  /* mve_vcmpgtq_n_v8hi */
    case 3241:  /* mve_vcmpcsq_n_v8hi */
    case 3240:  /* mve_vcmpgeq_n_v8hi */
    case 3239:  /* mve_vcmpeqq_n_v8hi */
    case 3238:  /* mve_vcmpneq_n_v16qi */
    case 3237:  /* mve_vcmpltq_n_v16qi */
    case 3236:  /* mve_vcmpleq_n_v16qi */
    case 3235:  /* mve_vcmphiq_n_v16qi */
    case 3234:  /* mve_vcmpgtq_n_v16qi */
    case 3233:  /* mve_vcmpcsq_n_v16qi */
    case 3232:  /* mve_vcmpgeq_n_v16qi */
    case 3231:  /* mve_vcmpeqq_n_v16qi */
    case 3230:  /* mve_vcmpneq_v4si */
    case 3229:  /* mve_vcmpltq_v4si */
    case 3228:  /* mve_vcmpleq_v4si */
    case 3227:  /* mve_vcmphiq_v4si */
    case 3226:  /* mve_vcmpgtq_v4si */
    case 3225:  /* mve_vcmpcsq_v4si */
    case 3224:  /* mve_vcmpgeq_v4si */
    case 3223:  /* mve_vcmpeqq_v4si */
    case 3222:  /* mve_vcmpneq_v8hi */
    case 3221:  /* mve_vcmpltq_v8hi */
    case 3220:  /* mve_vcmpleq_v8hi */
    case 3219:  /* mve_vcmphiq_v8hi */
    case 3218:  /* mve_vcmpgtq_v8hi */
    case 3217:  /* mve_vcmpcsq_v8hi */
    case 3216:  /* mve_vcmpgeq_v8hi */
    case 3215:  /* mve_vcmpeqq_v8hi */
    case 3214:  /* mve_vcmpneq_v16qi */
    case 3213:  /* mve_vcmpltq_v16qi */
    case 3212:  /* mve_vcmpleq_v16qi */
    case 3211:  /* mve_vcmphiq_v16qi */
    case 3210:  /* mve_vcmpgtq_v16qi */
    case 3209:  /* mve_vcmpcsq_v16qi */
    case 3208:  /* mve_vcmpgeq_v16qi */
    case 3207:  /* mve_vcmpeqq_v16qi */
    case 3206:  /* mve_vaddlvq_p_uv4si */
    case 3205:  /* mve_vaddlvq_p_sv4si */
    case 3204:  /* mve_vcvtq_n_from_f_uv4si */
    case 3203:  /* mve_vcvtq_n_from_f_sv4si */
    case 3202:  /* mve_vcvtq_n_from_f_uv8hi */
    case 3201:  /* mve_vcvtq_n_from_f_sv8hi */
    case 3200:  /* mve_vshrq_n_uv4si_imm */
    case 3199:  /* mve_vshrq_n_uv8hi_imm */
    case 3198:  /* mve_vshrq_n_uv16qi_imm */
    case 3197:  /* mve_vshrq_n_sv4si_imm */
    case 3196:  /* mve_vshrq_n_sv8hi_imm */
    case 3195:  /* mve_vshrq_n_sv16qi_imm */
    case 3194:  /* mve_vshrq_n_uv4si */
    case 3193:  /* mve_vshrq_n_sv4si */
    case 3192:  /* mve_vshrq_n_uv8hi */
    case 3191:  /* mve_vshrq_n_sv8hi */
    case 3190:  /* mve_vshrq_n_uv16qi */
    case 3189:  /* mve_vshrq_n_sv16qi */
    case 3188:  /* mve_vcreateq_sv2di */
    case 3187:  /* mve_vcreateq_uv2di */
    case 3186:  /* mve_vcreateq_sv4si */
    case 3185:  /* mve_vcreateq_uv4si */
    case 3184:  /* mve_vcreateq_sv8hi */
    case 3183:  /* mve_vcreateq_uv8hi */
    case 3182:  /* mve_vcreateq_sv16qi */
    case 3181:  /* mve_vcreateq_uv16qi */
    case 3180:  /* mve_vcreateq_fv4sf */
    case 3179:  /* mve_vcreateq_fv8hf */
    case 3178:  /* mve_vcvtq_n_to_f_uv4sf */
    case 3177:  /* mve_vcvtq_n_to_f_sv4sf */
    case 3176:  /* mve_vcvtq_n_to_f_uv8hf */
    case 3175:  /* mve_vcvtq_n_to_f_sv8hf */
    case 3174:  /* mve_vbrsrq_n_fv4sf */
    case 3173:  /* mve_vbrsrq_n_fv8hf */
    case 3172:  /* mve_vsubq_n_fv4sf */
    case 3171:  /* mve_vsubq_n_fv8hf */
    case 3170:  /* mve_vpnotv16bi */
    case 3169:  /* mve_vctp64qv2qi */
    case 3168:  /* mve_vctp32qv4bi */
    case 3167:  /* mve_vctp16qv8bi */
    case 3166:  /* mve_vctp8qv16bi */
    case 3165:  /* mve_vaddlvq_sv4si */
    case 3164:  /* mve_vaddlvq_uv4si */
    case 3163:  /* mve_vrev16q_sv16qi */
    case 3162:  /* mve_vrev16q_uv16qi */
    case 3161:  /* mve_vmvnq_n_sv4si */
    case 3160:  /* mve_vmvnq_n_uv4si */
    case 3159:  /* mve_vmvnq_n_sv8hi */
    case 3158:  /* mve_vmvnq_n_uv8hi */
    case 3157:  /* mve_vcvtaq_sv4si */
    case 3156:  /* mve_vcvtaq_uv4si */
    case 3155:  /* mve_vcvtaq_sv8hi */
    case 3154:  /* mve_vcvtaq_uv8hi */
    case 3153:  /* mve_vcvtmq_uv4si */
    case 3152:  /* mve_vcvtmq_sv4si */
    case 3151:  /* mve_vcvtmq_uv8hi */
    case 3150:  /* mve_vcvtmq_sv8hi */
    case 3149:  /* mve_vcvtnq_uv4si */
    case 3148:  /* mve_vcvtnq_sv4si */
    case 3147:  /* mve_vcvtnq_uv8hi */
    case 3146:  /* mve_vcvtnq_sv8hi */
    case 3145:  /* mve_vcvtpq_uv4si */
    case 3144:  /* mve_vcvtpq_sv4si */
    case 3143:  /* mve_vcvtpq_uv8hi */
    case 3142:  /* mve_vcvtpq_sv8hi */
    case 3141:  /* mve_vmovlbq_uv8hi */
    case 3140:  /* mve_vmovlbq_sv8hi */
    case 3139:  /* mve_vmovlbq_uv16qi */
    case 3138:  /* mve_vmovlbq_sv16qi */
    case 3137:  /* mve_vmovltq_sv8hi */
    case 3136:  /* mve_vmovltq_uv8hi */
    case 3135:  /* mve_vmovltq_sv16qi */
    case 3134:  /* mve_vmovltq_uv16qi */
    case 3133:  /* mve_vrev32q_sv8hi */
    case 3132:  /* mve_vrev32q_uv8hi */
    case 3131:  /* mve_vrev32q_sv16qi */
    case 3130:  /* mve_vrev32q_uv16qi */
    case 3129:  /* mve_vabsq_sv4si */
    case 3128:  /* mve_vabsq_sv8hi */
    case 3127:  /* mve_vabsq_sv16qi */
    case 3126:  /* mve_vaddvq_sv4si */
    case 3125:  /* mve_vaddvq_uv4si */
    case 3124:  /* mve_vaddvq_sv8hi */
    case 3123:  /* mve_vaddvq_uv8hi */
    case 3122:  /* mve_vaddvq_sv16qi */
    case 3121:  /* mve_vaddvq_uv16qi */
    case 3120:  /* mve_vclsq_sv4si */
    case 3119:  /* mve_vclsq_sv8hi */
    case 3118:  /* mve_vclsq_sv16qi */
    case 3117:  /* mve_vclzq_sv4si */
    case 3116:  /* mve_vclzq_sv8hi */
    case 3115:  /* mve_vclzq_sv16qi */
    case 3114:  /* mve_vdupq_n_sv4si */
    case 3113:  /* mve_vdupq_n_uv4si */
    case 3112:  /* mve_vdupq_n_sv8hi */
    case 3111:  /* mve_vdupq_n_uv8hi */
    case 3110:  /* mve_vdupq_n_sv16qi */
    case 3109:  /* mve_vdupq_n_uv16qi */
    case 3108:  /* mve_vmvnq_uv4si */
    case 3107:  /* mve_vmvnq_uv8hi */
    case 3106:  /* mve_vmvnq_uv16qi */
    case 3105:  /* mve_vnegq_sv4si */
    case 3104:  /* mve_vnegq_sv8hi */
    case 3103:  /* mve_vnegq_sv16qi */
    case 3102:  /* mve_vqabsq_sv4si */
    case 3101:  /* mve_vqabsq_sv8hi */
    case 3100:  /* mve_vqabsq_sv16qi */
    case 3099:  /* mve_vqnegq_sv4si */
    case 3098:  /* mve_vqnegq_sv8hi */
    case 3097:  /* mve_vqnegq_sv16qi */
    case 3096:  /* mve_vcvtq_from_f_uv4si */
    case 3095:  /* mve_vcvtq_from_f_sv4si */
    case 3094:  /* mve_vcvtq_from_f_uv8hi */
    case 3093:  /* mve_vcvtq_from_f_sv8hi */
    case 3092:  /* mve_vrev64q_uv4si */
    case 3091:  /* mve_vrev64q_sv4si */
    case 3090:  /* mve_vrev64q_uv8hi */
    case 3089:  /* mve_vrev64q_sv8hi */
    case 3088:  /* mve_vrev64q_uv16qi */
    case 3087:  /* mve_vrev64q_sv16qi */
    case 3086:  /* mve_vcvtq_to_f_uv4sf */
    case 3085:  /* mve_vcvtq_to_f_sv4sf */
    case 3084:  /* mve_vcvtq_to_f_uv8hf */
    case 3083:  /* mve_vcvtq_to_f_sv8hf */
    case 3082:  /* mve_vcvtbq_f32_f16v4sf */
    case 3081:  /* mve_vcvttq_f32_f16v4sf */
    case 3080:  /* mve_vrev32q_fv8hf */
    case 3079:  /* mve_vabsq_fv4sf */
    case 3078:  /* mve_vabsq_fv8hf */
    case 3077:  /* mve_vdupq_n_fv4sf */
    case 3076:  /* mve_vdupq_n_fv8hf */
    case 3075:  /* mve_vnegq_fv4sf */
    case 3074:  /* mve_vnegq_fv8hf */
    case 3073:  /* mve_vrev64q_fv4sf */
    case 3072:  /* mve_vrev64q_fv8hf */
    case 3071:  /* mve_vrndaq_fv4sf */
    case 3070:  /* mve_vrndaq_fv8hf */
    case 3069:  /* mve_vrndmq_fv4sf */
    case 3068:  /* mve_vrndmq_fv8hf */
    case 3067:  /* mve_vrndnq_fv4sf */
    case 3066:  /* mve_vrndnq_fv8hf */
    case 3065:  /* mve_vrndpq_fv4sf */
    case 3064:  /* mve_vrndpq_fv8hf */
    case 3063:  /* mve_vrndq_fv4sf */
    case 3062:  /* mve_vrndq_fv8hf */
    case 3061:  /* mve_vrndxq_fv4sf */
    case 3060:  /* mve_vrndxq_fv8hf */
    case 3059:  /* mve_vrndq_m_fv4sf */
    case 3058:  /* mve_vrndq_m_fv8hf */
    case 3057:  /* mve_vst4qv4sf */
    case 3056:  /* mve_vst4qv8hf */
    case 3055:  /* mve_vst4qv4si */
    case 3054:  /* mve_vst4qv8hi */
    case 3053:  /* mve_vst4qv16qi */
    case 3052:  /* *mve_vdupv2df */
    case 3051:  /* *mve_vdupv4sf */
    case 3050:  /* *mve_vdupv8hf */
    case 3049:  /* *mve_vdupv2di */
    case 3048:  /* *mve_vdupv4si */
    case 3047:  /* *mve_vdupv8hi */
    case 3046:  /* *mve_vdupv16qi */
    case 2979:  /* arm_store_release_exclusivesi */
    case 2978:  /* arm_store_release_exclusivehi */
    case 2977:  /* arm_store_release_exclusiveqi */
    case 2976:  /* arm_store_release_exclusivedi */
    case 2975:  /* arm_store_exclusivedi */
    case 2974:  /* arm_store_exclusivesi */
    case 2973:  /* arm_store_exclusivehi */
    case 2972:  /* arm_store_exclusiveqi */
    case 2971:  /* arm_load_acquire_exclusivedi */
    case 2970:  /* arm_load_exclusivedi */
    case 2969:  /* arm_load_acquire_exclusivesi */
    case 2968:  /* arm_load_exclusivesi */
    case 2967:  /* arm_load_acquire_exclusivehi */
    case 2966:  /* arm_load_acquire_exclusiveqi */
    case 2965:  /* arm_load_exclusivehi */
    case 2964:  /* arm_load_exclusiveqi */
    case 2963:  /* atomic_nand_fetchdi */
    case 2962:  /* atomic_nand_fetchsi */
    case 2961:  /* atomic_nand_fetchhi */
    case 2960:  /* atomic_nand_fetchqi */
    case 2959:  /* atomic_and_fetchdi */
    case 2958:  /* atomic_xor_fetchdi */
    case 2957:  /* atomic_or_fetchdi */
    case 2956:  /* atomic_sub_fetchdi */
    case 2955:  /* atomic_add_fetchdi */
    case 2954:  /* atomic_and_fetchsi */
    case 2953:  /* atomic_xor_fetchsi */
    case 2952:  /* atomic_or_fetchsi */
    case 2951:  /* atomic_sub_fetchsi */
    case 2950:  /* atomic_add_fetchsi */
    case 2949:  /* atomic_and_fetchhi */
    case 2948:  /* atomic_xor_fetchhi */
    case 2947:  /* atomic_or_fetchhi */
    case 2946:  /* atomic_sub_fetchhi */
    case 2945:  /* atomic_add_fetchhi */
    case 2944:  /* atomic_and_fetchqi */
    case 2943:  /* atomic_xor_fetchqi */
    case 2942:  /* atomic_or_fetchqi */
    case 2941:  /* atomic_sub_fetchqi */
    case 2940:  /* atomic_add_fetchqi */
    case 2939:  /* atomic_fetch_nanddi */
    case 2938:  /* atomic_fetch_nandsi */
    case 2937:  /* atomic_fetch_nandhi */
    case 2936:  /* atomic_fetch_nandqi */
    case 2935:  /* atomic_fetch_anddi */
    case 2934:  /* atomic_fetch_xordi */
    case 2933:  /* atomic_fetch_ordi */
    case 2932:  /* atomic_fetch_subdi */
    case 2931:  /* atomic_fetch_adddi */
    case 2930:  /* atomic_fetch_andsi */
    case 2929:  /* atomic_fetch_xorsi */
    case 2928:  /* atomic_fetch_orsi */
    case 2927:  /* atomic_fetch_subsi */
    case 2926:  /* atomic_fetch_addsi */
    case 2925:  /* atomic_fetch_andhi */
    case 2924:  /* atomic_fetch_xorhi */
    case 2923:  /* atomic_fetch_orhi */
    case 2922:  /* atomic_fetch_subhi */
    case 2921:  /* atomic_fetch_addhi */
    case 2920:  /* atomic_fetch_andqi */
    case 2919:  /* atomic_fetch_xorqi */
    case 2918:  /* atomic_fetch_orqi */
    case 2917:  /* atomic_fetch_subqi */
    case 2916:  /* atomic_fetch_addqi */
    case 2915:  /* atomic_nanddi */
    case 2914:  /* atomic_nandsi */
    case 2913:  /* atomic_nandhi */
    case 2912:  /* atomic_nandqi */
    case 2911:  /* atomic_anddi */
    case 2910:  /* atomic_xordi */
    case 2909:  /* atomic_ordi */
    case 2908:  /* atomic_subdi */
    case 2907:  /* atomic_adddi */
    case 2906:  /* atomic_andsi */
    case 2905:  /* atomic_xorsi */
    case 2904:  /* atomic_orsi */
    case 2903:  /* atomic_subsi */
    case 2902:  /* atomic_addsi */
    case 2901:  /* atomic_andhi */
    case 2900:  /* atomic_xorhi */
    case 2899:  /* atomic_orhi */
    case 2898:  /* atomic_subhi */
    case 2897:  /* atomic_addhi */
    case 2896:  /* atomic_andqi */
    case 2895:  /* atomic_xorqi */
    case 2894:  /* atomic_orqi */
    case 2893:  /* atomic_subqi */
    case 2892:  /* atomic_addqi */
    case 2891:  /* atomic_exchangedi */
    case 2890:  /* atomic_exchangesi */
    case 2889:  /* atomic_exchangehi */
    case 2888:  /* atomic_exchangeqi */
    case 2887:  /* atomic_compare_and_swapt1di_1 */
    case 2886:  /* atomic_compare_and_swapt1si_1 */
    case 2885:  /* atomic_compare_and_swap32di_1 */
    case 2884:  /* atomic_compare_and_swap32si_1 */
    case 2883:  /* atomic_compare_and_swapt1hi_1 */
    case 2882:  /* atomic_compare_and_swapt1qi_1 */
    case 2881:  /* atomic_compare_and_swap32hi_1 */
    case 2880:  /* atomic_compare_and_swap32qi_1 */
    case 2879:  /* arm_atomic_loaddi2_ldrd */
    case 2878:  /* atomic_storesi */
    case 2877:  /* atomic_storehi */
    case 2876:  /* atomic_storeqi */
    case 2875:  /* atomic_loadsi */
    case 2874:  /* atomic_loadhi */
    case 2873:  /* atomic_loadqi */
    case 2872:  /* *memory_barrier */
    case 2842:  /* neon_vbfcvtbf_cvtmodesf */
    case 2841:  /* neon_vbfcvtbf_cvtmodev2si */
    case 1069:  /* dls_insn */
    case 1067:  /* thumb2_lsrl */
    case 1066:  /* thumb2_lsll */
    case 1065:  /* thumb2_asrl */
    case 1064:  /* *clear_multiple */
    case 1063:  /* *clear_apsr */
    case 1044:  /* thumb2_eh_return */
    case 979:  /* *cstoresi_ne0_thumb1_insn */
    case 933:  /* arm_vcx3adi */
    case 932:  /* arm_vcx3asi */
    case 931:  /* arm_vcx3di */
    case 930:  /* arm_vcx3si */
    case 929:  /* arm_vcx2adi */
    case 928:  /* arm_vcx2asi */
    case 927:  /* arm_vcx2di */
    case 926:  /* arm_vcx2si */
    case 925:  /* arm_vcx1adi */
    case 924:  /* arm_vcx1asi */
    case 923:  /* arm_vcx1di */
    case 922:  /* arm_vcx1si */
    case 921:  /* no_literal_pool_sf_immediate */
    case 920:  /* no_literal_pool_df_immediate */
    case 857:  /* *cmpdf_trap_split_vfp */
    case 856:  /* *cmpdf_split_vfp */
    case 855:  /* *cmpsf_trap_split_vfp */
    case 854:  /* *cmpsf_split_vfp */
    case 510:  /* bti_nop */
    case 509:  /* aut_nop */
    case 508:  /* pacbti_nop */
    case 507:  /* pac_nop */
    case 505:  /* arm_mrrc2 */
    case 504:  /* arm_mrrc */
    case 503:  /* arm_mcrr2 */
    case 502:  /* arm_mcrr */
    case 501:  /* arm_mrc2 */
    case 500:  /* arm_mrc */
    case 499:  /* arm_mcr2 */
    case 498:  /* arm_mcr */
    case 497:  /* *stc */
    case 496:  /* *stc */
    case 495:  /* *stc */
    case 494:  /* *stc */
    case 493:  /* *ldc */
    case 492:  /* *ldc */
    case 491:  /* *ldc */
    case 490:  /* *ldc */
    case 489:  /* arm_cdp2 */
    case 488:  /* arm_cdp */
    case 487:  /* *load_multiple */
    case 404:  /* arm_eh_return */
    case 401:  /* ctzsi2 */
    case 318:  /* trap */
    case 310:  /* *stack_protect_combined_test_insn */
    case 308:  /* *stack_protect_combined_set_insn */
    case 289:  /* restore_pic_register_after_call */
    case 150:  /* arm_cx3adi */
    case 149:  /* arm_cx3asi */
    case 148:  /* arm_cx3di */
    case 147:  /* arm_cx3si */
    case 146:  /* arm_cx2adi */
    case 145:  /* arm_cx2asi */
    case 144:  /* arm_cx2di */
    case 143:  /* arm_cx2si */
    case 142:  /* arm_cx1adi */
    case 141:  /* arm_cx1asi */
    case 140:  /* arm_cx1di */
    case 139:  /* arm_cx1si */
    case 132:  /* arm_set_apsr */
    case 131:  /* arm_get_apsr */
    case 54:  /* subvsi3_borrow */
    case 52:  /* usubvsi3_borrow */
      if ((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))))))
        {
	  return 27 /* 0x1b */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    case -1:
      if (GET_CODE (PATTERN (insn)) != ASM_INPUT
          && asm_noperands (PATTERN (insn)) < 0)
        fatal_insn_not_found (insn);
      /* FALLTHRU */
    default:
      extract_constrain_insn_cached (insn);
      if ((cached_type = get_attr_type (insn)) == TYPE_NO_INSN)
        {
	  return 0;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (get_attr_wmmxt_alu_c1 (insn) == WMMXT_ALU_C1_YES))
        {
	  return 1;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (get_attr_wmmxt_pack (insn) == WMMXT_PACK_YES))
        {
	  return 2;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (get_attr_wmmxt_shift (insn) == WMMXT_SHIFT_YES))
        {
	  return 3;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (get_attr_wmmxt_transfer_c1 (insn) == WMMXT_TRANSFER_C1_YES))
        {
	  return 4;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (get_attr_wmmxt_transfer_c2 (insn) == WMMXT_TRANSFER_C2_YES))
        {
	  return 5;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (get_attr_wmmxt_alu_c2 (insn) == WMMXT_ALU_C2_YES))
        {
	  return 6;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (get_attr_wmmxt_alu_c3 (insn) == WMMXT_ALU_C3_YES))
        {
	  return 7;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (get_attr_wmmxt_transfer_c3 (insn) == WMMXT_TRANSFER_C3_YES))
        {
	  return 8;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (get_attr_wmmxt_mult_c1 (insn) == WMMXT_MULT_C1_YES))
        {
	  return 9;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (get_attr_wmmxt_mult_c2 (insn) == WMMXT_MULT_C2_YES))
        {
	  return 10 /* 0xa */;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (cached_type == TYPE_WMMX_WSTR))
        {
	  return 11 /* 0xb */;
        }
      else if (((
#line 56 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/marvell-f-iwmmxt.md"
(arm_arch_iwmmxt))) && (cached_type == TYPE_WMMX_WLDR))
        {
	  return 12 /* 0xc */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 332 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_tune_wbuf)) == (
(MODEL_WBUF_YES)))) && (cached_type == TYPE_STORE_4))
        {
	  return 13 /* 0xd */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 332 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_tune_wbuf)) == (
(MODEL_WBUF_YES)))) && (cached_type == TYPE_STORE_8))
        {
	  return 14 /* 0xe */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 332 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_tune_wbuf)) == (
(MODEL_WBUF_YES)))) && (cached_type == TYPE_STORE_12))
        {
	  return 15 /* 0xf */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 332 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_tune_wbuf)) == (
(MODEL_WBUF_YES)))) && (cached_type == TYPE_STORE_16))
        {
	  return 16 /* 0x10 */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 332 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_tune_wbuf)) == (
(MODEL_WBUF_NO)))) && (cached_type == TYPE_STORE_8))
        {
	  return 17 /* 0x11 */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 332 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_tune_wbuf)) == (
(MODEL_WBUF_NO)))) && (cached_type == TYPE_STORE_12))
        {
	  return 18 /* 0x12 */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 332 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_tune_wbuf)) == (
(MODEL_WBUF_NO)))) && (cached_type == TYPE_STORE_16))
        {
	  return 19 /* 0x13 */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 289 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_ld_sched)) == (
(LDSCHED_YES)))) && (cached_type == TYPE_STORE_4))
        {
	  return 20 /* 0x14 */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 289 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_ld_sched)) == (
(LDSCHED_YES)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)) && ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XSCALE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_IWMMXT)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_IWMMXT2))))))
        {
	  return 21 /* 0x15 */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 289 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_ld_sched)) == (
(LDSCHED_YES)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)) && (! ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XSCALE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_IWMMXT)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_IWMMXT2)))))))
        {
	  return 22 /* 0x16 */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (! (((
#line 289 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_ld_sched)) == (
(LDSCHED_YES))))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16) || (cached_type == TYPE_STORE_4)))
        {
	  return 23 /* 0x17 */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 289 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_ld_sched)) == (
(LDSCHED_NO)))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 24 /* 0x18 */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 289 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_ld_sched)) == (
(LDSCHED_YES)))) && (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_STRONGARM)))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 25 /* 0x19 */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (((
#line 289 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_ld_sched)) == (
(LDSCHED_YES)))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_STRONGARM))))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 26 /* 0x1a */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && ((cached_core_cycles = get_attr_core_cycles (insn)) == CORE_CYCLES_MULTI) && (! ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16) || (cached_type == TYPE_STORE_4) || (cached_type == TYPE_STORE_8) || (cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16))) && (! (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES))))
        {
	  return 27 /* 0x1b */;
        }
      else if (((! (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA12)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1))))) || (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && ((cached_core_cycles = get_attr_core_cycles (insn)) == CORE_CYCLES_SINGLE))
        {
	  return 28 /* 0x1c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 29 /* 0x1d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 30 /* 0x1e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && ((cached_type == TYPE_SMLALXY) || (cached_type == TYPE_MUL) || (cached_type == TYPE_MLA)))
        {
	  return 31 /* 0x1f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && ((cached_type == TYPE_MULS) || (cached_type == TYPE_MLAS)))
        {
	  return 32 /* 0x20 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && ((cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMLAL)))
        {
	  return 33 /* 0x21 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && ((cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMLALS) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_SMLALS)))
        {
	  return 34 /* 0x22 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && ((cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMLAWX)))
        {
	  return 35 /* 0x23 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && (cached_type == TYPE_SMLALXY))
        {
	  return 36 /* 0x24 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_BYTE)))
        {
	  return 37 /* 0x25 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && (cached_type == TYPE_STORE_4))
        {
	  return 38 /* 0x26 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 39 /* 0x27 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && (cached_type == TYPE_LOAD_12))
        {
	  return 40 /* 0x28 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && (cached_type == TYPE_LOAD_16))
        {
	  return 41 /* 0x29 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && (cached_type == TYPE_STORE_8))
        {
	  return 42 /* 0x2a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && (cached_type == TYPE_STORE_12))
        {
	  return 43 /* 0x2b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && (cached_type == TYPE_STORE_16))
        {
	  return 44 /* 0x2c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && (cached_type == TYPE_BRANCH))
        {
	  return 45 /* 0x2d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM926EJS)))) && (cached_type == TYPE_CALL))
        {
	  return 46 /* 0x2e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 47 /* 0x2f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 48 /* 0x30 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 49 /* 0x31 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMULWY)))
        {
	  return 50 /* 0x32 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMLALXY) || (cached_type == TYPE_SMLAWX)))
        {
	  return 51 /* 0x33 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_SMLALXY) || (cached_type == TYPE_MUL) || (cached_type == TYPE_MLA)))
        {
	  return 52 /* 0x34 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_MULS) || (cached_type == TYPE_MLAS)))
        {
	  return 53 /* 0x35 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMLAL)))
        {
	  return 54 /* 0x36 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMLALS) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_SMLALS)))
        {
	  return 55 /* 0x37 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 56 /* 0x38 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (cached_type == TYPE_STORE_4))
        {
	  return 57 /* 0x39 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 58 /* 0x3a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (cached_type == TYPE_STORE_8))
        {
	  return 59 /* 0x3b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 60 /* 0x3c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 61 /* 0x3d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (cached_type == TYPE_BRANCH))
        {
	  return 62 /* 0x3e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (cached_type == TYPE_CALL))
        {
	  return 63 /* 0x3f */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && ((cached_type == TYPE_FMOV) || (cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD)))
        {
	  return 64 /* 0x40 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && ((cached_type == TYPE_FADDD) || (cached_type == TYPE_FADDS)))
        {
	  return 65 /* 0x41 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && ((cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTI2F) || (cached_type == TYPE_F_CVTF2I)))
        {
	  return 66 /* 0x42 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && ((cached_type == TYPE_FMULS) || (cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS) || (cached_type == TYPE_FMULD) || (cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 67 /* 0x43 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 68 /* 0x44 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 69 /* 0x45 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (cached_type == TYPE_F_LOADS))
        {
	  return 70 /* 0x46 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (cached_type == TYPE_F_LOADD))
        {
	  return 71 /* 0x47 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && ((cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 72 /* 0x48 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (cached_type == TYPE_F_STORES))
        {
	  return 73 /* 0x49 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (cached_type == TYPE_F_STORED))
        {
	  return 74 /* 0x4a */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && ((cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC)))
        {
	  return 75 /* 0x4b */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E)))) && (((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))))) && (cached_type == TYPE_F_FLAG))
        {
	  return 76 /* 0x4c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 77 /* 0x4d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 78 /* 0x4e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 79 /* 0x4f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMULWY)))
        {
	  return 80 /* 0x50 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMLALXY) || (cached_type == TYPE_SMLAWX)))
        {
	  return 81 /* 0x51 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_SMLALXY) || (cached_type == TYPE_MUL) || (cached_type == TYPE_MLA)))
        {
	  return 82 /* 0x52 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_MULS) || (cached_type == TYPE_MLAS)))
        {
	  return 83 /* 0x53 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMLAL)))
        {
	  return 84 /* 0x54 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMLALS) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_SMLALS)))
        {
	  return 85 /* 0x55 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 86 /* 0x56 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && (cached_type == TYPE_STORE_4))
        {
	  return 87 /* 0x57 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 88 /* 0x58 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && (cached_type == TYPE_STORE_8))
        {
	  return 89 /* 0x59 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 90 /* 0x5a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 91 /* 0x5b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && (cached_type == TYPE_BRANCH))
        {
	  return 92 /* 0x5c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1026EJS)))) && (cached_type == TYPE_CALL))
        {
	  return 93 /* 0x5d */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 94 /* 0x5e */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 95 /* 0x5f */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 96 /* 0x60 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_MUL) || (cached_type == TYPE_MLA)))
        {
	  return 97 /* 0x61 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_MULS) || (cached_type == TYPE_MLAS)))
        {
	  return 98 /* 0x62 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_SMULL) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMLAL)))
        {
	  return 99 /* 0x63 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_SMULLS) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_UMLALS)))
        {
	  return 100 /* 0x64 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMULWY) || (cached_type == TYPE_SMLAWY) || (cached_type == TYPE_SMUAD) || (cached_type == TYPE_SMUADX) || (cached_type == TYPE_SMLAD) || (cached_type == TYPE_SMLADX) || (cached_type == TYPE_SMUSD) || (cached_type == TYPE_SMUSDX) || (cached_type == TYPE_SMLSD) || (cached_type == TYPE_SMLSDX)))
        {
	  return 101 /* 0x65 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (cached_type == TYPE_SMLALXY))
        {
	  return 102 /* 0x66 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_SMMUL) || (cached_type == TYPE_SMMULR)))
        {
	  return 103 /* 0x67 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (cached_type == TYPE_BRANCH))
        {
	  return 104 /* 0x68 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (cached_type == TYPE_CALL))
        {
	  return 105 /* 0x69 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (cached_type == TYPE_LOAD_4))
        {
	  return 106 /* 0x6a */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (cached_type == TYPE_LOAD_BYTE))
        {
	  return 107 /* 0x6b */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (cached_type == TYPE_STORE_4))
        {
	  return 108 /* 0x6c */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (cached_type == TYPE_LOAD_8))
        {
	  return 109 /* 0x6d */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && (cached_type == TYPE_STORE_8))
        {
	  return 110 /* 0x6e */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 111 /* 0x6f */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JS)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM1136JFS))))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 112 /* 0x70 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 113 /* 0x71 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && ((cached_type == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 114 /* 0x72 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && ((cached_type == TYPE_SMLALXY) || (cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMLAXY)))
        {
	  return 115 /* 0x73 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && ((cached_type == TYPE_MUL) || (cached_type == TYPE_MLA) || (cached_type == TYPE_MULS) || (cached_type == TYPE_MLAS) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMLALS) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_SMLAWX)))
        {
	  return 116 /* 0x74 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_BYTE)))
        {
	  return 117 /* 0x75 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 118 /* 0x76 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && (cached_type == TYPE_LOAD_12))
        {
	  return 119 /* 0x77 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && (cached_type == TYPE_LOAD_16))
        {
	  return 120 /* 0x78 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && (cached_type == TYPE_STORE_4))
        {
	  return 121 /* 0x79 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && (cached_type == TYPE_STORE_8))
        {
	  return 122 /* 0x7a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && (cached_type == TYPE_STORE_12))
        {
	  return 123 /* 0x7b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && (cached_type == TYPE_STORE_16))
        {
	  return 124 /* 0x7c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && (cached_type == TYPE_BRANCH))
        {
	  return 125 /* 0x7d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA526)))) && (cached_type == TYPE_CALL))
        {
	  return 126 /* 0x7e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 127 /* 0x7f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && (cached_type == TYPE_SMLALXY))
        {
	  return 128 /* 0x80 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && ((cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMULWY) || (cached_type == TYPE_SMLAWY)))
        {
	  return 129 /* 0x81 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && ((cached_type == TYPE_MUL) || (cached_type == TYPE_MLA) || (cached_type == TYPE_MULS) || (cached_type == TYPE_MLAS)))
        {
	  return 130 /* 0x82 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && ((cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMLALS) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_SMLALS)))
        {
	  return 131 /* 0x83 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_BYTE)))
        {
	  return 132 /* 0x84 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 133 /* 0x85 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && (cached_type == TYPE_LOAD_12))
        {
	  return 134 /* 0x86 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && (cached_type == TYPE_LOAD_16))
        {
	  return 135 /* 0x87 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && (cached_type == TYPE_STORE_4))
        {
	  return 136 /* 0x88 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && (cached_type == TYPE_STORE_8))
        {
	  return 137 /* 0x89 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && (cached_type == TYPE_STORE_12))
        {
	  return 138 /* 0x8a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && (cached_type == TYPE_STORE_16))
        {
	  return 139 /* 0x8b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && (cached_type == TYPE_BRANCH))
        {
	  return 140 /* 0x8c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA606TE)))) && (cached_type == TYPE_CALL))
        {
	  return 141 /* 0x8d */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 142 /* 0x8e */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && ((cached_type == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 143 /* 0x8f */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && ((cached_type == TYPE_SMULWY) || (cached_type == TYPE_SMLAWY) || (cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMLAXY)))
        {
	  return 144 /* 0x90 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && ((cached_type == TYPE_MUL) || (cached_type == TYPE_MLA)))
        {
	  return 145 /* 0x91 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && ((cached_type == TYPE_MULS) || (cached_type == TYPE_MLAS) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_SMLALXY) || (cached_type == TYPE_SMLAWX)))
        {
	  return 146 /* 0x92 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && ((cached_type == TYPE_SMULLS) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMLALS)))
        {
	  return 147 /* 0x93 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_BYTE)))
        {
	  return 148 /* 0x94 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && ((cached_type == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_12)))
        {
	  return 149 /* 0x95 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && (cached_type == TYPE_LOAD_16))
        {
	  return 150 /* 0x96 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && (cached_type == TYPE_STORE_4))
        {
	  return 151 /* 0x97 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && ((cached_type == TYPE_STORE_8) || (cached_type == TYPE_STORE_12)))
        {
	  return 152 /* 0x98 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && (cached_type == TYPE_STORE_16))
        {
	  return 153 /* 0x99 */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && (cached_type == TYPE_BRANCH))
        {
	  return 154 /* 0x9a */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA626TE))))) && (cached_type == TYPE_CALL))
        {
	  return 155 /* 0x9b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG)))
        {
	  return 156 /* 0x9c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 157 /* 0x9d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && ((cached_type == TYPE_SMULWY) || (cached_type == TYPE_SMLAWY) || (cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMLAXY)))
        {
	  return 158 /* 0x9e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && ((cached_type == TYPE_MUL) || (cached_type == TYPE_MLA)))
        {
	  return 159 /* 0x9f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && ((cached_type == TYPE_MULS) || (cached_type == TYPE_MLAS) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_SMLALXY) || (cached_type == TYPE_SMLAWX)))
        {
	  return 160 /* 0xa0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && ((cached_type == TYPE_SMULLS) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMLALS)))
        {
	  return 161 /* 0xa1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_BYTE)))
        {
	  return 162 /* 0xa2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && ((cached_type == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_12)))
        {
	  return 163 /* 0xa3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (cached_type == TYPE_LOAD_16))
        {
	  return 164 /* 0xa4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (cached_type == TYPE_STORE_4))
        {
	  return 165 /* 0xa5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && ((cached_type == TYPE_STORE_8) || (cached_type == TYPE_STORE_12)))
        {
	  return 166 /* 0xa6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (cached_type == TYPE_STORE_16))
        {
	  return 167 /* 0xa7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (cached_type == TYPE_BRANCH))
        {
	  return 168 /* 0xa8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FMP626)))) && (cached_type == TYPE_CALL))
        {
	  return 169 /* 0xa9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && ((cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 170 /* 0xaa */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 171 /* 0xab */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && ((cached_type == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM)))
        {
	  return 172 /* 0xac */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG)))
        {
	  return 173 /* 0xad */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && ((cached_type == TYPE_SMLALXY) || (cached_type == TYPE_MUL) || (cached_type == TYPE_MLA) || (cached_type == TYPE_MULS) || (cached_type == TYPE_MLAS) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_SMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_UMLALS) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_SMLAWX) || (cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMLAXY)))
        {
	  return 174 /* 0xae */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_BYTE)))
        {
	  return 175 /* 0xaf */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (cached_type == TYPE_STORE_4))
        {
	  return 176 /* 0xb0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && ((cached_type == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_12)))
        {
	  return 177 /* 0xb1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (cached_type == TYPE_LOAD_16))
        {
	  return 178 /* 0xb2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && ((cached_type == TYPE_STORE_8) || (cached_type == TYPE_STORE_12)))
        {
	  return 179 /* 0xb3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (cached_type == TYPE_STORE_16))
        {
	  return 180 /* 0xb4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (cached_type == TYPE_BRANCH))
        {
	  return 181 /* 0xb5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_FA726TE)))) && (cached_type == TYPE_CALL))
        {
	  return 182 /* 0xb6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 183 /* 0xb7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 184 /* 0xb8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 185 /* 0xb9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 186 /* 0xba */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_STORE_4))
        {
	  return 187 /* 0xbb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 188 /* 0xbc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_STORE_8))
        {
	  return 189 /* 0xbd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_LOAD_12))
        {
	  return 190 /* 0xbe */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_STORE_12))
        {
	  return 191 /* 0xbf */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_LOAD_12))
        {
	  return 192 /* 0xc0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_STORE_12))
        {
	  return 193 /* 0xc1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_BRANCH) || (cached_type == TYPE_CALL)))
        {
	  return 194 /* 0xc2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FADDS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FADDD) || (cached_type == TYPE_FMOV) || (cached_type == TYPE_FMULS) || (cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD)))
        {
	  return 195 /* 0xc3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 196 /* 0xc4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_FMULS))
        {
	  return 197 /* 0xc5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 198 /* 0xc6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_FMULD))
        {
	  return 199 /* 0xc7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 200 /* 0xc8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 201 /* 0xc9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 202 /* 0xca */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 203 /* 0xcb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && ((cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC)))
        {
	  return 204 /* 0xcc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_F_FLAG))
        {
	  return 205 /* 0xcd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_F_LOADS))
        {
	  return 206 /* 0xce */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_F_LOADD))
        {
	  return 207 /* 0xcf */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_F_STORES))
        {
	  return 208 /* 0xd0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5)))) && (cached_type == TYPE_F_STORED))
        {
	  return 209 /* 0xd1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_BRANCH))
        {
	  return 210 /* 0xd2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_CALL))
        {
	  return 211 /* 0xd3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (((cached_type == TYPE_ADR) || (cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_EXTEND)) || (((cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG)) && (! (get_attr_length (insn) == 8)))))
        {
	  return 212 /* 0xd4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_REG)))
        {
	  return 213 /* 0xd5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 214 /* 0xd6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 215 /* 0xd7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_UDIV) || (cached_type == TYPE_SDIV)))
        {
	  return 216 /* 0xd8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 217 /* 0xd9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_STORE_4))
        {
	  return 218 /* 0xda */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 219 /* 0xdb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_STORE_8))
        {
	  return 220 /* 0xdc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_LOAD_12))
        {
	  return 221 /* 0xdd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_STORE_16))
        {
	  return 222 /* 0xde */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_LOAD_16))
        {
	  return 223 /* 0xdf */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_STORE_12))
        {
	  return 224 /* 0xe0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FADDS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FADDD) || (cached_type == TYPE_FMOV) || (cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD)))
        {
	  return 225 /* 0xe1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 226 /* 0xe2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_FMULS))
        {
	  return 227 /* 0xe3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_cortex_a7_neon_type = get_attr_cortex_a7_neon_type (insn)) == CORTEX_A7_NEON_TYPE_NEON_MUL))
        {
	  return 228 /* 0xe4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 229 /* 0xe5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_cortex_a7_neon_type = get_attr_cortex_a7_neon_type (insn)) == CORTEX_A7_NEON_TYPE_NEON_MLA))
        {
	  return 230 /* 0xe6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_FMULD))
        {
	  return 231 /* 0xe7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_FMACD))
        {
	  return 232 /* 0xe8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_FFMAD))
        {
	  return 233 /* 0xe9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 234 /* 0xea */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 235 /* 0xeb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 236 /* 0xec */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && ((cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC)))
        {
	  return 237 /* 0xed */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_F_FLAG))
        {
	  return 238 /* 0xee */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_F_LOADS))
        {
	  return 239 /* 0xef */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_F_LOADD))
        {
	  return 240 /* 0xf0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_F_STORES))
        {
	  return 241 /* 0xf1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (cached_type == TYPE_F_STORED))
        {
	  return 242 /* 0xf2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7)))) && (get_attr_is_neon_type (insn) == IS_NEON_TYPE_YES) && ((cached_cortex_a7_neon_type = get_attr_cortex_a7_neon_type (insn)) == CORTEX_A7_NEON_TYPE_NEON_OTHER))
        {
	  return 243 /* 0xf3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 244 /* 0xf4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_EXTEND)))
        {
	  return 245 /* 0xf5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG)))
        {
	  return 246 /* 0xf6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG) || (cached_type == TYPE_MRS)))
        {
	  return 247 /* 0xf7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_MUL) || (cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMMUL)))
        {
	  return 248 /* 0xf8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_MLA) || (cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMLAWY) || (cached_type == TYPE_SMMLA) || (cached_type == TYPE_SMLAD) || (cached_type == TYPE_SMLSD)))
        {
	  return 249 /* 0xf9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_SMULL) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_UMAAL) || (cached_type == TYPE_SMLALXY)))
        {
	  return 250 /* 0xfa */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_SMULWY) || (cached_type == TYPE_SMUAD) || (cached_type == TYPE_SMUSD)))
        {
	  return 251 /* 0xfb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_SMLALD) || (cached_type == TYPE_SMLSLD)))
        {
	  return 252 /* 0xfc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_BYTE)))
        {
	  return 253 /* 0xfd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 254 /* 0xfe */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_STORE_4) || (cached_type == TYPE_STORE_8)))
        {
	  return 255 /* 0xff */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 256 /* 0x100 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (cached_type == TYPE_BRANCH))
        {
	  return 257 /* 0x101 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (cached_type == TYPE_CALL))
        {
	  return 258 /* 0x102 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD) || (cached_type == TYPE_FADDS) || (cached_type == TYPE_FADDD)))
        {
	  return 259 /* 0x103 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (cached_type == TYPE_FMULS))
        {
	  return 260 /* 0x104 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && (cached_type == TYPE_FMULD))
        {
	  return 261 /* 0x105 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 262 /* 0x106 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 263 /* 0x107 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 264 /* 0x108 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 265 /* 0x109 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_FMOV) || (cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD)))
        {
	  return 266 /* 0x10a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F)))
        {
	  return 267 /* 0x10b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MRC))
        {
	  return 268 /* 0x10c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MRRC))
        {
	  return 269 /* 0x10d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_INT_1))
        {
	  return 270 /* 0x10e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_INT_2))
        {
	  return 271 /* 0x10f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_INT_3))
        {
	  return 272 /* 0x110 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_INT_4))
        {
	  return 273 /* 0x111 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_INT_5))
        {
	  return 274 /* 0x112 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VQNEG_VQABS))
        {
	  return 275 /* 0x113 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VMOV))
        {
	  return 276 /* 0x114 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VABA))
        {
	  return 277 /* 0x115 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VABA_QQQ))
        {
	  return 278 /* 0x116 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_BIT_OPS_Q))
        {
	  return 279 /* 0x117 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MUL_DDD_8_16_QDD_16_8_LONG_32_16_LONG))
        {
	  return 280 /* 0x118 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MUL_QQQ_8_16_32_DDD_32))
        {
	  return 281 /* 0x119 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR))
        {
	  return 282 /* 0x11a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_8_16_QDD_16_8_LONG_32_16_LONG))
        {
	  return 283 /* 0x11b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_8_16))
        {
	  return 284 /* 0x11c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG))
        {
	  return 285 /* 0x11d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR))
        {
	  return 286 /* 0x11e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MUL_DDD_16_SCALAR_32_16_LONG_SCALAR))
        {
	  return 287 /* 0x11f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MUL_QQD_32_SCALAR))
        {
	  return 288 /* 0x120 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MLA_DDD_16_SCALAR_QDD_32_16_LONG_SCALAR))
        {
	  return 289 /* 0x121 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_SHIFT_1))
        {
	  return 290 /* 0x122 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_SHIFT_2))
        {
	  return 291 /* 0x123 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_SHIFT_3))
        {
	  return 292 /* 0x124 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VQSHL_VRSHL_VQRSHL_QQQ))
        {
	  return 293 /* 0x125 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VSRA_VRSRA))
        {
	  return 294 /* 0x126 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD))
        {
	  return 295 /* 0x127 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ))
        {
	  return 296 /* 0x128 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VSUM))
        {
	  return 297 /* 0x129 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_DDD))
        {
	  return 298 /* 0x12a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMUL_QQD))
        {
	  return 299 /* 0x12b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD))
        {
	  return 300 /* 0x12c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ))
        {
	  return 301 /* 0x12d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR))
        {
	  return 302 /* 0x12e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR))
        {
	  return 303 /* 0x12f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_DDD))
        {
	  return 304 /* 0x130 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_type == TYPE_NEON_FP_RECPS_S_Q) || (cached_type == TYPE_NEON_FP_RSQRTS_S_Q)))
        {
	  return 305 /* 0x131 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_BP_SIMPLE))
        {
	  return 306 /* 0x132 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_BP_2CYCLE))
        {
	  return 307 /* 0x133 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_BP_3CYCLE))
        {
	  return 308 /* 0x134 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_LDR))
        {
	  return 309 /* 0x135 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_STR))
        {
	  return 310 /* 0x136 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD1_1_2_REGS))
        {
	  return 311 /* 0x137 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD1_3_4_REGS))
        {
	  return 312 /* 0x138 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES))
        {
	  return 313 /* 0x139 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD2_4_REGS))
        {
	  return 314 /* 0x13a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4))
        {
	  return 315 /* 0x13b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS))
        {
	  return 316 /* 0x13c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VST1_3_4_REGS))
        {
	  return 317 /* 0x13d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4))
        {
	  return 318 /* 0x13e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD1_VLD2_LANE))
        {
	  return 319 /* 0x13f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VLD3_VLD4_LANE))
        {
	  return 320 /* 0x140 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VST1_VST2_LANE))
        {
	  return 321 /* 0x141 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_VST3_VST4_LANE))
        {
	  return 322 /* 0x142 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MCR))
        {
	  return 323 /* 0x143 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8)))) && ((cached_cortex_a8_neon_type = get_attr_cortex_a8_neon_type (insn)) == CORTEX_A8_NEON_TYPE_NEON_MCR_2_MCRR))
        {
	  return 324 /* 0x144 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 325 /* 0x145 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 326 /* 0x146 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8) || (cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD)))
        {
	  return 327 /* 0x147 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 328 /* 0x148 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_STORE_4) || (cached_type == TYPE_STORE_8) || (cached_type == TYPE_F_STORES) || (cached_type == TYPE_F_STORED)))
        {
	  return 329 /* 0x149 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 330 /* 0x14a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (cached_type == TYPE_SMULXY))
        {
	  return 331 /* 0x14b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (cached_type == TYPE_SMLAXY))
        {
	  return 332 /* 0x14c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_MUL) || (cached_type == TYPE_SMMUL) || (cached_type == TYPE_SMMULR)))
        {
	  return 333 /* 0x14d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_MLA) || (cached_type == TYPE_SMMLA)))
        {
	  return 334 /* 0x14e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_SMULL) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_UMULLS) || (cached_type == TYPE_SMLAL) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_UMLALS)))
        {
	  return 335 /* 0x14f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (cached_type == TYPE_BRANCH))
        {
	  return 336 /* 0x150 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (cached_type == TYPE_CALL))
        {
	  return 337 /* 0x151 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_FMOV) || (cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD) || (cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR) || (cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC) || (cached_type == TYPE_F_FLAG)))
        {
	  return 338 /* 0x152 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_FADDS) || (cached_type == TYPE_FADDD) || (cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F)))
        {
	  return 339 /* 0x153 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD)))
        {
	  return 340 /* 0x154 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (cached_type == TYPE_FMULS))
        {
	  return 341 /* 0x155 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && (cached_type == TYPE_FMULD))
        {
	  return 342 /* 0x156 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 343 /* 0x157 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 344 /* 0x158 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 345 /* 0x159 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 346 /* 0x15a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MRC))
        {
	  return 347 /* 0x15b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MRRC))
        {
	  return 348 /* 0x15c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_INT_1))
        {
	  return 349 /* 0x15d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_INT_2))
        {
	  return 350 /* 0x15e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_INT_3))
        {
	  return 351 /* 0x15f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_INT_4))
        {
	  return 352 /* 0x160 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_INT_5))
        {
	  return 353 /* 0x161 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VQNEG_VQABS))
        {
	  return 354 /* 0x162 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VMOV))
        {
	  return 355 /* 0x163 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VABA))
        {
	  return 356 /* 0x164 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VABA_QQQ))
        {
	  return 357 /* 0x165 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_BIT_OPS_Q))
        {
	  return 358 /* 0x166 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MUL_DDD_8_16_QDD_16_8_LONG_32_16_LONG))
        {
	  return 359 /* 0x167 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MUL_QQQ_8_16_32_DDD_32))
        {
	  return 360 /* 0x168 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MUL_QDD_64_32_LONG_QQD_16_DDD_32_SCALAR_64_32_LONG_SCALAR))
        {
	  return 361 /* 0x169 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_8_16_QDD_16_8_LONG_32_16_LONG))
        {
	  return 362 /* 0x16a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_8_16))
        {
	  return 363 /* 0x16b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_32_QQD_16_DDD_32_SCALAR_QDD_64_32_LONG_SCALAR_QDD_64_32_LONG))
        {
	  return 364 /* 0x16c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MLA_QQQ_32_QQD_32_SCALAR))
        {
	  return 365 /* 0x16d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MUL_DDD_16_SCALAR_32_16_LONG_SCALAR))
        {
	  return 366 /* 0x16e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MUL_QQD_32_SCALAR))
        {
	  return 367 /* 0x16f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MLA_DDD_16_SCALAR_QDD_32_16_LONG_SCALAR))
        {
	  return 368 /* 0x170 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_SHIFT_1))
        {
	  return 369 /* 0x171 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_SHIFT_2))
        {
	  return 370 /* 0x172 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_SHIFT_3))
        {
	  return 371 /* 0x173 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VQSHL_VRSHL_VQRSHL_QQQ))
        {
	  return 372 /* 0x174 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VSRA_VRSRA))
        {
	  return 373 /* 0x175 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VADD_DDD_VABS_DD))
        {
	  return 374 /* 0x176 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VADD_QQQ_VABS_QQ))
        {
	  return 375 /* 0x177 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VSUM))
        {
	  return 376 /* 0x178 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_DDD))
        {
	  return 377 /* 0x179 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMUL_QQD))
        {
	  return 378 /* 0x17a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD))
        {
	  return 379 /* 0x17b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ))
        {
	  return 380 /* 0x17c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_DDD_SCALAR))
        {
	  return 381 /* 0x17d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VMLA_QQQ_SCALAR))
        {
	  return 382 /* 0x17e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_DDD))
        {
	  return 383 /* 0x17f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_FP_VRECPS_VRSQRTS_QQQ))
        {
	  return 384 /* 0x180 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_BP_SIMPLE))
        {
	  return 385 /* 0x181 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_BP_2CYCLE))
        {
	  return 386 /* 0x182 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_BP_3CYCLE))
        {
	  return 387 /* 0x183 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_LDR))
        {
	  return 388 /* 0x184 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_STR))
        {
	  return 389 /* 0x185 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD1_1_2_REGS))
        {
	  return 390 /* 0x186 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD1_3_4_REGS))
        {
	  return 391 /* 0x187 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD2_2_REGS_VLD1_VLD2_ALL_LANES))
        {
	  return 392 /* 0x188 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD2_4_REGS))
        {
	  return 393 /* 0x189 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4))
        {
	  return 394 /* 0x18a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VST1_1_2_REGS_VST2_2_REGS))
        {
	  return 395 /* 0x18b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VST1_3_4_REGS))
        {
	  return 396 /* 0x18c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VST2_4_REGS_VST3_VST4))
        {
	  return 397 /* 0x18d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD1_VLD2_LANE))
        {
	  return 398 /* 0x18e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4_LANE))
        {
	  return 399 /* 0x18f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VST1_VST2_LANE))
        {
	  return 400 /* 0x190 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VST3_VST4_LANE))
        {
	  return 401 /* 0x191 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_VLD3_VLD4_ALL_LANES))
        {
	  return 402 /* 0x192 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MCR))
        {
	  return 403 /* 0x193 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9)))) && ((cached_cortex_a9_neon_type = get_attr_cortex_a9_neon_type (insn)) == CORTEX_A9_NEON_TYPE_NEON_MCR_2_MCRR))
        {
	  return 404 /* 0x194 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 405 /* 0x195 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_CRC) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 406 /* 0x196 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 407 /* 0x197 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES))
        {
	  return 408 /* 0x198 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES))
        {
	  return 409 /* 0x199 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_UDIV))
        {
	  return 410 /* 0x19a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_SDIV))
        {
	  return 411 /* 0x19b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_BLOCK))
        {
	  return 412 /* 0x19c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_BRANCH))
        {
	  return 413 /* 0x19d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8)))
        {
	  return 414 /* 0x19e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 415 /* 0x19f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_STORE_4) || (cached_type == TYPE_STORE_8)))
        {
	  return 416 /* 0x1a0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 417 /* 0x1a1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ABD))
        {
	  return 418 /* 0x1a2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ABD_Q))
        {
	  return 419 /* 0x1a3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ARITH_ACC))
        {
	  return 420 /* 0x1a4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ARITH_ACC_Q))
        {
	  return 421 /* 0x1a5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ARITH_BASIC))
        {
	  return 422 /* 0x1a6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ARITH_COMPLEX))
        {
	  return 423 /* 0x1a7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_MULTIPLY))
        {
	  return 424 /* 0x1a8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_MULTIPLY_Q))
        {
	  return 425 /* 0x1a9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_MLA))
        {
	  return 426 /* 0x1aa */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_MLA_Q))
        {
	  return 427 /* 0x1ab */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SAT_MLA_LONG))
        {
	  return 428 /* 0x1ac */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_ACC))
        {
	  return 429 /* 0x1ad */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_IMM_BASIC))
        {
	  return 430 /* 0x1ae */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX))
        {
	  return 431 /* 0x1af */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_BASIC))
        {
	  return 432 /* 0x1b0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q))
        {
	  return 433 /* 0x1b1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_COMPLEX))
        {
	  return 434 /* 0x1b2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_SHIFT_REG_COMPLEX_Q))
        {
	  return 435 /* 0x1b3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_NEGABS))
        {
	  return 436 /* 0x1b4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_ARITH))
        {
	  return 437 /* 0x1b5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_ARITH_Q))
        {
	  return 438 /* 0x1b6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_CVT_INT))
        {
	  return 439 /* 0x1b7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_CVT_INT_Q))
        {
	  return 440 /* 0x1b8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_CVT16))
        {
	  return 441 /* 0x1b9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_MUL))
        {
	  return 442 /* 0x1ba */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_MUL_Q))
        {
	  return 443 /* 0x1bb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_MLA))
        {
	  return 444 /* 0x1bc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_MLA_Q))
        {
	  return 445 /* 0x1bd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_RECPE_RSQRTE))
        {
	  return 446 /* 0x1be */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q))
        {
	  return 447 /* 0x1bf */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_BITOPS))
        {
	  return 448 /* 0x1c0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_BITOPS_Q))
        {
	  return 449 /* 0x1c1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FROM_GP))
        {
	  return 450 /* 0x1c2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_FROM_GP_Q))
        {
	  return 451 /* 0x1c3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_TBL3_TBL4))
        {
	  return 452 /* 0x1c4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_ZIP_Q))
        {
	  return 453 /* 0x1c5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_TO_GP))
        {
	  return 454 /* 0x1c6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_A))
        {
	  return 455 /* 0x1c7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_B))
        {
	  return 456 /* 0x1c8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_C))
        {
	  return 457 /* 0x1c9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_D))
        {
	  return 458 /* 0x1ca */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_E))
        {
	  return 459 /* 0x1cb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_LOAD_F))
        {
	  return 460 /* 0x1cc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_A))
        {
	  return 461 /* 0x1cd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_B))
        {
	  return 462 /* 0x1ce */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_C))
        {
	  return 463 /* 0x1cf */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_D))
        {
	  return 464 /* 0x1d0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_E))
        {
	  return 465 /* 0x1d1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_F))
        {
	  return 466 /* 0x1d2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_G))
        {
	  return 467 /* 0x1d3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_cortex_a15_neon_type = get_attr_cortex_a15_neon_type (insn)) == CORTEX_A15_NEON_TYPE_NEON_STORE_H))
        {
	  return 468 /* 0x1d4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 469 /* 0x1d5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_FADDS))
        {
	  return 470 /* 0x1d6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_FADDD))
        {
	  return 471 /* 0x1d7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_FMULS))
        {
	  return 472 /* 0x1d8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_FMULD))
        {
	  return 473 /* 0x1d9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 474 /* 0x1da */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 475 /* 0x1db */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F)))
        {
	  return 476 /* 0x1dc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_FCMPD))
        {
	  return 477 /* 0x1dd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_FCMPS))
        {
	  return 478 /* 0x1de */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_FFARITHD))
        {
	  return 479 /* 0x1df */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_FMOV))
        {
	  return 480 /* 0x1e0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 481 /* 0x1e1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC)))
        {
	  return 482 /* 0x1e2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_FFARITHS))
        {
	  return 483 /* 0x1e3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 484 /* 0x1e4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 485 /* 0x1e5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA15)))) && (cached_type == TYPE_CALL))
        {
	  return 486 /* 0x1e6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 487 /* 0x1e7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_REV) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 488 /* 0x1e8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG)))
        {
	  return 489 /* 0x1e9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_MUL) || (cached_type == TYPE_MULS) || (cached_type == TYPE_SMMUL) || (cached_type == TYPE_SMMULR)))
        {
	  return 490 /* 0x1ea */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_MLA) || (cached_type == TYPE_MLAS) || (cached_type == TYPE_SMMLA)))
        {
	  return 491 /* 0x1eb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_SMLAD) || (cached_type == TYPE_SMLADX) || (cached_type == TYPE_SMLSD) || (cached_type == TYPE_SMLSDX) || (cached_type == TYPE_SMUAD) || (cached_type == TYPE_SMUADX) || (cached_type == TYPE_SMUSD) || (cached_type == TYPE_SMUSDX)))
        {
	  return 492 /* 0x1ec */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_SMLAL) || (cached_type == TYPE_SMLALS) || (cached_type == TYPE_UMAAL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_UMLALS)))
        {
	  return 493 /* 0x1ed */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_SMLALD) || (cached_type == TYPE_SMLALXY) || (cached_type == TYPE_SMLSLD)))
        {
	  return 494 /* 0x1ee */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_SMULL) || (cached_type == TYPE_SMULLS) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMULLS)))
        {
	  return 495 /* 0x1ef */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_UDIV))
        {
	  return 496 /* 0x1f0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_SDIV))
        {
	  return 497 /* 0x1f1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_BRANCH))
        {
	  return 498 /* 0x1f2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8)))
        {
	  return 499 /* 0x1f3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_LOAD_12))
        {
	  return 500 /* 0x1f4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_LOAD_16))
        {
	  return 501 /* 0x1f5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_STORE_4) || (cached_type == TYPE_STORE_8)))
        {
	  return 502 /* 0x1f6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_STORE_12))
        {
	  return 503 /* 0x1f7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_STORE_16))
        {
	  return 504 /* 0x1f8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_CALL))
        {
	  return 505 /* 0x1f9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_ABD))
        {
	  return 506 /* 0x1fa */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_ABD_Q))
        {
	  return 507 /* 0x1fb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_ARITH_ACC))
        {
	  return 508 /* 0x1fc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_ARITH_ACC_Q))
        {
	  return 509 /* 0x1fd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_ARITH_BASIC))
        {
	  return 510 /* 0x1fe */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_ARITH_COMPLEX))
        {
	  return 511 /* 0x1ff */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_MULTIPLY))
        {
	  return 512 /* 0x200 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_MULTIPLY_Q))
        {
	  return 513 /* 0x201 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_MLA))
        {
	  return 514 /* 0x202 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_MLA_Q))
        {
	  return 515 /* 0x203 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_SAT_MLA_LONG))
        {
	  return 516 /* 0x204 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_SHIFT_ACC))
        {
	  return 517 /* 0x205 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_SHIFT_IMM_BASIC))
        {
	  return 518 /* 0x206 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX))
        {
	  return 519 /* 0x207 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_BASIC))
        {
	  return 520 /* 0x208 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q))
        {
	  return 521 /* 0x209 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_COMPLEX))
        {
	  return 522 /* 0x20a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_SHIFT_REG_COMPLEX_Q))
        {
	  return 523 /* 0x20b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_NEGABS))
        {
	  return 524 /* 0x20c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_ARITH))
        {
	  return 525 /* 0x20d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_ARITH_Q))
        {
	  return 526 /* 0x20e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_CVT_INT))
        {
	  return 527 /* 0x20f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_CVT_INT_Q))
        {
	  return 528 /* 0x210 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_CVT16))
        {
	  return 529 /* 0x211 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_MUL))
        {
	  return 530 /* 0x212 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_MUL_Q))
        {
	  return 531 /* 0x213 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_MLA))
        {
	  return 532 /* 0x214 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_MLA_Q))
        {
	  return 533 /* 0x215 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_RECPE_RSQRTE))
        {
	  return 534 /* 0x216 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q))
        {
	  return 535 /* 0x217 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_BITOPS))
        {
	  return 536 /* 0x218 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_BITOPS_Q))
        {
	  return 537 /* 0x219 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FROM_GP))
        {
	  return 538 /* 0x21a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_FROM_GP_Q))
        {
	  return 539 /* 0x21b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_TBL3_TBL4))
        {
	  return 540 /* 0x21c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_ZIP_Q))
        {
	  return 541 /* 0x21d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_TO_GP))
        {
	  return 542 /* 0x21e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_F_FLAG))
        {
	  return 543 /* 0x21f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD)))
        {
	  return 544 /* 0x220 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_LOAD_A))
        {
	  return 545 /* 0x221 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_LOAD_B))
        {
	  return 546 /* 0x222 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_LOAD_C))
        {
	  return 547 /* 0x223 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_LOAD_D))
        {
	  return 548 /* 0x224 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_LOAD_E))
        {
	  return 549 /* 0x225 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_LOAD_F))
        {
	  return 550 /* 0x226 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_LOAD_G))
        {
	  return 551 /* 0x227 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_LOAD_H))
        {
	  return 552 /* 0x228 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_F_STORES) || (cached_type == TYPE_F_STORED)))
        {
	  return 553 /* 0x229 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_STORE_A))
        {
	  return 554 /* 0x22a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_cortex_a17_neon_type = get_attr_cortex_a17_neon_type (insn)) == CORTEX_A17_NEON_TYPE_NEON_STORE_B))
        {
	  return 555 /* 0x22b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 556 /* 0x22c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_FADDS))
        {
	  return 557 /* 0x22d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_FADDD))
        {
	  return 558 /* 0x22e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_FMULS) || (cached_type == TYPE_FMULD)))
        {
	  return 559 /* 0x22f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS) || (cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 560 /* 0x230 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F) || (cached_type == TYPE_F_RINTS) || (cached_type == TYPE_F_RINTD)))
        {
	  return 561 /* 0x231 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD)))
        {
	  return 562 /* 0x232 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_FFARITHD))
        {
	  return 563 /* 0x233 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_FMOV) || (cached_type == TYPE_FCSEL)))
        {
	  return 564 /* 0x234 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 565 /* 0x235 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC)))
        {
	  return 566 /* 0x236 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && (cached_type == TYPE_FFARITHS))
        {
	  return 567 /* 0x237 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 568 /* 0x238 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA17)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 569 /* 0x239 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_ADR) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MOV_SHIFT)))
        {
	  return 570 /* 0x23a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG)))
        {
	  return 571 /* 0x23b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_CSEL) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 572 /* 0x23c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_CRC) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_EXT) || (cached_type == TYPE_ALUS_EXT) || (cached_type == TYPE_BFM) || (cached_type == TYPE_BFX) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 573 /* 0x23d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 574 /* 0x23e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (cached_type == TYPE_ROTATE_IMM))
        {
	  return 575 /* 0x23f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 576 /* 0x240 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_UDIV) || (cached_type == TYPE_SDIV)))
        {
	  return 577 /* 0x241 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_ACQ)))
        {
	  return 578 /* 0x242 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_STORE_4) || (cached_type == TYPE_STORE_REL)))
        {
	  return 579 /* 0x243 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 580 /* 0x244 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (cached_type == TYPE_STORE_8))
        {
	  return 581 /* 0x245 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 582 /* 0x246 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 583 /* 0x247 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_BRANCH) || (cached_type == TYPE_CALL)))
        {
	  return 584 /* 0x248 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FADDS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FADDD) || (cached_type == TYPE_FMOV) || (cached_type == TYPE_F_CVT) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD) || (cached_type == TYPE_FCCMPS) || (cached_type == TYPE_FCCMPD) || (cached_type == TYPE_FCSEL) || (cached_type == TYPE_F_RINTS) || (cached_type == TYPE_F_RINTD) || (cached_type == TYPE_F_MINMAXS) || (cached_type == TYPE_F_MINMAXD)))
        {
	  return 585 /* 0x249 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 586 /* 0x24a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_FMULS) || (cached_type == TYPE_FMULD)))
        {
	  return 587 /* 0x24b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAS) || (cached_type == TYPE_FFMAD)))
        {
	  return 588 /* 0x24c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 589 /* 0x24d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC)))
        {
	  return 590 /* 0x24e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_F_CVTI2F) || (cached_type == TYPE_NEON_FROM_GP) || (cached_type == TYPE_NEON_FROM_GP_Q)))
        {
	  return 591 /* 0x24f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_NEON_TO_GP) || (cached_type == TYPE_NEON_TO_GP_Q)))
        {
	  return 592 /* 0x250 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (cached_type == TYPE_F_FLAG))
        {
	  return 593 /* 0x251 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD)) || ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_64)))
        {
	  return 594 /* 0x252 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_128) || (cached_cortex_a53_advsimd_type == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_LOAD_LOTS)))
        {
	  return 595 /* 0x253 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type == TYPE_F_STORES) || (cached_type == TYPE_F_STORED)) || ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_64)))
        {
	  return 596 /* 0x254 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_128) || (cached_cortex_a53_advsimd_type == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_STORE_LOTS)))
        {
	  return 597 /* 0x255 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU))
        {
	  return 598 /* 0x256 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_ALU_Q))
        {
	  return 599 /* 0x257 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_MUL))
        {
	  return 600 /* 0x258 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_MUL_Q))
        {
	  return 601 /* 0x259 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)) || ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_DIV_S)))
        {
	  return 602 /* 0x25a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)) || ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_DIV_D)))
        {
	  return 603 /* 0x25b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_DIV_S_Q))
        {
	  return 604 /* 0x25c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_cortex_a53_advsimd_type = get_attr_cortex_a53_advsimd_type (insn)) == CORTEX_A53_ADVSIMD_TYPE_ADVSIMD_DIV_D_Q))
        {
	  return 605 /* 0x25d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (cached_type == TYPE_CRYPTO_AESE))
        {
	  return 606 /* 0x25e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (cached_type == TYPE_CRYPTO_AESMC))
        {
	  return 607 /* 0x25f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (cached_type == TYPE_CRYPTO_SHA1_FAST))
        {
	  return 608 /* 0x260 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (cached_type == TYPE_CRYPTO_SHA256_FAST))
        {
	  return 609 /* 0x261 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && (cached_type == TYPE_CRYPTO_SHA1_XOR))
        {
	  return 610 /* 0x262 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53)))) && ((cached_type == TYPE_CRYPTO_SHA1_SLOW) || (cached_type == TYPE_CRYPTO_SHA256_SLOW)))
        {
	  return 611 /* 0x263 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFX) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_ROTATE_IMM) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 612 /* 0x264 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_BFM) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_CRC) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 613 /* 0x265 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 614 /* 0x266 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 615 /* 0x267 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_UDIV) || (cached_type == TYPE_SDIV)))
        {
	  return 616 /* 0x268 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (cached_type == TYPE_BLOCK))
        {
	  return 617 /* 0x269 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (cached_type == TYPE_BRANCH))
        {
	  return 618 /* 0x26a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8)))
        {
	  return 619 /* 0x26b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 620 /* 0x26c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_STORE_4) || (cached_type == TYPE_STORE_8)))
        {
	  return 621 /* 0x26d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 622 /* 0x26e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ABD))
        {
	  return 623 /* 0x26f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ABD_Q))
        {
	  return 624 /* 0x270 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ARITH_ACC))
        {
	  return 625 /* 0x271 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ARITH_ACC_Q))
        {
	  return 626 /* 0x272 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ARITH_BASIC))
        {
	  return 627 /* 0x273 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ARITH_COMPLEX))
        {
	  return 628 /* 0x274 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_MULTIPLY))
        {
	  return 629 /* 0x275 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_MULTIPLY_Q))
        {
	  return 630 /* 0x276 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_MLA))
        {
	  return 631 /* 0x277 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_MLA_Q))
        {
	  return 632 /* 0x278 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SAT_MLA_LONG))
        {
	  return 633 /* 0x279 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_ACC))
        {
	  return 634 /* 0x27a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_IMM_BASIC))
        {
	  return 635 /* 0x27b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX))
        {
	  return 636 /* 0x27c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_BASIC))
        {
	  return 637 /* 0x27d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_BASIC_Q))
        {
	  return 638 /* 0x27e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_COMPLEX))
        {
	  return 639 /* 0x27f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_SHIFT_REG_COMPLEX_Q))
        {
	  return 640 /* 0x280 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_NEGABS))
        {
	  return 641 /* 0x281 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_ARITH))
        {
	  return 642 /* 0x282 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_ARITH_Q))
        {
	  return 643 /* 0x283 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_REDUCTIONS_Q))
        {
	  return 644 /* 0x284 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_CVT_INT))
        {
	  return 645 /* 0x285 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_CVT_INT_Q))
        {
	  return 646 /* 0x286 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_CVT16))
        {
	  return 647 /* 0x287 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_MUL))
        {
	  return 648 /* 0x288 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_MUL_Q))
        {
	  return 649 /* 0x289 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_MLA))
        {
	  return 650 /* 0x28a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_MLA_Q))
        {
	  return 651 /* 0x28b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_RECPE_RSQRTE))
        {
	  return 652 /* 0x28c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_RECPE_RSQRTE_Q))
        {
	  return 653 /* 0x28d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_RECPS_RSQRTS))
        {
	  return 654 /* 0x28e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FP_RECPS_RSQRTS_Q))
        {
	  return 655 /* 0x28f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_BITOPS))
        {
	  return 656 /* 0x290 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_BITOPS_Q))
        {
	  return 657 /* 0x291 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FROM_GP))
        {
	  return 658 /* 0x292 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_FROM_GP_Q))
        {
	  return 659 /* 0x293 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_TBL3_TBL4))
        {
	  return 660 /* 0x294 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_ZIP_Q))
        {
	  return 661 /* 0x295 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_TO_GP))
        {
	  return 662 /* 0x296 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_A))
        {
	  return 663 /* 0x297 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_B))
        {
	  return 664 /* 0x298 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_C))
        {
	  return 665 /* 0x299 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_D))
        {
	  return 666 /* 0x29a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_E))
        {
	  return 667 /* 0x29b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_LOAD_F))
        {
	  return 668 /* 0x29c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_STORE_A))
        {
	  return 669 /* 0x29d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_STORE_B))
        {
	  return 670 /* 0x29e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_cortex_a57_neon_type = get_attr_cortex_a57_neon_type (insn)) == CORTEX_A57_NEON_TYPE_NEON_STORE_COMPLEX))
        {
	  return 671 /* 0x29f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 672 /* 0x2a0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_FADDS) || (cached_type == TYPE_FADDD)))
        {
	  return 673 /* 0x2a1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_FMULS) || (cached_type == TYPE_FMULD)))
        {
	  return 674 /* 0x2a2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS) || (cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 675 /* 0x2a3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F)))
        {
	  return 676 /* 0x2a4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD) || (cached_type == TYPE_FCCMPS) || (cached_type == TYPE_FCCMPD)))
        {
	  return 677 /* 0x2a5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD)))
        {
	  return 678 /* 0x2a6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_FMOV) || (cached_type == TYPE_FCSEL)))
        {
	  return 679 /* 0x2a7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS) || (cached_type == TYPE_NEON_FP_DIV_S) || (cached_type == TYPE_NEON_FP_SQRT_S)))
        {
	  return 680 /* 0x2a8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD) || (cached_type == TYPE_NEON_FP_DIV_D) || (cached_type == TYPE_NEON_FP_SQRT_D)))
        {
	  return 681 /* 0x2a9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD) || (cached_type == TYPE_NEON_FP_DIV_S_Q) || (cached_type == TYPE_NEON_FP_DIV_D_Q) || (cached_type == TYPE_NEON_FP_SQRT_S_Q) || (cached_type == TYPE_NEON_FP_SQRT_D_Q)))
        {
	  return 682 /* 0x2aa */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_CRYPTO_AESE) || (cached_type == TYPE_CRYPTO_AESMC) || (cached_type == TYPE_CRYPTO_SHA1_FAST) || (cached_type == TYPE_CRYPTO_SHA256_FAST)))
        {
	  return 683 /* 0x2ab */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && ((cached_type == TYPE_CRYPTO_SHA1_SLOW) || (cached_type == TYPE_CRYPTO_SHA256_SLOW)))
        {
	  return 684 /* 0x2ac */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (cached_type == TYPE_CRYPTO_SHA1_XOR))
        {
	  return 685 /* 0x2ad */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA57)))) && (cached_type == TYPE_CALL))
        {
	  return 686 /* 0x2ae */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG)))
        {
	  return 687 /* 0x2af */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG)))
        {
	  return 688 /* 0x2b0 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 689 /* 0x2b1 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 690 /* 0x2b2 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_MUL) || (cached_type == TYPE_SMMUL)))
        {
	  return 691 /* 0x2b3 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_SMULXY) || (cached_type == TYPE_SMULWY) || (cached_type == TYPE_SMUAD) || (cached_type == TYPE_SMUSD)))
        {
	  return 692 /* 0x2b4 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_MLA) || (cached_type == TYPE_SMMLA)))
        {
	  return 693 /* 0x2b5 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMLAWY) || (cached_type == TYPE_SMLAD) || (cached_type == TYPE_SMLSD)))
        {
	  return 694 /* 0x2b6 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_SMLALD) || (cached_type == TYPE_SMLSLD)))
        {
	  return 695 /* 0x2b7 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_SMULL) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_UMLAL) || (cached_type == TYPE_UMAAL)))
        {
	  return 696 /* 0x2b8 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (cached_type == TYPE_UDIV))
        {
	  return 697 /* 0x2b9 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (cached_type == TYPE_SDIV))
        {
	  return 698 /* 0x2ba */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (cached_type == TYPE_BRANCH))
        {
	  return 699 /* 0x2bb */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (cached_type == TYPE_CALL))
        {
	  return 700 /* 0x2bc */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8)))
        {
	  return 701 /* 0x2bd */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 702 /* 0x2be */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_STORE_4) || (cached_type == TYPE_STORE_8)))
        {
	  return 703 /* 0x2bf */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 704 /* 0x2c0 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (cached_type == TYPE_FMOV))
        {
	  return 705 /* 0x2c1 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCMPS)))
        {
	  return 706 /* 0x2c2 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_FADDS) || (cached_type == TYPE_FMULS)))
        {
	  return 707 /* 0x2c3 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 708 /* 0x2c4 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 709 /* 0x2c5 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (cached_type == TYPE_F_LOADS))
        {
	  return 710 /* 0x2c6 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (cached_type == TYPE_F_STORES))
        {
	  return 711 /* 0x2c7 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 712 /* 0x2c8 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC)))
        {
	  return 713 /* 0x2c9 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 714 /* 0x2ca */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_FADDD) || (cached_type == TYPE_FMULD)))
        {
	  return 715 /* 0x2cb */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 716 /* 0x2cc */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FCONSTD)))
        {
	  return 717 /* 0x2cd */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (cached_type == TYPE_FCMPD))
        {
	  return 718 /* 0x2ce */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F)))
        {
	  return 719 /* 0x2cf */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && ((cached_type == TYPE_F_LOADD) || (cached_type == TYPE_F_STORED)))
        {
	  return 720 /* 0x2d0 */;
        }
      else if ((((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5)))))) && (cached_type == TYPE_F_STORES))
        {
	  return 721 /* 0x2d1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MRC) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 722 /* 0x2d2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM)))
        {
	  return 723 /* 0x2d3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SMLAXY) || (cached_type == TYPE_SMLALXY) || (cached_type == TYPE_SMULXY)))
        {
	  return 724 /* 0x2d4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_MUL) || (cached_type == TYPE_MULS) || (cached_type == TYPE_UMULL) || (cached_type == TYPE_SMULL)))
        {
	  return 725 /* 0x2d5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_SDIV) || (cached_type == TYPE_UDIV)))
        {
	  return 726 /* 0x2d6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && (cached_type == TYPE_EXTEND))
        {
	  return 727 /* 0x2d7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_MLA) || (cached_type == TYPE_MLAS)))
        {
	  return 728 /* 0x2d8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_BRANCH) || (cached_type == TYPE_CALL)))
        {
	  return 729 /* 0x2d9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 730 /* 0x2da */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 731 /* 0x2db */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 732 /* 0x2dc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && (cached_type == TYPE_STORE_4))
        {
	  return 733 /* 0x2dd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && (cached_type == TYPE_STORE_8))
        {
	  return 734 /* 0x2de */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 735 /* 0x2df */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FADDS) || (cached_type == TYPE_FADDD) || (cached_type == TYPE_FMOV) || (cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD) || (cached_type == TYPE_FCMPD) || (cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FMULS) || (cached_type == TYPE_F_FLAG)))
        {
	  return 736 /* 0x2e0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 737 /* 0x2e1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 738 /* 0x2e2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && (cached_type == TYPE_F_LOADS))
        {
	  return 739 /* 0x2e3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && (cached_type == TYPE_F_STORES))
        {
	  return 740 /* 0x2e4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && (cached_type == TYPE_FMULD))
        {
	  return 741 /* 0x2e5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 742 /* 0x2e6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 743 /* 0x2e7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && (cached_type == TYPE_F_LOADD))
        {
	  return 744 /* 0x2e8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && (cached_type == TYPE_F_STORED))
        {
	  return 745 /* 0x2e9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7)))) && ((cached_type == TYPE_F_MCRR) || (cached_type == TYPE_F_MRRC)))
        {
	  return 746 /* 0x2ea */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MVN_SHIFT_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)) || ((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 747 /* 0x2eb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 748 /* 0x2ec */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_STORE_4)) && (
#line 60 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/cortex-m4.md"
(arm_address_offset_is_imm (insn))))
        {
	  return 749 /* 0x2ed */;
        }
      else if (((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_STORE_4)) && (! (
#line 60 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/cortex-m4.md"
(arm_address_offset_is_imm (insn)))))
        {
	  return 750 /* 0x2ee */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 751 /* 0x2ef */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_STORE_8))
        {
	  return 752 /* 0x2f0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_LOAD_12))
        {
	  return 753 /* 0x2f1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_STORE_12))
        {
	  return 754 /* 0x2f2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_LOAD_16))
        {
	  return 755 /* 0x2f3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_STORE_16))
        {
	  return 756 /* 0x2f4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_BRANCH))
        {
	  return 757 /* 0x2f5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_CALL))
        {
	  return 758 /* 0x2f6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_BLOCK))
        {
	  return 759 /* 0x2f7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 760 /* 0x2f8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && ((cached_type == TYPE_FMOV) || (cached_type == TYPE_FCONSTS)))
        {
	  return 761 /* 0x2f9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && ((cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC) || (cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 762 /* 0x2fa */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_FMULS))
        {
	  return 763 /* 0x2fb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 764 /* 0x2fc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_FFARITHS))
        {
	  return 765 /* 0x2fd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_FADDS))
        {
	  return 766 /* 0x2fe */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_FCMPS))
        {
	  return 767 /* 0x2ff */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_F_FLAG))
        {
	  return 768 /* 0x300 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && ((cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F)))
        {
	  return 769 /* 0x301 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_F_LOADS))
        {
	  return 770 /* 0x302 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_F_STORES))
        {
	  return 771 /* 0x303 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_F_LOADD))
        {
	  return 772 /* 0x304 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4)))) && (cached_type == TYPE_F_STORED))
        {
	  return 773 /* 0x305 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (cached_type == TYPE_BRANCH))
        {
	  return 774 /* 0x306 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (cached_type == TYPE_CALL))
        {
	  return 775 /* 0x307 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (! ((cached_predicated = get_attr_predicated (insn)) == PREDICATED_YES)) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_BFX) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_CSEL) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_ROTATE_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 776 /* 0x308 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_predicated = get_attr_predicated (insn)) == PREDICATED_YES) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_BFX) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG) || (cached_type == TYPE_ROTATE_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG) || (cached_type == TYPE_MRS) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 777 /* 0x309 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_ALU_EXT) || (cached_type == TYPE_ALUS_EXT) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT)))
        {
	  return 778 /* 0x30a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (! ((cached_predicated = get_attr_predicated (insn)) == PREDICATED_YES)) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 779 /* 0x30b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_predicated = get_attr_predicated (insn)) == PREDICATED_YES) && ((cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 780 /* 0x30c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES))
        {
	  return 781 /* 0x30d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES))
        {
	  return 782 /* 0x30e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_UDIV) || (cached_type == TYPE_SDIV)))
        {
	  return 783 /* 0x30f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8)))
        {
	  return 784 /* 0x310 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 785 /* 0x311 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_STORE_4) || (cached_type == TYPE_STORE_8)))
        {
	  return 786 /* 0x312 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 787 /* 0x313 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_ARITH_SIMPLE))
        {
	  return 788 /* 0x314 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_ARITH_BASIC))
        {
	  return 789 /* 0x315 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_ARITH_COMPLEX))
        {
	  return 790 /* 0x316 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_MULTIPLY) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_MLA) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_SAT_MLA_LONG)))
        {
	  return 791 /* 0x317 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_SHIFT_ACC))
        {
	  return 792 /* 0x318 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_SHIFT_IMM_BASIC) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_SHIFT_REG_BASIC)))
        {
	  return 793 /* 0x319 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_SHIFT_IMM_COMPLEX) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_SHIFT_REG_COMPLEX)))
        {
	  return 794 /* 0x31a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_UNARY))
        {
	  return 795 /* 0x31b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_ADD))
        {
	  return 796 /* 0x31c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_ABD))
        {
	  return 797 /* 0x31d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_COMPARE))
        {
	  return 798 /* 0x31e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_MINMAX))
        {
	  return 799 /* 0x31f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_REDUC_ADD))
        {
	  return 800 /* 0x320 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_ROUND))
        {
	  return 801 /* 0x321 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_CVT))
        {
	  return 802 /* 0x322 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_MUL))
        {
	  return 803 /* 0x323 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_MLA))
        {
	  return 804 /* 0x324 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_ESTIMATE))
        {
	  return 805 /* 0x325 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_ESTIMATEX))
        {
	  return 806 /* 0x326 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FP_STEP))
        {
	  return 807 /* 0x327 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_BITOPS))
        {
	  return 808 /* 0x328 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_BITOPS_Q))
        {
	  return 809 /* 0x329 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_BITINS))
        {
	  return 810 /* 0x32a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_TBL))
        {
	  return 811 /* 0x32b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_FROM_GP))
        {
	  return 812 /* 0x32c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_TO_GP))
        {
	  return 813 /* 0x32d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD) || (cached_type == TYPE_NEON_LDP)))
        {
	  return 814 /* 0x32e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (cached_type == TYPE_NEON_LDP_Q))
        {
	  return 815 /* 0x32f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_1) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_ALL)))
        {
	  return 816 /* 0x330 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_2))
        {
	  return 817 /* 0x331 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_3))
        {
	  return 818 /* 0x332 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_4))
        {
	  return 819 /* 0x333 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD1_ONE))
        {
	  return 820 /* 0x334 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD2_2))
        {
	  return 821 /* 0x335 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ONE))
        {
	  return 822 /* 0x336 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD2_ALL))
        {
	  return 823 /* 0x337 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD3_3))
        {
	  return 824 /* 0x338 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ONE))
        {
	  return 825 /* 0x339 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD3_ALL))
        {
	  return 826 /* 0x33a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD4_4))
        {
	  return 827 /* 0x33b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ONE))
        {
	  return 828 /* 0x33c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_LOAD4_ALL))
        {
	  return 829 /* 0x33d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_F_STORES) || (cached_type == TYPE_F_STORED) || (cached_type == TYPE_NEON_STP)))
        {
	  return 830 /* 0x33e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (cached_type == TYPE_NEON_STP_Q))
        {
	  return 831 /* 0x33f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE1_1))
        {
	  return 832 /* 0x340 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE1_2))
        {
	  return 833 /* 0x341 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE1_3))
        {
	  return 834 /* 0x342 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE1_4))
        {
	  return 835 /* 0x343 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE1_ONE))
        {
	  return 836 /* 0x344 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE2_2) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_STORE2_ONE)))
        {
	  return 837 /* 0x345 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE3_3) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_STORE3_ONE)))
        {
	  return 838 /* 0x346 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (((cached_exynos_m1_neon_type = get_attr_exynos_m1_neon_type (insn)) == EXYNOS_M1_NEON_TYPE_NEON_STORE4_4) || (cached_exynos_m1_neon_type == EXYNOS_M1_NEON_TYPE_NEON_STORE4_ONE)))
        {
	  return 839 /* 0x347 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 840 /* 0x348 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_FADDS) || (cached_type == TYPE_FADDD)))
        {
	  return 841 /* 0x349 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_FMULS) || (cached_type == TYPE_FMULD)))
        {
	  return 842 /* 0x34a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS) || (cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 843 /* 0x34b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_RINTS) || (cached_type == TYPE_F_RINTD)))
        {
	  return 844 /* 0x34c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (cached_type == TYPE_F_CVTF2I))
        {
	  return 845 /* 0x34d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (cached_type == TYPE_F_CVTI2F))
        {
	  return 846 /* 0x34e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD)))
        {
	  return 847 /* 0x34f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_FCCMPS) || (cached_type == TYPE_FCCMPD)))
        {
	  return 848 /* 0x350 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (cached_type == TYPE_FCSEL))
        {
	  return 849 /* 0x351 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD)))
        {
	  return 850 /* 0x352 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (cached_type == TYPE_FMOV))
        {
	  return 851 /* 0x353 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_NEON_FP_DIV_S) || (cached_type == TYPE_NEON_FP_DIV_S_Q) || (cached_type == TYPE_FSQRTS) || (cached_type == TYPE_NEON_FP_SQRT_S) || (cached_type == TYPE_NEON_FP_SQRT_S_Q)))
        {
	  return 852 /* 0x354 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_NEON_FP_DIV_D) || (cached_type == TYPE_NEON_FP_DIV_D_Q) || (cached_type == TYPE_FSQRTD) || (cached_type == TYPE_NEON_FP_SQRT_D) || (cached_type == TYPE_NEON_FP_SQRT_D_Q)))
        {
	  return 853 /* 0x355 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_F_MINMAXS) || (cached_type == TYPE_F_MINMAXD)))
        {
	  return 854 /* 0x356 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_CRYPTO_AESE) || (cached_type == TYPE_CRYPTO_AESMC) || (cached_type == TYPE_CRYPTO_SHA1_XOR) || (cached_type == TYPE_CRYPTO_SHA1_FAST) || (cached_type == TYPE_CRYPTO_SHA256_FAST)))
        {
	  return 855 /* 0x357 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_CRYPTO_SHA1_SLOW) || (cached_type == TYPE_CRYPTO_SHA256_SLOW)))
        {
	  return 856 /* 0x358 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && ((cached_type == TYPE_NEON_MUL_B_LONG) || (cached_type == TYPE_NEON_MUL_H_LONG) || (cached_type == TYPE_NEON_MUL_S_LONG)))
        {
	  return 857 /* 0x359 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (cached_type == TYPE_NEON_MUL_D_LONG))
        {
	  return 858 /* 0x35a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_EXYNOSM1)))) && (cached_type == TYPE_CRC))
        {
	  return 859 /* 0x35b */;
        }
      else if ((((((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))) && ((! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))))) && ((! ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && ((cached_type == TYPE_FMOV) || (cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD)))
        {
	  return 860 /* 0x35c */;
        }
      else if ((((((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))) && ((! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))))) && ((! ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && ((cached_type == TYPE_FADDS) || (cached_type == TYPE_FADDD) || (cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD) || (cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F) || (cached_type == TYPE_FMULS) || (cached_type == TYPE_FMACS) || (cached_type == TYPE_FFMAS)))
        {
	  return 861 /* 0x35d */;
        }
      else if ((((((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))) && ((! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))))) && ((! ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && ((cached_type == TYPE_FMULD) || (cached_type == TYPE_FMACD) || (cached_type == TYPE_FFMAD)))
        {
	  return 862 /* 0x35e */;
        }
      else if ((((((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))) && ((! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))))) && ((! ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 863 /* 0x35f */;
        }
      else if ((((((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))) && ((! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))))) && ((! ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 864 /* 0x360 */;
        }
      else if ((((((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))) && ((! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))))) && ((! ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && ((cached_type == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD) || (cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 865 /* 0x361 */;
        }
      else if ((((((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))) && ((! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))))) && ((! ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && ((cached_type == TYPE_F_STORES) || (cached_type == TYPE_F_STORED) || (cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC)))
        {
	  return 866 /* 0x362 */;
        }
      else if ((((((
#line 120 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm.md"
(arm_fpu_attr)) == (
(FPU_VFP)))) && ((! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_ARM10E))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA5))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA8))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA9))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXA53))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXM7))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4))))) && (! (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))))) && ((! ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR4F)))) || (((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_CORTEXR5))))))))) && (cached_type == TYPE_F_FLAG))
        {
	  return 867 /* 0x363 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG)) && (! ((cached_conds = get_attr_conds (insn)) == CONDS_SET)))
        {
	  return 868 /* 0x364 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MVN_IMM) || (cached_type == TYPE_MVN_REG)) && ((cached_conds = get_attr_conds (insn)) == CONDS_SET))
        {
	  return 869 /* 0x365 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG)) && (! ((cached_conds = get_attr_conds (insn)) == CONDS_SET)))
        {
	  return 870 /* 0x366 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_ADC_IMM) || (cached_type == TYPE_ADCS_IMM) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_ADCS_REG) || (cached_type == TYPE_ADR) || (cached_type == TYPE_BFM) || (cached_type == TYPE_REV) || (cached_type == TYPE_ALU_DSP_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_SHIFT_REG)) && ((cached_conds = get_attr_conds (insn)) == CONDS_SET))
        {
	  return 871 /* 0x367 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)) && (! ((cached_conds = get_attr_conds (insn)) == CONDS_SET)) && ((cached_shift = get_attr_shift (insn)) == 1))
        {
	  return 872 /* 0x368 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)) && ((cached_conds = get_attr_conds (insn)) == CONDS_SET) && ((cached_shift = get_attr_shift (insn)) == 1))
        {
	  return 873 /* 0x369 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (! ((cached_conds = get_attr_conds (insn)) == CONDS_SET)) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 874 /* 0x36a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_conds = get_attr_conds (insn)) == CONDS_SET) && ((cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_LOGICS_SHIFT_IMM) || (cached_type == TYPE_ALU_SHIFT_REG) || (cached_type == TYPE_LOGIC_SHIFT_REG) || (cached_type == TYPE_ALUS_SHIFT_REG) || (cached_type == TYPE_LOGICS_SHIFT_REG) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MOV_SHIFT) || (cached_type == TYPE_MVN_SHIFT) || (cached_type == TYPE_MOV_SHIFT_REG) || (cached_type == TYPE_MVN_SHIFT_REG)))
        {
	  return 875 /* 0x36b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES) || ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES)))
        {
	  return 876 /* 0x36c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_UDIV) || (cached_type == TYPE_SDIV)))
        {
	  return 877 /* 0x36d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (cached_type == TYPE_BRANCH))
        {
	  return 878 /* 0x36e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (cached_type == TYPE_CALL))
        {
	  return 879 /* 0x36f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_LOAD_BYTE) || (cached_type == TYPE_LOAD_4)))
        {
	  return 880 /* 0x370 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (cached_type == TYPE_LOAD_8))
        {
	  return 881 /* 0x371 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (cached_type == TYPE_STORE_4))
        {
	  return 882 /* 0x372 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && (cached_type == TYPE_STORE_8))
        {
	  return 883 /* 0x373 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_LOAD_12) || (cached_type == TYPE_LOAD_16)))
        {
	  return 884 /* 0x374 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_STORE_12) || (cached_type == TYPE_STORE_16)))
        {
	  return 885 /* 0x375 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_FADDS) || (cached_type == TYPE_FADDD)))
        {
	  return 886 /* 0x376 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_FMULS) || (cached_type == TYPE_FMULD)))
        {
	  return 887 /* 0x377 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 888 /* 0x378 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_FDIVD) || (cached_type == TYPE_FSQRTD)))
        {
	  return 889 /* 0x379 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_FMACS) || (cached_type == TYPE_FMACD)))
        {
	  return 890 /* 0x37a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_FMOV) || (cached_type == TYPE_FFARITHS) || (cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCMPD) || (cached_type == TYPE_F_CVT) || (cached_type == TYPE_F_CVTF2I) || (cached_type == TYPE_F_CVTI2F)))
        {
	  return 891 /* 0x37b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_F_LOADS) || (cached_type == TYPE_F_LOADD)))
        {
	  return 892 /* 0x37c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_F_STORES) || (cached_type == TYPE_F_STORED)))
        {
	  return 893 /* 0x37d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_F_MRC) || (cached_type == TYPE_F_MRRC) || (cached_type == TYPE_F_FLAG)))
        {
	  return 894 /* 0x37e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_MARVELL_PJ4)))) && ((cached_type == TYPE_F_MCR) || (cached_type == TYPE_F_MCRR)))
        {
	  return 895 /* 0x37f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_BRANCH))
        {
	  return 896 /* 0x380 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_CALL))
        {
	  return 897 /* 0x381 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_F_LOADD) || (cached_type == TYPE_F_LOADS)))
        {
	  return 898 /* 0x382 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_F_STORED) || (cached_type == TYPE_F_STORES)))
        {
	  return 899 /* 0x383 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_FMOV) || (cached_type == TYPE_FCONSTS) || (cached_type == TYPE_FCONSTD)))
        {
	  return 900 /* 0x384 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_F_MCR))
        {
	  return 901 /* 0x385 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_F_MRC))
        {
	  return 902 /* 0x386 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_LOAD_16))
        {
	  return 903 /* 0x387 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_STORE_16))
        {
	  return 904 /* 0x388 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8)) && (get_attr_fp (insn) == FP_YES))
        {
	  return 905 /* 0x389 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_LOAD_4) || (cached_type == TYPE_LOAD_8)))
        {
	  return 906 /* 0x38a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_STORE_4) || (cached_type == TYPE_STORE_8)))
        {
	  return 907 /* 0x38b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_MOV_REG) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_MRS)))
        {
	  return 908 /* 0x38c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_CSEL))
        {
	  return 909 /* 0x38d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_ALU_IMM) || (cached_type == TYPE_ALU_SREG) || (cached_type == TYPE_ALU_SHIFT_IMM_LSL_1TO4) || (cached_type == TYPE_ALU_SHIFT_IMM_OTHER) || (cached_type == TYPE_ALU_EXT) || (cached_type == TYPE_ADC_REG) || (cached_type == TYPE_LOGIC_IMM) || (cached_type == TYPE_LOGIC_REG) || (cached_type == TYPE_LOGIC_SHIFT_IMM) || (cached_type == TYPE_CLZ) || (cached_type == TYPE_RBIT) || (cached_type == TYPE_ADR) || (cached_type == TYPE_MOV_REG) || (cached_type == TYPE_SHIFT_IMM) || (cached_type == TYPE_MOV_IMM) || (cached_type == TYPE_EXTEND) || (cached_type == TYPE_MULTIPLE)))
        {
	  return 910 /* 0x38e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_SHIFT_REG))
        {
	  return 911 /* 0x38f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_REV))
        {
	  return 912 /* 0x390 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_ALUS_IMM) || (cached_type == TYPE_ALUS_SREG) || (cached_type == TYPE_ALUS_SHIFT_IMM) || (cached_type == TYPE_ALUS_EXT) || (cached_type == TYPE_LOGICS_IMM) || (cached_type == TYPE_LOGICS_REG) || (cached_type == TYPE_LOGICS_SHIFT_IMM)))
        {
	  return 913 /* 0x391 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_mul32 = get_attr_mul32 (insn)) == MUL32_YES))
        {
	  return 914 /* 0x392 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_widen_mul64 = get_attr_widen_mul64 (insn)) == WIDEN_MUL64_YES))
        {
	  return 915 /* 0x393 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_SDIV) || (cached_type == TYPE_UDIV)))
        {
	  return 916 /* 0x394 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_FCMPD) || (cached_type == TYPE_FCMPS) || (cached_type == TYPE_FCCMPD) || (cached_type == TYPE_FCCMPS)))
        {
	  return 917 /* 0x395 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_FCSEL))
        {
	  return 918 /* 0x396 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_BFX))
        {
	  return 919 /* 0x397 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_BFM))
        {
	  return 920 /* 0x398 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_F_RINTD) || (cached_type == TYPE_F_RINTS)))
        {
	  return 921 /* 0x399 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_F_CVT))
        {
	  return 922 /* 0x39a */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_F_CVTF2I))
        {
	  return 923 /* 0x39b */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_F_CVTI2F))
        {
	  return 924 /* 0x39c */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_FADDD) || (cached_type == TYPE_FADDS) || (cached_type == TYPE_FMULD) || (cached_type == TYPE_FMULS)))
        {
	  return 925 /* 0x39d */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_FDIVS) || (cached_type == TYPE_FSQRTS)))
        {
	  return 926 /* 0x39e */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_FDIVD))
        {
	  return 927 /* 0x39f */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_FSQRTD))
        {
	  return 928 /* 0x3a0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_FFARITHD) || (cached_type == TYPE_FFARITHS)))
        {
	  return 929 /* 0x3a1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_F_MINMAXD) || (cached_type == TYPE_F_MINMAXS)))
        {
	  return 930 /* 0x3a2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_DUP) || (cached_type == TYPE_NEON_DUP_Q)))
        {
	  return 931 /* 0x3a3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_LOAD1_1REG) || (cached_type == TYPE_NEON_LOAD1_1REG_Q)))
        {
	  return 932 /* 0x3a4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_STORE1_1REG) || (cached_type == TYPE_NEON_STORE1_1REG_Q)))
        {
	  return 933 /* 0x3a5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_LOGIC) || (cached_type == TYPE_NEON_LOGIC_Q) || (cached_type == TYPE_NEON_BSL) || (cached_type == TYPE_NEON_BSL_Q) || (cached_type == TYPE_NEON_MOVE) || (cached_type == TYPE_NEON_MOVE_Q)))
        {
	  return 934 /* 0x3a6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_TO_GP) || (cached_type == TYPE_NEON_TO_GP_Q)))
        {
	  return 935 /* 0x3a7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FROM_GP) || (cached_type == TYPE_NEON_FROM_GP_Q) || (cached_type == TYPE_NEON_INS) || (cached_type == TYPE_NEON_INS_Q)))
        {
	  return 936 /* 0x3a8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_SHIFT_IMM) || (cached_type == TYPE_NEON_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SHIFT_REG) || (cached_type == TYPE_NEON_SHIFT_REG_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_LONG) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_IMM_NARROW_Q) || (cached_type == TYPE_NEON_SAT_SHIFT_REG) || (cached_type == TYPE_NEON_SAT_SHIFT_REG_Q) || (cached_type == TYPE_NEON_SHIFT_IMM_NARROW_Q)))
        {
	  return 937 /* 0x3a9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_ADD) || (cached_type == TYPE_NEON_ADD_Q) || (cached_type == TYPE_NEON_SUB) || (cached_type == TYPE_NEON_SUB_Q) || (cached_type == TYPE_NEON_NEG) || (cached_type == TYPE_NEON_NEG_Q) || (cached_type == TYPE_NEON_ABS) || (cached_type == TYPE_NEON_ABS_Q) || (cached_type == TYPE_NEON_ABD_Q) || (cached_type == TYPE_NEON_ARITH_ACC) || (cached_type == TYPE_NEON_ARITH_ACC_Q) || (cached_type == TYPE_NEON_REDUC_ADD) || (cached_type == TYPE_NEON_REDUC_ADD_Q) || (cached_type == TYPE_NEON_ADD_HALVE) || (cached_type == TYPE_NEON_ADD_HALVE_Q) || (cached_type == TYPE_NEON_SUB_HALVE) || (cached_type == TYPE_NEON_SUB_HALVE_Q) || (cached_type == TYPE_NEON_QADD) || (cached_type == TYPE_NEON_QADD_Q) || (cached_type == TYPE_NEON_COMPARE) || (cached_type == TYPE_NEON_COMPARE_Q) || (cached_type == TYPE_NEON_COMPARE_ZERO) || (cached_type == TYPE_NEON_COMPARE_ZERO_Q) || (cached_type == TYPE_NEON_TST) || (cached_type == TYPE_NEON_TST_Q) || (cached_type == TYPE_NEON_MINMAX) || (cached_type == TYPE_NEON_MINMAX_Q)))
        {
	  return 938 /* 0x3aa */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_ARITH_ACC) || (cached_type == TYPE_NEON_ARITH_ACC_Q)))
        {
	  return 939 /* 0x3ab */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_MUL_B) || (cached_type == TYPE_NEON_MUL_B_Q) || (cached_type == TYPE_NEON_MUL_H) || (cached_type == TYPE_NEON_MUL_H_Q) || (cached_type == TYPE_NEON_MUL_S) || (cached_type == TYPE_NEON_MUL_S_Q) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR) || (cached_type == TYPE_NEON_FP_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MUL_D_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_B) || (cached_type == TYPE_NEON_MLA_B_Q) || (cached_type == TYPE_NEON_MLA_H) || (cached_type == TYPE_NEON_MLA_H_Q) || (cached_type == TYPE_NEON_MLA_S) || (cached_type == TYPE_NEON_MLA_S_Q) || (cached_type == TYPE_NEON_MLA_H_SCALAR) || (cached_type == TYPE_NEON_MLA_H_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_S_SCALAR) || (cached_type == TYPE_NEON_MLA_S_SCALAR_Q) || (cached_type == TYPE_NEON_MLA_B_LONG) || (cached_type == TYPE_NEON_MLA_H_LONG) || (cached_type == TYPE_NEON_MLA_S_LONG) || (cached_type == TYPE_NEON_FP_MUL_S) || (cached_type == TYPE_NEON_FP_MUL_S_Q) || (cached_type == TYPE_NEON_FP_MUL_D) || (cached_type == TYPE_NEON_FP_MUL_D_Q) || (cached_type == TYPE_NEON_FP_MLA_S) || (cached_type == TYPE_NEON_FP_MLA_S_Q) || (cached_type == TYPE_NEON_FP_MLA_D) || (cached_type == TYPE_NEON_FP_MLA_D_Q) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR) || (cached_type == TYPE_NEON_FP_MLA_S_SCALAR_Q) || (cached_type == TYPE_NEON_FP_MLA_D_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_B) || (cached_type == TYPE_NEON_SAT_MUL_B_Q) || (cached_type == TYPE_NEON_SAT_MUL_H) || (cached_type == TYPE_NEON_SAT_MUL_H_Q) || (cached_type == TYPE_NEON_SAT_MUL_S) || (cached_type == TYPE_NEON_SAT_MUL_S_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_Q) || (cached_type == TYPE_NEON_SAT_MUL_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MUL_S_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_B_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_LONG) || (cached_type == TYPE_NEON_SAT_MLA_H_SCALAR_LONG) || (cached_type == TYPE_NEON_SAT_MLA_S_SCALAR_LONG)))
        {
	  return 940 /* 0x3ac */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FP_ABD_S) || (cached_type == TYPE_NEON_FP_ABD_S_Q) || (cached_type == TYPE_NEON_FP_ABD_D) || (cached_type == TYPE_NEON_FP_ABD_D_Q)))
        {
	  return 941 /* 0x3ad */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FP_ADDSUB_S) || (cached_type == TYPE_NEON_FP_ADDSUB_S_Q) || (cached_type == TYPE_NEON_FP_ADDSUB_D) || (cached_type == TYPE_NEON_FP_ADDSUB_D_Q)))
        {
	  return 942 /* 0x3ae */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FP_DIV_S) || (cached_type == TYPE_NEON_FP_DIV_S_Q) || (cached_type == TYPE_NEON_FP_DIV_D) || (cached_type == TYPE_NEON_FP_DIV_D_Q)))
        {
	  return 943 /* 0x3af */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FP_NEG_S) || (cached_type == TYPE_NEON_FP_NEG_S_Q) || (cached_type == TYPE_NEON_FP_NEG_D) || (cached_type == TYPE_NEON_FP_NEG_D_Q) || (cached_type == TYPE_NEON_FP_ABS_S) || (cached_type == TYPE_NEON_FP_ABS_S_Q) || (cached_type == TYPE_NEON_FP_ABS_D) || (cached_type == TYPE_NEON_FP_ABS_D_Q)))
        {
	  return 944 /* 0x3b0 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FP_ROUND_S) || (cached_type == TYPE_NEON_FP_ROUND_S_Q) || (cached_type == TYPE_NEON_FP_ROUND_D) || (cached_type == TYPE_NEON_FP_ROUND_D_Q)))
        {
	  return 945 /* 0x3b1 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_INT_TO_FP_S) || (cached_type == TYPE_NEON_INT_TO_FP_S_Q) || (cached_type == TYPE_NEON_INT_TO_FP_D) || (cached_type == TYPE_NEON_INT_TO_FP_D_Q) || (cached_type == TYPE_NEON_FP_CVT_WIDEN_S) || (cached_type == TYPE_NEON_FP_CVT_NARROW_S_Q) || (cached_type == TYPE_NEON_FP_CVT_NARROW_D_Q)))
        {
	  return 946 /* 0x3b2 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FP_REDUC_ADD_S) || (cached_type == TYPE_NEON_FP_REDUC_ADD_S_Q) || (cached_type == TYPE_NEON_FP_REDUC_ADD_D) || (cached_type == TYPE_NEON_FP_REDUC_ADD_D_Q)))
        {
	  return 947 /* 0x3b3 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_CLS) || (cached_type == TYPE_NEON_CLS_Q)))
        {
	  return 948 /* 0x3b4 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_STORE1_ONE_LANE) || (cached_type == TYPE_NEON_STORE1_ONE_LANE_Q) || (cached_type == TYPE_NEON_STP) || (cached_type == TYPE_NEON_STP_Q)))
        {
	  return 949 /* 0x3b5 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_SUB_HALVE_NARROW_Q) || (cached_type == TYPE_NEON_ADD_HALVE_NARROW_Q)))
        {
	  return 950 /* 0x3b6 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_SHIFT_ACC) || (cached_type == TYPE_NEON_SHIFT_ACC_Q)))
        {
	  return 951 /* 0x3b7 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FP_COMPARE_S) || (cached_type == TYPE_NEON_FP_COMPARE_S_Q) || (cached_type == TYPE_NEON_FP_COMPARE_D) || (cached_type == TYPE_NEON_FP_COMPARE_D_Q)))
        {
	  return 952 /* 0x3b8 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FP_SQRT_S) || (cached_type == TYPE_NEON_FP_SQRT_S_Q) || (cached_type == TYPE_NEON_FP_SQRT_D) || (cached_type == TYPE_NEON_FP_SQRT_D_Q)))
        {
	  return 953 /* 0x3b9 */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_TBL1) || (cached_type == TYPE_NEON_TBL1_Q)))
        {
	  return 954 /* 0x3ba */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_TBL2) || (cached_type == TYPE_NEON_TBL2_Q)))
        {
	  return 955 /* 0x3bb */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_PERMUTE) || (cached_type == TYPE_NEON_PERMUTE_Q)))
        {
	  return 956 /* 0x3bc */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && (cached_type == TYPE_NEON_LOAD1_ALL_LANES))
        {
	  return 957 /* 0x3bd */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FP_RECPE_S) || (cached_type == TYPE_NEON_FP_RECPE_S_Q) || (cached_type == TYPE_NEON_FP_RECPE_D) || (cached_type == TYPE_NEON_FP_RECPE_D_Q) || (cached_type == TYPE_NEON_FP_RECPX_S) || (cached_type == TYPE_NEON_FP_RECPX_S_Q) || (cached_type == TYPE_NEON_FP_RECPX_D) || (cached_type == TYPE_NEON_FP_RECPX_D_Q)))
        {
	  return 958 /* 0x3be */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_FP_RECPS_S) || (cached_type == TYPE_NEON_FP_RECPS_S_Q) || (cached_type == TYPE_NEON_FP_RECPS_D) || (cached_type == TYPE_NEON_FP_RECPS_D_Q)))
        {
	  return 959 /* 0x3bf */;
        }
      else if ((((
#line 55 "../../../../../../../work-shared/gcc-13.4.0-r0/gcc-13.4.0/gcc/config/arm/arm-tune.md"
(((enum attr_tune) arm_tune))) == (
(TUNE_XGENE1)))) && ((cached_type == TYPE_NEON_MUL_D_LONG) || (cached_type == TYPE_CRYPTO_PMULL)))
        {
	  return 960 /* 0x3c0 */;
        }
      else
        {
	  return 962 /* 0x3c2 */;
        }

    }
}

